@@ -1,7 +1,7 @@
 var class_ogre_1_1_float_gpu_parameter_controller_value =
 [
     [ "FloatGpuParameterControllerValue", "class_ogre_1_1_float_gpu_parameter_controller_value.html#aa15f3e1a7e929f71dbc2c6d47199175f", null ],
-    [ "~FloatGpuParameterControllerValue", "class_ogre_1_1_float_gpu_parameter_controller_value.html#a4cd25fecd64c347a91c5277f4bfebbce", null ],
+    [ "create", "class_ogre_1_1_float_gpu_parameter_controller_value.html#ac804a54162283b2f94ddf937a3e7cdb6", null ],
     [ "getValue", "class_ogre_1_1_float_gpu_parameter_controller_value.html#a3d2c1276b208a33c2a0bc3a97247cd6e", null ],
     [ "setValue", "class_ogre_1_1_float_gpu_parameter_controller_value.html#a15070b767a1bf1cd7c0b6a97c319d029", null ]
 ];
\ No newline at end of file
