@@ -15,9 +15,9 @@ var class_ogre_1_1_g_l3_plus_render_system =
     [ "_getDepthStencilFormatFor", "class_ogre_1_1_g_l3_plus_render_system.html#a98c23effa8e7a111375bc0a27e9b2f89", null ],
     [ "createMultiRenderTarget", "class_ogre_1_1_g_l3_plus_render_system.html#afd00f0bccdd8832500e5ed52eee5be77", null ],
     [ "destroyRenderWindow", "class_ogre_1_1_g_l3_plus_render_system.html#a092487e8ab8ffe42bce344fb7a4c4541", null ],
-    [ "areFixedFunctionLightsInViewSpace", "class_ogre_1_1_g_l3_plus_render_system.html#a2ddd26db12f8cecef346f16c25e04fae", null ],
     [ "_setTexture", "class_ogre_1_1_g_l3_plus_render_system.html#a2ccdbd25f783a9c64aadc234aac93d87", null ],
-    [ "_setTextureAddressingMode", "class_ogre_1_1_g_l3_plus_render_system.html#a74f5d3668aa2a5ecab76f272f39ffb03", null ],
+    [ "_setSampler", "class_ogre_1_1_g_l3_plus_render_system.html#ab36aea7b8542a98a870b7de244117849", null ],
+    [ "_setTextureAddressingMode", "class_ogre_1_1_g_l3_plus_render_system.html#abd0559da33ca6ff32315dccd7966f696", null ],
     [ "_setTextureBorderColour", "class_ogre_1_1_g_l3_plus_render_system.html#a0b952b0373f8cdaaf7acac5e15e60570", null ],
     [ "_setTextureMipmapBias", "class_ogre_1_1_g_l3_plus_render_system.html#a3fa41dc5a8234641fa6246e71b4875d5", null ],
     [ "_setLineWidth", "class_ogre_1_1_g_l3_plus_render_system.html#ad924907f88f5ea789bc82d97149ebaf4", null ],
@@ -38,6 +38,7 @@ var class_ogre_1_1_g_l3_plus_render_system =
     [ "_setTextureUnitCompareFunction", "class_ogre_1_1_g_l3_plus_render_system.html#ac068003fa440b1ff68f059d4aef58cb2", null ],
     [ "_setTextureUnitCompareEnabled", "class_ogre_1_1_g_l3_plus_render_system.html#a36297395bb547a7980809cfb4535fec9", null ],
     [ "_setTextureLayerAnisotropy", "class_ogre_1_1_g_l3_plus_render_system.html#ab29f91b7d53b86b2bc74273e5077d40a", null ],
+    [ "_dispatchCompute", "class_ogre_1_1_g_l3_plus_render_system.html#a30bac3e9059a8681fc63ee66556a5a0b", null ],
     [ "_render", "class_ogre_1_1_g_l3_plus_render_system.html#ad6b5f3d0029b6a7add41aa0833b4aea0", null ],
     [ "setScissorTest", "class_ogre_1_1_g_l3_plus_render_system.html#aa82fcefbb2e338be7037734d1d3dbc44", null ],
     [ "clearFrameBuffer", "class_ogre_1_1_g_l3_plus_render_system.html#abd0c3b3a128c4e13ec6ba669dff6824c", null ],
@@ -47,7 +48,6 @@ var class_ogre_1_1_g_l3_plus_render_system =
     [ "unregisterThread", "class_ogre_1_1_g_l3_plus_render_system.html#abf5969cca19f815380e71a45386d2e81", null ],
     [ "preExtraThreadsStarted", "class_ogre_1_1_g_l3_plus_render_system.html#af8dce80de108c05fb7477e367773f0d1", null ],
     [ "postExtraThreadsStarted", "class_ogre_1_1_g_l3_plus_render_system.html#a7fbfe867fc50c5bc2dbdc8ec7c48626a", null ],
-    [ "setClipPlanesImpl", "class_ogre_1_1_g_l3_plus_render_system.html#a01e6581a377e82f5c306ea9d5c939353", null ],
     [ "_getStateCacheManager", "class_ogre_1_1_g_l3_plus_render_system.html#a15e22ac738389e62d8c0ac37debe8be6", null ],
     [ "_createVao", "class_ogre_1_1_g_l3_plus_render_system.html#ab144c7e8e0adc6f8bf8e5965bddb9a90", null ],
     [ "_bindVao", "class_ogre_1_1_g_l3_plus_render_system.html#af6dc48dd1001416215e05e329ae70691", null ],
@@ -58,18 +58,15 @@ var class_ogre_1_1_g_l3_plus_render_system =
     [ "_oneTimeContextInitialization", "class_ogre_1_1_g_l3_plus_render_system.html#abeb8846df70f13a57398879110e5ca24", null ],
     [ "initialiseContext", "class_ogre_1_1_g_l3_plus_render_system.html#a9969e9ead963147492cc8a85bca37a93", null ],
     [ "_setRenderTarget", "class_ogre_1_1_g_l3_plus_render_system.html#a630d759471ad28ee51cf53921c4e0329", null ],
-    [ "convertCompareFunction", "class_ogre_1_1_g_l3_plus_render_system.html#a9e27197340ec10de428608eae0692897", null ],
-    [ "convertStencilOp", "class_ogre_1_1_g_l3_plus_render_system.html#a4034c39b2bf0df0d29c6371d29c558ed", null ],
+    [ "convertCompareFunction", "class_ogre_1_1_g_l3_plus_render_system.html#aeeb44bff1b5829c3b401734693a8e072", null ],
+    [ "convertStencilOp", "class_ogre_1_1_g_l3_plus_render_system.html#a60db00707d0200332b5c69a8329fb104", null ],
     [ "bindGpuProgram", "class_ogre_1_1_g_l3_plus_render_system.html#a60721569c9a5af5443127d6933d56849", null ],
     [ "unbindGpuProgram", "class_ogre_1_1_g_l3_plus_render_system.html#ac306cee8fe166e70f8dbb0110a9811e8", null ],
-    [ "bindGpuProgramParameters", "class_ogre_1_1_g_l3_plus_render_system.html#a1f90d9ad1b3d70fd15b13ddd844d0c43", null ],
+    [ "bindGpuProgramParameters", "class_ogre_1_1_g_l3_plus_render_system.html#a3b4afd2063cd6325585bc2f7eb37665f", null ],
     [ "bindGpuProgramPassIterationParameters", "class_ogre_1_1_g_l3_plus_render_system.html#a70ba86bbb305dc8f8210cc3a13a1a867", null ],
-    [ "_setSceneBlending", "class_ogre_1_1_g_l3_plus_render_system.html#a24aae349d3ded2b5fd8666e4703127c2", null ],
     [ "_setSeparateSceneBlending", "class_ogre_1_1_g_l3_plus_render_system.html#a302fe1c87b6d7f4de2bbdaad6648a006", null ],
     [ "_setAlphaRejectSettings", "class_ogre_1_1_g_l3_plus_render_system.html#a4f4bff652fc2b85d7803dc54f0fb59e3", null ],
     [ "getDisplayMonitorCount", "class_ogre_1_1_g_l3_plus_render_system.html#a1526bb1c290815e1c6541f53782c7ff6", null ],
-    [ "_setSceneBlendingOperation", "class_ogre_1_1_g_l3_plus_render_system.html#ad66e95fef04d10c3ab0f1a9176cfa11d", null ],
-    [ "_setSeparateSceneBlendingOperation", "class_ogre_1_1_g_l3_plus_render_system.html#ac14d755b6f7cc2c327e71ef4d428a212", null ],
     [ "hasAnisotropicMipMapFilter", "class_ogre_1_1_g_l3_plus_render_system.html#ad65affaed7e771573042e2cbb206c047", null ],
     [ "beginProfileEvent", "class_ogre_1_1_g_l3_plus_render_system.html#aead888edc98d11905cbf8f40815dfebb", null ],
     [ "endProfileEvent", "class_ogre_1_1_g_l3_plus_render_system.html#a86f08fb580b6e1d8c064e96da2935b17", null ],
@@ -118,6 +115,7 @@ var class_ogre_1_1_g_l3_plus_render_system =
     [ "setGlobalNumberOfInstances", "class_ogre_1_1_g_l3_plus_render_system.html#a3e31b243ba86e2114925a99b2c2825e1", null ],
     [ "setDepthBufferFor", "class_ogre_1_1_g_l3_plus_render_system.html#a63c23bbd80d6862a54d471754d9bccf0", null ],
     [ "_useLights", "class_ogre_1_1_g_l3_plus_render_system.html#afe87000fc9e5619f4f17fd77b37a212f", null ],
+    [ "areFixedFunctionLightsInViewSpace", "class_ogre_1_1_g_l3_plus_render_system.html#a008131b65568c0bf072ae3a96203d6c0", null ],
     [ "_setWorldMatrix", "class_ogre_1_1_g_l3_plus_render_system.html#ae8d7a587d3a8d15102f73b65bbceb56e", null ],
     [ "_setViewMatrix", "class_ogre_1_1_g_l3_plus_render_system.html#a1a7926fe7b59598fdb7b7e743efdae6c", null ],
     [ "_setProjectionMatrix", "class_ogre_1_1_g_l3_plus_render_system.html#ab72ff6224be9aebbc957b49919edf271", null ],
@@ -134,6 +132,8 @@ var class_ogre_1_1_g_l3_plus_render_system =
     [ "_setTextureBlendMode", "class_ogre_1_1_g_l3_plus_render_system.html#ac3e1b9a4c8499932b010d531b21e20ac", null ],
     [ "_setTextureUnitFiltering", "class_ogre_1_1_g_l3_plus_render_system.html#adbc64c669661f87ee2f8db8dd18a0fe5", null ],
     [ "_setTextureMatrix", "class_ogre_1_1_g_l3_plus_render_system.html#a6512839a2f001e463c0d46e07993192c", null ],
+    [ "setColourBlendState", "class_ogre_1_1_g_l3_plus_render_system.html#a46abac034b2217b91ae66b334e1ca42f", null ],
+    [ "_setSceneBlending", "class_ogre_1_1_g_l3_plus_render_system.html#afd5d05521034b0e901ba0ff7f653d1e7", null ],
     [ "_setTextureProjectionRelativeTo", "class_ogre_1_1_g_l3_plus_render_system.html#a91e7ee7dd1f244ffa9a0681efb6fae6c", null ],
     [ "_cleanupDepthBuffers", "class_ogre_1_1_g_l3_plus_render_system.html#a568dd8e5d75fc7eef649dda6d14d447d", null ],
     [ "_pauseFrame", "class_ogre_1_1_g_l3_plus_render_system.html#a9893de6903d77fe231da1135f5ee00db", null ],
