@@ -68,6 +68,7 @@ var class_ogre_1_1_g_l_render_system_common =
     [ "_setViewMatrix", "class_ogre_1_1_g_l_render_system_common.html#a1a7926fe7b59598fdb7b7e743efdae6c", null ],
     [ "_setProjectionMatrix", "class_ogre_1_1_g_l_render_system_common.html#ab72ff6224be9aebbc957b49919edf271", null ],
     [ "_setTextureUnitSettings", "class_ogre_1_1_g_l_render_system_common.html#ad504623eff0678f9f79b075f32673414", null ],
+    [ "_setSampler", "class_ogre_1_1_g_l_render_system_common.html#a7475c99df40ff3c2a7edf6a15ad6c460", null ],
     [ "_setBindingType", "class_ogre_1_1_g_l_render_system_common.html#ae197c344b0b2dce1739e3c566c280f8c", null ],
     [ "_disableTextureUnit", "class_ogre_1_1_g_l_render_system_common.html#a058d6805142fce7ec095a018447cbe33", null ],
     [ "_disableTextureUnitsFrom", "class_ogre_1_1_g_l_render_system_common.html#a68e0ecb23c3eba58b5aeb06d646ce4cd", null ],
@@ -85,11 +86,12 @@ var class_ogre_1_1_g_l_render_system_common =
     [ "_setTextureUnitCompareEnabled", "class_ogre_1_1_g_l_render_system_common.html#ad935b875abb352407242ea15bf92324b", null ],
     [ "_setTextureUnitCompareFunction", "class_ogre_1_1_g_l_render_system_common.html#a58be1a70bee1dcaa9e177e02b64b5885", null ],
     [ "_setTextureLayerAnisotropy", "class_ogre_1_1_g_l_render_system_common.html#aba523c0055a520d25fd7f08683e3c98e", null ],
-    [ "_setTextureAddressingMode", "class_ogre_1_1_g_l_render_system_common.html#a67b3f87c6ef12e5b24812eeb61635308", null ],
+    [ "_setTextureAddressingMode", "class_ogre_1_1_g_l_render_system_common.html#a1ed6aa9eadc930c59d2e6ac9015a6f14", null ],
     [ "_setTextureBorderColour", "class_ogre_1_1_g_l_render_system_common.html#ad771e198662c3316b13b2c86caff6f2e", null ],
     [ "_setTextureMipmapBias", "class_ogre_1_1_g_l_render_system_common.html#a99f92ad60c2da38c7dfcf3f429e65572", null ],
     [ "_setTextureMatrix", "class_ogre_1_1_g_l_render_system_common.html#a6512839a2f001e463c0d46e07993192c", null ],
-    [ "_setSceneBlending", "class_ogre_1_1_g_l_render_system_common.html#a9835950f83b9f9a9da05da425033c25e", null ],
+    [ "setColourBlendState", "class_ogre_1_1_g_l_render_system_common.html#a46abac034b2217b91ae66b334e1ca42f", null ],
+    [ "_setSceneBlending", "class_ogre_1_1_g_l_render_system_common.html#afd5d05521034b0e901ba0ff7f653d1e7", null ],
     [ "_setSeparateSceneBlending", "class_ogre_1_1_g_l_render_system_common.html#a00289b710ac8817153afd820827cd49a", null ],
     [ "_setAlphaRejectSettings", "class_ogre_1_1_g_l_render_system_common.html#a6a3facdc0f1b8c68af65598fd3fd34aa", null ],
     [ "_setTextureProjectionRelativeTo", "class_ogre_1_1_g_l_render_system_common.html#a91e7ee7dd1f244ffa9a0681efb6fae6c", null ],
@@ -120,11 +122,12 @@ var class_ogre_1_1_g_l_render_system_common =
     [ "setStencilBufferParams", "class_ogre_1_1_g_l_render_system_common.html#ae921e432a4c8123b1571982ed8900105", null ],
     [ "setNormaliseNormals", "class_ogre_1_1_g_l_render_system_common.html#a07859d3fde38c9b447d0801d79eb3bee", null ],
     [ "_render", "class_ogre_1_1_g_l_render_system_common.html#a64961cc3cdc616beb264c51d532c94c1", null ],
+    [ "_dispatchCompute", "class_ogre_1_1_g_l_render_system_common.html#a2c59487ad841c47a24b94d242b3a01af", null ],
     [ "getCapabilities", "class_ogre_1_1_g_l_render_system_common.html#ac4b66fe49129476323eba9bdca672a36", null ],
     [ "getDriverVersion", "class_ogre_1_1_g_l_render_system_common.html#a884fc9154ef8f4c1d17a7920460d81f2", null ],
     [ "_getDefaultViewportMaterialScheme", "class_ogre_1_1_g_l_render_system_common.html#aeb912c6c0bfc8bd8d0670448e0a5370a", null ],
     [ "bindGpuProgram", "class_ogre_1_1_g_l_render_system_common.html#ae8144a770f5bbe9390928abf24d37b16", null ],
-    [ "bindGpuProgramParameters", "class_ogre_1_1_g_l_render_system_common.html#a6919b64b3dc06d81dd2484f1059449d6", null ],
+    [ "bindGpuProgramParameters", "class_ogre_1_1_g_l_render_system_common.html#a19fdcb9443c1786787c09990a71ecd4f", null ],
     [ "bindGpuProgramPassIterationParameters", "class_ogre_1_1_g_l_render_system_common.html#ae1f7904fe5f6a1d39fe8a0621dab7509", null ],
     [ "unbindGpuProgram", "class_ogre_1_1_g_l_render_system_common.html#a045731ce43fe553744e69664d5d648b3", null ],
     [ "isGpuProgramBound", "class_ogre_1_1_g_l_render_system_common.html#a6077b61e7511ae56887c67498f5282a1", null ],
