@@ -1,11 +1,11 @@
 var class_ogre_1_1_r_t_shader_1_1_per_pixel_lighting =
 [
-    [ "PerPixelLighting", "class_ogre_1_1_r_t_shader_1_1_per_pixel_lighting.html#a51fedef7333037ff96cd9bc730cf174b", null ],
     [ "getType", "class_ogre_1_1_r_t_shader_1_1_per_pixel_lighting.html#a8b3626c7011632d6393f91d00e56fb7b", null ],
-    [ "getExecutionOrder", "class_ogre_1_1_r_t_shader_1_1_per_pixel_lighting.html#ac507ca415866e33ea85171bf565ea328", null ],
-    [ "updateGpuProgramsParams", "class_ogre_1_1_r_t_shader_1_1_per_pixel_lighting.html#abe2eddda64829432cbef5b020f7b01a5", null ],
-    [ "copyFrom", "class_ogre_1_1_r_t_shader_1_1_per_pixel_lighting.html#a2767ee76fad984f070b23d5d6decf54a", null ],
-    [ "preAddToRenderState", "class_ogre_1_1_r_t_shader_1_1_per_pixel_lighting.html#aa941aaf1327f9cec725e7de4c4871e16", null ],
+    [ "getExecutionOrder", "class_ogre_1_1_r_t_shader_1_1_per_pixel_lighting.html#a11bddfecc7052cf235f1a0321600b7c5", null ],
+    [ "updateGpuProgramsParams", "class_ogre_1_1_r_t_shader_1_1_per_pixel_lighting.html#a0e670dbfea49dc92dde893ca175d722e", null ],
+    [ "copyFrom", "class_ogre_1_1_r_t_shader_1_1_per_pixel_lighting.html#a84fa2416b04dae927f9acbe3aff18615", null ],
+    [ "preAddToRenderState", "class_ogre_1_1_r_t_shader_1_1_per_pixel_lighting.html#a58a11d4b0389a5bd595a092244bb8bdf", null ],
+    [ "setNormaliseEnabled", "class_ogre_1_1_r_t_shader_1_1_per_pixel_lighting.html#a98d8a4dd67c07e121c9e11fb72bf2079", null ],
     [ "createCpuSubPrograms", "class_ogre_1_1_r_t_shader_1_1_per_pixel_lighting.html#a4b43c261946926ebbc6456deccc6697a", null ],
     [ "getAccessor", "class_ogre_1_1_r_t_shader_1_1_per_pixel_lighting.html#aa73560a3f1b9117cb8b438867848c255", null ],
     [ "getAccessor", "class_ogre_1_1_r_t_shader_1_1_per_pixel_lighting.html#a9d34ec312d5b8a627be41da5b57382eb", null ],
