@@ -1,7 +1,8 @@
 var class_ogre_1_1_texture_unit_state =
 [
     [ "TextureEffect", "struct_ogre_1_1_texture_unit_state_1_1_texture_effect.html", "struct_ogre_1_1_texture_unit_state_1_1_texture_effect" ],
-    [ "UVWAddressingMode", "struct_ogre_1_1_texture_unit_state_1_1_u_v_w_addressing_mode.html", "struct_ogre_1_1_texture_unit_state_1_1_u_v_w_addressing_mode" ],
+    [ "TextureAddressingMode", "class_ogre_1_1_texture_unit_state.html#a162e712b66645d1faa9f11c270ad2794", null ],
+    [ "UVWAddressingMode", "class_ogre_1_1_texture_unit_state.html#ac60c0a3508a6ff12f8dac4668df9dd79", null ],
     [ "EffectMap", "class_ogre_1_1_texture_unit_state.html#a76b0d087ff12f806b0bd5e8b97d466bf", null ],
     [ "TextureEffectType", "class_ogre_1_1_texture_unit_state.html#a717b14961a636b3a18b8ab3dcef61626", [
       [ "ET_ENVIRONMENT_MAP", "class_ogre_1_1_texture_unit_state.html#a717b14961a636b3a18b8ab3dcef61626a2f0676d96ba378e32c3087fff9b7e73e", null ],
@@ -25,13 +26,6 @@ var class_ogre_1_1_texture_unit_state =
       [ "TT_SCALE_V", "class_ogre_1_1_texture_unit_state.html#a942a1ce66d0909d29ed09c98e9e6d82da6e85f00afb893c2bace9a394e5ac9f95", null ],
       [ "TT_ROTATE", "class_ogre_1_1_texture_unit_state.html#a942a1ce66d0909d29ed09c98e9e6d82daecf829c4f898451d496f56e774e0eacf", null ]
     ] ],
-    [ "TextureAddressingMode", "class_ogre_1_1_texture_unit_state.html#a47c5a9f4fc08159b99bdc51103bcf852", [
-      [ "TAM_WRAP", "class_ogre_1_1_texture_unit_state.html#a47c5a9f4fc08159b99bdc51103bcf852a9421f7d4fa30994823c3a011ca693a8d", null ],
-      [ "TAM_MIRROR", "class_ogre_1_1_texture_unit_state.html#a47c5a9f4fc08159b99bdc51103bcf852a2f132fdcdbeea6b30d8cb84f2fc50239", null ],
-      [ "TAM_CLAMP", "class_ogre_1_1_texture_unit_state.html#a47c5a9f4fc08159b99bdc51103bcf852a01e4d16b7bc55a9718db2e5a3bf22378", null ],
-      [ "TAM_BORDER", "class_ogre_1_1_texture_unit_state.html#a47c5a9f4fc08159b99bdc51103bcf852a4fe25e95df059a8d54bc3d9cf57986a0", null ],
-      [ "TAM_UNKNOWN", "class_ogre_1_1_texture_unit_state.html#a47c5a9f4fc08159b99bdc51103bcf852ac9a0e6e319ed6487447cbc799550066e", null ]
-    ] ],
     [ "TextureCubeFace", "class_ogre_1_1_texture_unit_state.html#a2584766311cf6d0eaada7be28c287cc3", [
       [ "CUBE_FRONT", "class_ogre_1_1_texture_unit_state.html#a2584766311cf6d0eaada7be28c287cc3aa9d74ce7d0576d0dda5b5046a6434529", null ],
       [ "CUBE_BACK", "class_ogre_1_1_texture_unit_state.html#a2584766311cf6d0eaada7be28c287cc3a4459a171ecd0fe942dc5b5f8e517ecb2", null ],
@@ -107,12 +101,26 @@ var class_ogre_1_1_texture_unit_state =
     [ "setTextureScale", "class_ogre_1_1_texture_unit_state.html#aa5be6f7e13179f692c9af7c494c703cf", null ],
     [ "setTextureRotate", "class_ogre_1_1_texture_unit_state.html#a9239845b4de453c450e40f2c5f46cc8d", null ],
     [ "getTextureRotate", "class_ogre_1_1_texture_unit_state.html#a35f96567f246a00d967afcafccf242eb", null ],
-    [ "getTextureAddressingMode", "class_ogre_1_1_texture_unit_state.html#adb1a4e022683d76dece058279be1c5d0", null ],
-    [ "setTextureAddressingMode", "class_ogre_1_1_texture_unit_state.html#ac6116d92e9a3978aa367496c8b7bae5b", null ],
-    [ "setTextureAddressingMode", "class_ogre_1_1_texture_unit_state.html#a23a5f83043eeaf14c41e9930b91eeb09", null ],
-    [ "setTextureAddressingMode", "class_ogre_1_1_texture_unit_state.html#a8de35701b96f52764d292c580aa345fb", null ],
+    [ "getSampler", "class_ogre_1_1_texture_unit_state.html#aa88ea41c2ca613564f61c4b0d8b24203", null ],
+    [ "setSampler", "class_ogre_1_1_texture_unit_state.html#a2b3791c291aef832a03eb4582d71ed33", null ],
+    [ "getTextureAddressingMode", "class_ogre_1_1_texture_unit_state.html#ad25d04ad14d562c9e55d18da5695c898", null ],
+    [ "setTextureAddressingMode", "class_ogre_1_1_texture_unit_state.html#a06aef1d348eb56c1289c5791013bb1f7", null ],
+    [ "setTextureAddressingMode", "class_ogre_1_1_texture_unit_state.html#af8ab090b0fee62a2a330d07161a2d10c", null ],
+    [ "setTextureAddressingMode", "class_ogre_1_1_texture_unit_state.html#a5a54ece0b8cfb20f6dcddbd68813be43", null ],
     [ "setTextureBorderColour", "class_ogre_1_1_texture_unit_state.html#a4685adfbadf451fd318b3ea900abfca2", null ],
-    [ "getTextureBorderColour", "class_ogre_1_1_texture_unit_state.html#a98a26b14bc7315232b195c98d30cb7b2", null ],
+    [ "getTextureBorderColour", "class_ogre_1_1_texture_unit_state.html#a018bb274b11ff191a3502e2222fb9809", null ],
+    [ "setTextureFiltering", "class_ogre_1_1_texture_unit_state.html#a30757c168b734902d03720e3f36c27d4", null ],
+    [ "setTextureFiltering", "class_ogre_1_1_texture_unit_state.html#a363c69770217425598c716430abd159a", null ],
+    [ "setTextureFiltering", "class_ogre_1_1_texture_unit_state.html#afccaca77406c883c5bfe440b7ed3c3e4", null ],
+    [ "getTextureFiltering", "class_ogre_1_1_texture_unit_state.html#a41bef78e56a3b2071825f574070beed2", null ],
+    [ "setTextureCompareEnabled", "class_ogre_1_1_texture_unit_state.html#aa2f3464e36c93cca9bafefa4591433f3", null ],
+    [ "getTextureCompareEnabled", "class_ogre_1_1_texture_unit_state.html#ac026c759650a1d3d1e340b1b6a0d4425", null ],
+    [ "setTextureCompareFunction", "class_ogre_1_1_texture_unit_state.html#a453e725f0367bc8bae273d4d3f990d26", null ],
+    [ "getTextureCompareFunction", "class_ogre_1_1_texture_unit_state.html#a2da1174c8d8a33eeae1bfc1ee9ba67ef", null ],
+    [ "setTextureAnisotropy", "class_ogre_1_1_texture_unit_state.html#abb2bc03bc72f2098e37c4240f637c5e5", null ],
+    [ "getTextureAnisotropy", "class_ogre_1_1_texture_unit_state.html#ae0641061570bb6b02f2bc15f6fc76ba2", null ],
+    [ "setTextureMipmapBias", "class_ogre_1_1_texture_unit_state.html#acfe54cc0ec2c1247a90094d004d77db1", null ],
+    [ "getTextureMipmapBias", "class_ogre_1_1_texture_unit_state.html#a5c9a53ddea4dbdd68c1c42579ddc7fe8", null ],
     [ "setColourOperationEx", "class_ogre_1_1_texture_unit_state.html#a5f3994ce2f61c6c6fee6fe8f89c9e369", null ],
     [ "setColourOperation", "class_ogre_1_1_texture_unit_state.html#aa47f44936c3090c97d8b4179333a208b", null ],
     [ "setColourOpMultipassFallback", "class_ogre_1_1_texture_unit_state.html#a1c4dcca2a0d343dc6660b9071cd4c79f", null ],
@@ -135,19 +143,7 @@ var class_ogre_1_1_texture_unit_state =
     [ "retryTextureLoad", "class_ogre_1_1_texture_unit_state.html#a35ba5dfc7d336a92a1a3eccd260293eb", null ],
     [ "getEffects", "class_ogre_1_1_texture_unit_state.html#a8a92d3d54786e91d93c7ad95b1d93c74", null ],
     [ "getAnimationDuration", "class_ogre_1_1_texture_unit_state.html#a25b38aa2157538c8de784f46ab5442ac", null ],
-    [ "setTextureFiltering", "class_ogre_1_1_texture_unit_state.html#a30757c168b734902d03720e3f36c27d4", null ],
-    [ "setTextureFiltering", "class_ogre_1_1_texture_unit_state.html#a363c69770217425598c716430abd159a", null ],
-    [ "setTextureFiltering", "class_ogre_1_1_texture_unit_state.html#afccaca77406c883c5bfe440b7ed3c3e4", null ],
-    [ "getTextureFiltering", "class_ogre_1_1_texture_unit_state.html#ad09c689a1e700047d203c27ab5510601", null ],
     [ "isDefaultFiltering", "class_ogre_1_1_texture_unit_state.html#a5bb9b54d2869c429591b36f64d4361c5", null ],
-    [ "setTextureCompareEnabled", "class_ogre_1_1_texture_unit_state.html#aa2f3464e36c93cca9bafefa4591433f3", null ],
-    [ "getTextureCompareEnabled", "class_ogre_1_1_texture_unit_state.html#ac026c759650a1d3d1e340b1b6a0d4425", null ],
-    [ "setTextureCompareFunction", "class_ogre_1_1_texture_unit_state.html#a453e725f0367bc8bae273d4d3f990d26", null ],
-    [ "getTextureCompareFunction", "class_ogre_1_1_texture_unit_state.html#a2da1174c8d8a33eeae1bfc1ee9ba67ef", null ],
-    [ "setTextureAnisotropy", "class_ogre_1_1_texture_unit_state.html#abb2bc03bc72f2098e37c4240f637c5e5", null ],
-    [ "getTextureAnisotropy", "class_ogre_1_1_texture_unit_state.html#ae0641061570bb6b02f2bc15f6fc76ba2", null ],
-    [ "setTextureMipmapBias", "class_ogre_1_1_texture_unit_state.html#acfe54cc0ec2c1247a90094d004d77db1", null ],
-    [ "getTextureMipmapBias", "class_ogre_1_1_texture_unit_state.html#a5c9a53ddea4dbdd68c1c42579ddc7fe8", null ],
     [ "setCompositorReference", "class_ogre_1_1_texture_unit_state.html#a0073a4465cc92944252d69b2671ea97d", null ],
     [ "getReferencedCompositorName", "class_ogre_1_1_texture_unit_state.html#afb47cfd7dc8d6e24dee936a6645ae316", null ],
     [ "getReferencedTextureName", "class_ogre_1_1_texture_unit_state.html#a5dbc572cbcd0354b62b08009592936a4", null ],
@@ -172,5 +168,11 @@ var class_ogre_1_1_texture_unit_state =
     [ "_setTexturePtr", "class_ogre_1_1_texture_unit_state.html#a6236e0e398c153980ff06f13e58a667b", null ],
     [ "calculateSize", "class_ogre_1_1_texture_unit_state.html#a2c9d0e4e1188041093e8b2c95dc07359", null ],
     [ "_getAnimController", "class_ogre_1_1_texture_unit_state.html#aac051a780fa7e8ccd891c71d5dfb001b", null ],
-    [ "RenderSystem", "class_ogre_1_1_texture_unit_state.html#a06b786d8e0847dfe9cc15e1dea308fcd", null ]
+    [ "_getLocalSampler", "class_ogre_1_1_texture_unit_state.html#a983cd4d8de66d003dc173f5738fab245", null ],
+    [ "RenderSystem", "class_ogre_1_1_texture_unit_state.html#a06b786d8e0847dfe9cc15e1dea308fcd", null ],
+    [ "TAM_WRAP", "class_ogre_1_1_texture_unit_state.html#a9d12f77b02eacd0da7dcec2ac654c256", null ],
+    [ "TAM_MIRROR", "class_ogre_1_1_texture_unit_state.html#a7f29d334eabef6ca15cc1e3a1d594467", null ],
+    [ "TAM_CLAMP", "class_ogre_1_1_texture_unit_state.html#aaa593803cf70c8a67f24d4b74ad2ad77", null ],
+    [ "TAM_BORDER", "class_ogre_1_1_texture_unit_state.html#acced150b0dc0d1d64b0802dbe4cf7db1", null ],
+    [ "TAM_UNKNOWN", "class_ogre_1_1_texture_unit_state.html#a27d31e5a5ad06d018986d13b12fd4b41", null ]
 ];
\ No newline at end of file
