@@ -37,10 +37,10 @@ var group___direct3_d11 =
       [ "_getBoundTessellationDomainProgram", "class_ogre_1_1_d3_d11_render_system.html#a23e8a162bcba66cb73a11840ae8fd372", null ],
       [ "_getBoundComputeProgram", "class_ogre_1_1_d3_d11_render_system.html#a9d3ba8b196457507a188fdfc0345da5d", null ],
       [ "_setTexture", "class_ogre_1_1_d3_d11_render_system.html#afb472cf1a180d18cf28258ab7b1aa700", null ],
-      [ "_setTextureAddressingMode", "class_ogre_1_1_d3_d11_render_system.html#aa7edade016a9e9cdf5eb454e39861e8f", null ],
+      [ "_setSampler", "class_ogre_1_1_d3_d11_render_system.html#a49d1e995e5b6d9088ded6a4c74a3f51e", null ],
+      [ "_setTextureAddressingMode", "class_ogre_1_1_d3_d11_render_system.html#a36d2adc20d779463e6ad37d1088c7e49", null ],
       [ "_setTextureBorderColour", "class_ogre_1_1_d3_d11_render_system.html#abbfd42d04ce1b977676821f3ab0e8539", null ],
       [ "_setTextureMipmapBias", "class_ogre_1_1_d3_d11_render_system.html#a460969a00700c596d11a5d169975ea5b", null ],
-      [ "_setSceneBlending", "class_ogre_1_1_d3_d11_render_system.html#a4b4f94df5b4d643954696aaf9b437841", null ],
       [ "_setSeparateSceneBlending", "class_ogre_1_1_d3_d11_render_system.html#a5bb10398eda8986d56fbc24fd7064176", null ],
       [ "_setAlphaRejectSettings", "class_ogre_1_1_d3_d11_render_system.html#aa71e8588f6870ec5b4e0a29153436c5e", null ],
       [ "_setViewport", "class_ogre_1_1_d3_d11_render_system.html#a0ee4de38af33586f78359947e28dd733", null ],
@@ -68,10 +68,11 @@ var group___direct3_d11 =
       [ "setVertexDeclaration", "class_ogre_1_1_d3_d11_render_system.html#ad14beb0abdda7765c3157e6bf78d06dc", null ],
       [ "setVertexBufferBinding", "class_ogre_1_1_d3_d11_render_system.html#a0638f394c2b2a1b3035af3da58951317", null ],
       [ "_renderUsingReadBackAsTexture", "class_ogre_1_1_d3_d11_render_system.html#ac821da8701002a90b921cb437e07c8e7", null ],
+      [ "_dispatchCompute", "class_ogre_1_1_d3_d11_render_system.html#a03735de271e0dd86723d0acad345d8c7", null ],
       [ "_render", "class_ogre_1_1_d3_d11_render_system.html#a07e5f15791ec7f42fbf9348a89920176", null ],
       [ "bindGpuProgram", "class_ogre_1_1_d3_d11_render_system.html#a0b5fc5b6684ff7904e4e288c74f96694", null ],
       [ "unbindGpuProgram", "class_ogre_1_1_d3_d11_render_system.html#a493bc503eae3480c3e6e77d58cd1fca3", null ],
-      [ "bindGpuProgramParameters", "class_ogre_1_1_d3_d11_render_system.html#ab53388c0e1d47e43ed48b77595054fe6", null ],
+      [ "bindGpuProgramParameters", "class_ogre_1_1_d3_d11_render_system.html#a210ce555d89543fe39360659b4db410a", null ],
       [ "bindGpuProgramPassIterationParameters", "class_ogre_1_1_d3_d11_render_system.html#ad02c0c838045830a7fdea3557635bf34", null ],
       [ "setScissorTest", "class_ogre_1_1_d3_d11_render_system.html#a4ded234045f9ed9a1258dfcc858def02", null ],
       [ "clearFrameBuffer", "class_ogre_1_1_d3_d11_render_system.html#aed61ea88e44867a175794152a3c40507", null ],
@@ -85,7 +86,6 @@ var group___direct3_d11 =
       [ "preExtraThreadsStarted", "class_ogre_1_1_d3_d11_render_system.html#a2f7492cd8867ab290b77b0e7d7000fc6", null ],
       [ "postExtraThreadsStarted", "class_ogre_1_1_d3_d11_render_system.html#ad4377ca9759ef65902a521747bb4a9fb", null ],
       [ "_setRenderTarget", "class_ogre_1_1_d3_d11_render_system.html#ac5d750346fad8fb6e9406adbab3dcea1", null ],
-      [ "_checkTextureFilteringSupported", "class_ogre_1_1_d3_d11_render_system.html#af333c71b58159a046b79a7f0d5bb4955", null ],
       [ "determineFSAASettings", "class_ogre_1_1_d3_d11_render_system.html#a46f4c0a27d96185210ca7de1018af78e", null ],
       [ "getDisplayMonitorCount", "class_ogre_1_1_d3_d11_render_system.html#a8d9a996201d2fdbd5db0b69c5f70c5a4", null ],
       [ "hasAnisotropicMipMapFilter", "class_ogre_1_1_d3_d11_render_system.html#a193ab39d966862d2d10afde502fb356a", null ],
@@ -140,6 +140,8 @@ var group___direct3_d11 =
       [ "_setTextureBlendMode", "class_ogre_1_1_d3_d11_render_system.html#ac3e1b9a4c8499932b010d531b21e20ac", null ],
       [ "_setTextureUnitFiltering", "class_ogre_1_1_d3_d11_render_system.html#adbc64c669661f87ee2f8db8dd18a0fe5", null ],
       [ "_setTextureMatrix", "class_ogre_1_1_d3_d11_render_system.html#a6512839a2f001e463c0d46e07993192c", null ],
+      [ "setColourBlendState", "class_ogre_1_1_d3_d11_render_system.html#a46abac034b2217b91ae66b334e1ca42f", null ],
+      [ "_setSceneBlending", "class_ogre_1_1_d3_d11_render_system.html#afd5d05521034b0e901ba0ff7f653d1e7", null ],
       [ "_setTextureProjectionRelativeTo", "class_ogre_1_1_d3_d11_render_system.html#a91e7ee7dd1f244ffa9a0681efb6fae6c", null ],
       [ "_cleanupDepthBuffers", "class_ogre_1_1_d3_d11_render_system.html#a568dd8e5d75fc7eef649dda6d14d447d", null ],
       [ "_pauseFrame", "class_ogre_1_1_d3_d11_render_system.html#a9893de6903d77fe231da1135f5ee00db", null ],
