@@ -42,16 +42,16 @@ var group___direct3_d9 =
       [ "_setPointSpritesEnabled", "class_ogre_1_1_d3_d9_render_system.html#a8087fcbe4777015df90f574b61fdfa67", null ],
       [ "_setPointParameters", "class_ogre_1_1_d3_d9_render_system.html#a82e47ef0c94c5f7d87199151ca811ff5", null ],
       [ "_setTexture", "class_ogre_1_1_d3_d9_render_system.html#acc8659aa8149972ca8c1175199110d7d", null ],
+      [ "_setSampler", "class_ogre_1_1_d3_d9_render_system.html#a7319688813f35bb96dadbf22075b900b", null ],
       [ "_setVertexTexture", "class_ogre_1_1_d3_d9_render_system.html#a349ff5d559210fe9d1b733add4ddd350", null ],
       [ "_disableTextureUnit", "class_ogre_1_1_d3_d9_render_system.html#a0f35bab2afa97804cf8323d0205cd0c5", null ],
       [ "_setTextureCoordSet", "class_ogre_1_1_d3_d9_render_system.html#acfaf7c8ec448362a48a5ab1a026909dd", null ],
       [ "_setTextureCoordCalculation", "class_ogre_1_1_d3_d9_render_system.html#aa54b0c2ad942d41897c0b8a0a8e44166", null ],
       [ "_setTextureBlendMode", "class_ogre_1_1_d3_d9_render_system.html#ad0ce107404650d8b2ba8fcfba1448b60", null ],
-      [ "_setTextureAddressingMode", "class_ogre_1_1_d3_d9_render_system.html#a52779ba1276abbe4b5da48c2018b2061", null ],
+      [ "_setTextureAddressingMode", "class_ogre_1_1_d3_d9_render_system.html#a6d7e92fba6760452e19d7a414ccc8672", null ],
       [ "_setTextureBorderColour", "class_ogre_1_1_d3_d9_render_system.html#a8f2284cd8c24afda7c14f9570f400698", null ],
       [ "_setTextureMipmapBias", "class_ogre_1_1_d3_d9_render_system.html#a4f573f2b71583712a1dac603f6917f98", null ],
       [ "_setTextureMatrix", "class_ogre_1_1_d3_d9_render_system.html#aaf51e7092d88a781953f3d0d0048eb52", null ],
-      [ "_setSceneBlending", "class_ogre_1_1_d3_d9_render_system.html#aae2238e6e28dc099ed8cafad1b58b8d1", null ],
       [ "_setSeparateSceneBlending", "class_ogre_1_1_d3_d9_render_system.html#aebfca89852cb822a7dcfe3aa5288999f", null ],
       [ "_setAlphaRejectSettings", "class_ogre_1_1_d3_d9_render_system.html#ab63c18908e608834b601298afd2da197", null ],
       [ "_setViewport", "class_ogre_1_1_d3_d9_render_system.html#a85ad53d4f860030b319ce0420f4ece2a", null ],
@@ -84,7 +84,7 @@ var group___direct3_d9 =
       [ "_render", "class_ogre_1_1_d3_d9_render_system.html#ac95209c361f6d09fb6e0af0f6d4b4107", null ],
       [ "bindGpuProgram", "class_ogre_1_1_d3_d9_render_system.html#a82c436739e35880bf9a03d3296b93e4d", null ],
       [ "unbindGpuProgram", "class_ogre_1_1_d3_d9_render_system.html#a08255da85acf7431528d739c77d37ec3", null ],
-      [ "bindGpuProgramParameters", "class_ogre_1_1_d3_d9_render_system.html#a2d49ad76497b871e32bf18b6fd2edf5a", null ],
+      [ "bindGpuProgramParameters", "class_ogre_1_1_d3_d9_render_system.html#ad80a6a285980da1c47bebb4946596039", null ],
       [ "bindGpuProgramPassIterationParameters", "class_ogre_1_1_d3_d9_render_system.html#a89794d945fa06756b8fabab0aa400981", null ],
       [ "setScissorTest", "class_ogre_1_1_d3_d9_render_system.html#ada9466da79cf86fde16473cc8bf2c728", null ],
       [ "clearFrameBuffer", "class_ogre_1_1_d3_d9_render_system.html#a746af1925b9e07bfc96075b192c19333", null ],
@@ -121,6 +121,7 @@ var group___direct3_d9 =
       [ "getMultiheadUse", "class_ogre_1_1_d3_d9_render_system.html#a7f5e2beb4bd0d894ee99c6468ba20ee7", null ],
       [ "setDrawBuffer", "class_ogre_1_1_d3_d9_render_system.html#a869123f35563093de0f4fe68321b9b4b", null ],
       [ "createStereoDriver", "class_ogre_1_1_d3_d9_render_system.html#a296a4b8cb73c61dced451b6e23e95919", null ],
+      [ "_cleanupDepthBuffers", "class_ogre_1_1_d3_d9_render_system.html#a568dd8e5d75fc7eef649dda6d14d447d", null ],
       [ "getConfigOptions", "class_ogre_1_1_d3_d9_render_system.html#a4415ece805ed62ee16c8343c96766231", null ],
       [ "destroyHardwareOcclusionQuery", "class_ogre_1_1_d3_d9_render_system.html#ac4c60bf4c5d4347fd2b9346a90545e2b", null ],
       [ "getMutableCapabilities", "class_ogre_1_1_d3_d9_render_system.html#ab0aa0cedf1898f8cc70e290703b428c7", null ],
@@ -146,6 +147,8 @@ var group___direct3_d9 =
       [ "_disableTextureUnitsFrom", "class_ogre_1_1_d3_d9_render_system.html#a68e0ecb23c3eba58b5aeb06d646ce4cd", null ],
       [ "_setLineWidth", "class_ogre_1_1_d3_d9_render_system.html#a40f99785cb4f728763712169cec19f29", null ],
       [ "_setTextureUnitFiltering", "class_ogre_1_1_d3_d9_render_system.html#adbc64c669661f87ee2f8db8dd18a0fe5", null ],
+      [ "setColourBlendState", "class_ogre_1_1_d3_d9_render_system.html#a46abac034b2217b91ae66b334e1ca42f", null ],
+      [ "_setSceneBlending", "class_ogre_1_1_d3_d9_render_system.html#afd5d05521034b0e901ba0ff7f653d1e7", null ],
       [ "_setTextureProjectionRelativeTo", "class_ogre_1_1_d3_d9_render_system.html#a91e7ee7dd1f244ffa9a0681efb6fae6c", null ],
       [ "_cleanupDepthBuffers", "class_ogre_1_1_d3_d9_render_system.html#a568dd8e5d75fc7eef649dda6d14d447d", null ],
       [ "_getViewport", "class_ogre_1_1_d3_d9_render_system.html#aa0cf9dc2df0748f3076c5f8f1f8064db", null ],
@@ -155,6 +158,7 @@ var group___direct3_d9 =
       [ "_getBatchCount", "class_ogre_1_1_d3_d9_render_system.html#ac419ed21d6b2427b142a81fbfcde2be3", null ],
       [ "_getVertexCount", "class_ogre_1_1_d3_d9_render_system.html#a46c964471b448ada768b766aca428b91", null ],
       [ "convertColourValue", "class_ogre_1_1_d3_d9_render_system.html#a324d50e3fc58177d8d9f05c5cfc7e3e8", null ],
+      [ "_dispatchCompute", "class_ogre_1_1_d3_d9_render_system.html#a2c59487ad841c47a24b94d242b3a01af", null ],
       [ "getCapabilities", "class_ogre_1_1_d3_d9_render_system.html#ac4b66fe49129476323eba9bdca672a36", null ],
       [ "getDriverVersion", "class_ogre_1_1_d3_d9_render_system.html#a884fc9154ef8f4c1d17a7920460d81f2", null ],
       [ "_getDefaultViewportMaterialScheme", "class_ogre_1_1_d3_d9_render_system.html#aeb912c6c0bfc8bd8d0670448e0a5370a", null ],
