@@ -31,17 +31,15 @@ var group___g_l =
       [ "_setLineWidth", "class_ogre_1_1_g_l_render_system.html#a45218b92432521f0ba4822f683c0f46d", null ],
       [ "_setPointSpritesEnabled", "class_ogre_1_1_g_l_render_system.html#a1e6d7387880c747e089d9eb45c2afeb7", null ],
       [ "_setTexture", "class_ogre_1_1_g_l_render_system.html#af386371d383841ee4202352a5d2ca1c6", null ],
+      [ "_setSampler", "class_ogre_1_1_g_l_render_system.html#a1cf670f9a4b94f5b496eb604f576c570", null ],
       [ "_setTextureCoordSet", "class_ogre_1_1_g_l_render_system.html#a4ba1d55294de60fe8642528f00aa7c47", null ],
       [ "_setTextureCoordCalculation", "class_ogre_1_1_g_l_render_system.html#aac03f63c77f0728121db8bd8b3d36ccd", null ],
       [ "_setTextureBlendMode", "class_ogre_1_1_g_l_render_system.html#a533c3fcd317b3f8c4c9b872ec81e85c5", null ],
-      [ "_setTextureAddressingMode", "class_ogre_1_1_g_l_render_system.html#acedc9cf07c010f3579d1f92f4ca5d18b", null ],
+      [ "_setTextureAddressingMode", "class_ogre_1_1_g_l_render_system.html#a01a95aea1f8ae541834918f2993d0e5a", null ],
       [ "_setTextureBorderColour", "class_ogre_1_1_g_l_render_system.html#acf58133dea0e52a8e87fe298fc6bf288", null ],
       [ "_setTextureMipmapBias", "class_ogre_1_1_g_l_render_system.html#a1d53c10bd82bc8de155f6882fdd0c79b", null ],
       [ "_setTextureMatrix", "class_ogre_1_1_g_l_render_system.html#a9dc0ac6493242e225ed03ba0049a9ae3", null ],
-      [ "_setSceneBlending", "class_ogre_1_1_g_l_render_system.html#a5ecfdabe32251e80ef57bc594dba7506", null ],
       [ "_setSeparateSceneBlending", "class_ogre_1_1_g_l_render_system.html#a6f3c83cc74f963cdf80223abd4b0bbd6", null ],
-      [ "_setSceneBlendingOperation", "class_ogre_1_1_g_l_render_system.html#a673f7eb0b887a5d61d570651a8aa3829", null ],
-      [ "_setSeparateSceneBlendingOperation", "class_ogre_1_1_g_l_render_system.html#a708300fc5143c33ed39a32023f3be1e4", null ],
       [ "_setAlphaRejectSettings", "class_ogre_1_1_g_l_render_system.html#a0b00a68cbcfe3204d0827f0545097aee", null ],
       [ "_setViewport", "class_ogre_1_1_g_l_render_system.html#ad2cbeae78510938a2d77e08d011a1c59", null ],
       [ "_beginFrame", "class_ogre_1_1_g_l_render_system.html#a754fdf0325d4b90212b3992b4d265de8", null ],
@@ -66,7 +64,7 @@ var group___g_l =
       [ "_render", "class_ogre_1_1_g_l_render_system.html#ae864439ace42c4bf2ab645f8e2e86558", null ],
       [ "bindGpuProgram", "class_ogre_1_1_g_l_render_system.html#aac0ea19643a55921a6fd968bb698d7fb", null ],
       [ "unbindGpuProgram", "class_ogre_1_1_g_l_render_system.html#aac18158225e9fdd39e0853210e2bca57", null ],
-      [ "bindGpuProgramParameters", "class_ogre_1_1_g_l_render_system.html#abe7645864b1d97f1e5305da9bcfc67fc", null ],
+      [ "bindGpuProgramParameters", "class_ogre_1_1_g_l_render_system.html#a1ed03431073949af26a6ad6c9a9c30c5", null ],
       [ "bindGpuProgramPassIterationParameters", "class_ogre_1_1_g_l_render_system.html#af9e0875b43e73dcaebbbc4296114bb0f", null ],
       [ "setScissorTest", "class_ogre_1_1_g_l_render_system.html#ad48af2e46839e7a4c50a1315920c6f4a", null ],
       [ "clearFrameBuffer", "class_ogre_1_1_g_l_render_system.html#a54d191e0257488ac65b44015bcc35be3", null ],
@@ -136,6 +134,8 @@ var group___g_l =
       [ "_disableTextureUnitsFrom", "class_ogre_1_1_g_l_render_system.html#a68e0ecb23c3eba58b5aeb06d646ce4cd", null ],
       [ "_setVertexTexture", "class_ogre_1_1_g_l_render_system.html#af40bfb084b051d8433b0893921613ba7", null ],
       [ "_setTextureUnitFiltering", "class_ogre_1_1_g_l_render_system.html#adbc64c669661f87ee2f8db8dd18a0fe5", null ],
+      [ "setColourBlendState", "class_ogre_1_1_g_l_render_system.html#a46abac034b2217b91ae66b334e1ca42f", null ],
+      [ "_setSceneBlending", "class_ogre_1_1_g_l_render_system.html#afd5d05521034b0e901ba0ff7f653d1e7", null ],
       [ "_setTextureProjectionRelativeTo", "class_ogre_1_1_g_l_render_system.html#a91e7ee7dd1f244ffa9a0681efb6fae6c", null ],
       [ "_cleanupDepthBuffers", "class_ogre_1_1_g_l_render_system.html#a568dd8e5d75fc7eef649dda6d14d447d", null ],
       [ "_pauseFrame", "class_ogre_1_1_g_l_render_system.html#a9893de6903d77fe231da1135f5ee00db", null ],
@@ -147,6 +147,7 @@ var group___g_l =
       [ "_getBatchCount", "class_ogre_1_1_g_l_render_system.html#ac419ed21d6b2427b142a81fbfcde2be3", null ],
       [ "_getVertexCount", "class_ogre_1_1_g_l_render_system.html#a46c964471b448ada768b766aca428b91", null ],
       [ "convertColourValue", "class_ogre_1_1_g_l_render_system.html#a324d50e3fc58177d8d9f05c5cfc7e3e8", null ],
+      [ "_dispatchCompute", "class_ogre_1_1_g_l_render_system.html#a2c59487ad841c47a24b94d242b3a01af", null ],
       [ "getCapabilities", "class_ogre_1_1_g_l_render_system.html#ac4b66fe49129476323eba9bdca672a36", null ],
       [ "getDriverVersion", "class_ogre_1_1_g_l_render_system.html#a884fc9154ef8f4c1d17a7920460d81f2", null ],
       [ "_getDefaultViewportMaterialScheme", "class_ogre_1_1_g_l_render_system.html#aeb912c6c0bfc8bd8d0670448e0a5370a", null ],
