@@ -15,9 +15,9 @@ var group___g_l_e_s2 =
       [ "_getDepthStencilFormatFor", "group___g_l_e_s2.html#ga234e49f5469846344bd7ed4973d0b5f6", null ],
       [ "createMultiRenderTarget", "group___g_l_e_s2.html#ga485ebebda97e764bef335abadc04fb14", null ],
       [ "destroyRenderWindow", "group___g_l_e_s2.html#ga31201c00d107451d7f7ff264f3559a2e", null ],
-      [ "areFixedFunctionLightsInViewSpace", "group___g_l_e_s2.html#gae982beab16b67617dfe88fc6fdbede32", null ],
       [ "_setTexture", "group___g_l_e_s2.html#ga066f9dbe0f422cd350d22c563896e6c7", null ],
-      [ "_setTextureAddressingMode", "group___g_l_e_s2.html#gab35ff75c77786dd02c8df78cec83a638", null ],
+      [ "_setSampler", "group___g_l_e_s2.html#ga2a53c1abeeaaf7d7732571266b85d3bf", null ],
+      [ "_setTextureAddressingMode", "group___g_l_e_s2.html#ga9986214ed4d4bee60f62deef52659692", null ],
       [ "_setTextureBorderColour", "group___g_l_e_s2.html#ga8f7d75c7234f300c1d6fdb09d019a3bc", null ],
       [ "_setTextureMipmapBias", "group___g_l_e_s2.html#ga9120c932b874e1fb8645035bbf22b65e", null ],
       [ "_setLineWidth", "group___g_l_e_s2.html#ga55c3aaee65dee3249d3294a49d21e9d4", null ],
@@ -49,7 +49,6 @@ var group___g_l_e_s2 =
       [ "unregisterThread", "group___g_l_e_s2.html#gaa6bfad53622bb5f865871a3918bb4fac", null ],
       [ "preExtraThreadsStarted", "group___g_l_e_s2.html#ga8facb30ed47df20d9df6de77c23c5398", null ],
       [ "postExtraThreadsStarted", "group___g_l_e_s2.html#ga1767016ed55e3877d47464882aef9a27", null ],
-      [ "setClipPlanesImpl", "group___g_l_e_s2.html#ga2a7acd32e8329a1b59f40b7b7742dabf", null ],
       [ "_getStateCacheManager", "group___g_l_e_s2.html#gaa800af7ac51f670a3b8e4fc4ac320790", null ],
       [ "_createVao", "group___g_l_e_s2.html#ga22c282474176319fd19e77f343313c7e", null ],
       [ "_bindVao", "group___g_l_e_s2.html#ga098f0c566b7c08c3d368a7fdb24ddeee", null ],
@@ -64,14 +63,11 @@ var group___g_l_e_s2 =
       [ "convertStencilOp", "group___g_l_e_s2.html#gae96b47494abeb2761223b9408a37b2b9", null ],
       [ "bindGpuProgram", "group___g_l_e_s2.html#gad1b0cf3f7aea1a2f2bb3d8762500282f", null ],
       [ "unbindGpuProgram", "group___g_l_e_s2.html#ga564175c3cb628ac2deeea6d98d4e4bc0", null ],
-      [ "bindGpuProgramParameters", "group___g_l_e_s2.html#ga733ffc8e541d74e5cdbaff1ae59fb45b", null ],
+      [ "bindGpuProgramParameters", "group___g_l_e_s2.html#ga9c3c59236b71f033101d6d63f1e2af94", null ],
       [ "bindGpuProgramPassIterationParameters", "group___g_l_e_s2.html#ga9fe72776eaa2437f5a1ad7a2498de7cd", null ],
-      [ "_setSceneBlending", "group___g_l_e_s2.html#ga4ca1d78dff99ffe26c008c1a3a6ad330", null ],
       [ "_setSeparateSceneBlending", "group___g_l_e_s2.html#ga2ed07f074ae69826c8090cd8541b67a5", null ],
       [ "_setAlphaRejectSettings", "group___g_l_e_s2.html#ga817c719f6b647354c82559324ecbdc39", null ],
       [ "getDisplayMonitorCount", "group___g_l_e_s2.html#ga3f58ee26c14bf54639eb2cdaf054c11b", null ],
-      [ "_setSceneBlendingOperation", "group___g_l_e_s2.html#ga3fce8624a7935b6321530f0285348d9d", null ],
-      [ "_setSeparateSceneBlendingOperation", "group___g_l_e_s2.html#gad39f35ad1d2e2bb953f5114fb5da3eeb", null ],
       [ "_destroyDepthBuffer", "group___g_l_e_s2.html#ga5ee9e6efc4f43553d59498e31f670690", null ],
       [ "beginProfileEvent", "group___g_l_e_s2.html#gaa9d66fa2deb73aa6577716a9e3fc911c", null ],
       [ "endProfileEvent", "group___g_l_e_s2.html#ga5bbe15aca9033a03c1e91f8d685484a2", null ],
@@ -121,6 +117,7 @@ var group___g_l_e_s2 =
       [ "setGlobalNumberOfInstances", "class_ogre_1_1_g_l_e_s2_render_system.html#a3e31b243ba86e2114925a99b2c2825e1", null ],
       [ "setDepthBufferFor", "class_ogre_1_1_g_l_e_s2_render_system.html#a63c23bbd80d6862a54d471754d9bccf0", null ],
       [ "_useLights", "class_ogre_1_1_g_l_e_s2_render_system.html#afe87000fc9e5619f4f17fd77b37a212f", null ],
+      [ "areFixedFunctionLightsInViewSpace", "class_ogre_1_1_g_l_e_s2_render_system.html#a008131b65568c0bf072ae3a96203d6c0", null ],
       [ "_setWorldMatrix", "class_ogre_1_1_g_l_e_s2_render_system.html#ae8d7a587d3a8d15102f73b65bbceb56e", null ],
       [ "_setViewMatrix", "class_ogre_1_1_g_l_e_s2_render_system.html#a1a7926fe7b59598fdb7b7e743efdae6c", null ],
       [ "_setProjectionMatrix", "class_ogre_1_1_g_l_e_s2_render_system.html#ab72ff6224be9aebbc957b49919edf271", null ],
@@ -136,6 +133,8 @@ var group___g_l_e_s2 =
       [ "_setTextureCoordCalculation", "class_ogre_1_1_g_l_e_s2_render_system.html#a10fdc4a81a69fd6d9fb0bb62f3a3cece", null ],
       [ "_setTextureBlendMode", "class_ogre_1_1_g_l_e_s2_render_system.html#ac3e1b9a4c8499932b010d531b21e20ac", null ],
       [ "_setTextureMatrix", "class_ogre_1_1_g_l_e_s2_render_system.html#a6512839a2f001e463c0d46e07993192c", null ],
+      [ "setColourBlendState", "class_ogre_1_1_g_l_e_s2_render_system.html#a46abac034b2217b91ae66b334e1ca42f", null ],
+      [ "_setSceneBlending", "class_ogre_1_1_g_l_e_s2_render_system.html#afd5d05521034b0e901ba0ff7f653d1e7", null ],
       [ "_setTextureProjectionRelativeTo", "class_ogre_1_1_g_l_e_s2_render_system.html#a91e7ee7dd1f244ffa9a0681efb6fae6c", null ],
       [ "_cleanupDepthBuffers", "class_ogre_1_1_g_l_e_s2_render_system.html#a568dd8e5d75fc7eef649dda6d14d447d", null ],
       [ "_pauseFrame", "class_ogre_1_1_g_l_e_s2_render_system.html#a9893de6903d77fe231da1135f5ee00db", null ],
@@ -149,6 +148,7 @@ var group___g_l_e_s2 =
       [ "_getVertexCount", "class_ogre_1_1_g_l_e_s2_render_system.html#a46c964471b448ada768b766aca428b91", null ],
       [ "convertColourValue", "class_ogre_1_1_g_l_e_s2_render_system.html#a324d50e3fc58177d8d9f05c5cfc7e3e8", null ],
       [ "setNormaliseNormals", "class_ogre_1_1_g_l_e_s2_render_system.html#a07859d3fde38c9b447d0801d79eb3bee", null ],
+      [ "_dispatchCompute", "class_ogre_1_1_g_l_e_s2_render_system.html#a2c59487ad841c47a24b94d242b3a01af", null ],
       [ "getCapabilities", "class_ogre_1_1_g_l_e_s2_render_system.html#ac4b66fe49129476323eba9bdca672a36", null ],
       [ "getDriverVersion", "class_ogre_1_1_g_l_e_s2_render_system.html#a884fc9154ef8f4c1d17a7920460d81f2", null ],
       [ "_getDefaultViewportMaterialScheme", "class_ogre_1_1_g_l_e_s2_render_system.html#aeb912c6c0bfc8bd8d0670448e0a5370a", null ],
@@ -186,9 +186,9 @@ var group___g_l_e_s2 =
     [ "_getDepthStencilFormatFor", "group___g_l_e_s2.html#ga234e49f5469846344bd7ed4973d0b5f6", null ],
     [ "createMultiRenderTarget", "group___g_l_e_s2.html#ga485ebebda97e764bef335abadc04fb14", null ],
     [ "destroyRenderWindow", "group___g_l_e_s2.html#ga31201c00d107451d7f7ff264f3559a2e", null ],
-    [ "areFixedFunctionLightsInViewSpace", "group___g_l_e_s2.html#gae982beab16b67617dfe88fc6fdbede32", null ],
     [ "_setTexture", "group___g_l_e_s2.html#ga066f9dbe0f422cd350d22c563896e6c7", null ],
-    [ "_setTextureAddressingMode", "group___g_l_e_s2.html#gab35ff75c77786dd02c8df78cec83a638", null ],
+    [ "_setSampler", "group___g_l_e_s2.html#ga2a53c1abeeaaf7d7732571266b85d3bf", null ],
+    [ "_setTextureAddressingMode", "group___g_l_e_s2.html#ga9986214ed4d4bee60f62deef52659692", null ],
     [ "_setTextureBorderColour", "group___g_l_e_s2.html#ga8f7d75c7234f300c1d6fdb09d019a3bc", null ],
     [ "_setTextureMipmapBias", "group___g_l_e_s2.html#ga9120c932b874e1fb8645035bbf22b65e", null ],
     [ "_setLineWidth", "group___g_l_e_s2.html#ga55c3aaee65dee3249d3294a49d21e9d4", null ],
@@ -220,7 +220,6 @@ var group___g_l_e_s2 =
     [ "unregisterThread", "group___g_l_e_s2.html#gaa6bfad53622bb5f865871a3918bb4fac", null ],
     [ "preExtraThreadsStarted", "group___g_l_e_s2.html#ga8facb30ed47df20d9df6de77c23c5398", null ],
     [ "postExtraThreadsStarted", "group___g_l_e_s2.html#ga1767016ed55e3877d47464882aef9a27", null ],
-    [ "setClipPlanesImpl", "group___g_l_e_s2.html#ga2a7acd32e8329a1b59f40b7b7742dabf", null ],
     [ "_getStateCacheManager", "group___g_l_e_s2.html#gaa800af7ac51f670a3b8e4fc4ac320790", null ],
     [ "_createVao", "group___g_l_e_s2.html#ga22c282474176319fd19e77f343313c7e", null ],
     [ "_bindVao", "group___g_l_e_s2.html#ga098f0c566b7c08c3d368a7fdb24ddeee", null ],
@@ -235,14 +234,11 @@ var group___g_l_e_s2 =
     [ "convertStencilOp", "group___g_l_e_s2.html#gae96b47494abeb2761223b9408a37b2b9", null ],
     [ "bindGpuProgram", "group___g_l_e_s2.html#gad1b0cf3f7aea1a2f2bb3d8762500282f", null ],
     [ "unbindGpuProgram", "group___g_l_e_s2.html#ga564175c3cb628ac2deeea6d98d4e4bc0", null ],
-    [ "bindGpuProgramParameters", "group___g_l_e_s2.html#ga733ffc8e541d74e5cdbaff1ae59fb45b", null ],
+    [ "bindGpuProgramParameters", "group___g_l_e_s2.html#ga9c3c59236b71f033101d6d63f1e2af94", null ],
     [ "bindGpuProgramPassIterationParameters", "group___g_l_e_s2.html#ga9fe72776eaa2437f5a1ad7a2498de7cd", null ],
-    [ "_setSceneBlending", "group___g_l_e_s2.html#ga4ca1d78dff99ffe26c008c1a3a6ad330", null ],
     [ "_setSeparateSceneBlending", "group___g_l_e_s2.html#ga2ed07f074ae69826c8090cd8541b67a5", null ],
     [ "_setAlphaRejectSettings", "group___g_l_e_s2.html#ga817c719f6b647354c82559324ecbdc39", null ],
     [ "getDisplayMonitorCount", "group___g_l_e_s2.html#ga3f58ee26c14bf54639eb2cdaf054c11b", null ],
-    [ "_setSceneBlendingOperation", "group___g_l_e_s2.html#ga3fce8624a7935b6321530f0285348d9d", null ],
-    [ "_setSeparateSceneBlendingOperation", "group___g_l_e_s2.html#gad39f35ad1d2e2bb953f5114fb5da3eeb", null ],
     [ "_destroyDepthBuffer", "group___g_l_e_s2.html#ga5ee9e6efc4f43553d59498e31f670690", null ],
     [ "beginProfileEvent", "group___g_l_e_s2.html#gaa9d66fa2deb73aa6577716a9e3fc911c", null ],
     [ "endProfileEvent", "group___g_l_e_s2.html#ga5bbe15aca9033a03c1e91f8d685484a2", null ],
