@@ -70,6 +70,7 @@ var namespace_ogre =
     [ "CgProgram", "class_ogre_1_1_cg_program.html", "class_ogre_1_1_cg_program" ],
     [ "CgProgramFactory", "class_ogre_1_1_cg_program_factory.html", "class_ogre_1_1_cg_program_factory" ],
     [ "Codec", "class_ogre_1_1_codec.html", "class_ogre_1_1_codec" ],
+    [ "ColourBlendState", "struct_ogre_1_1_colour_blend_state.html", "struct_ogre_1_1_colour_blend_state" ],
     [ "ColourFaderAffector", "class_ogre_1_1_colour_fader_affector.html", "class_ogre_1_1_colour_fader_affector" ],
     [ "ColourFaderAffector2", "class_ogre_1_1_colour_fader_affector2.html", "class_ogre_1_1_colour_fader_affector2" ],
     [ "ColourFaderAffectorFactory", "class_ogre_1_1_colour_fader_affector_factory.html", "class_ogre_1_1_colour_fader_affector_factory" ],
@@ -263,6 +264,7 @@ var namespace_ogre =
     [ "GL3PlusRenderBuffer", "class_ogre_1_1_g_l3_plus_render_buffer.html", "class_ogre_1_1_g_l3_plus_render_buffer" ],
     [ "GL3PlusRenderSystem", "class_ogre_1_1_g_l3_plus_render_system.html", "class_ogre_1_1_g_l3_plus_render_system" ],
     [ "GL3PlusRenderToVertexBuffer", "class_ogre_1_1_g_l3_plus_render_to_vertex_buffer.html", "class_ogre_1_1_g_l3_plus_render_to_vertex_buffer" ],
+    [ "GL3PlusSampler", "class_ogre_1_1_g_l3_plus_sampler.html", "class_ogre_1_1_g_l3_plus_sampler" ],
     [ "GL3PlusStateCacheManager", "class_ogre_1_1_g_l3_plus_state_cache_manager.html", "class_ogre_1_1_g_l3_plus_state_cache_manager" ],
     [ "GL3PlusTexture", "class_ogre_1_1_g_l3_plus_texture.html", "class_ogre_1_1_g_l3_plus_texture" ],
     [ "GL3PlusTextureBuffer", "class_ogre_1_1_g_l3_plus_texture_buffer.html", "class_ogre_1_1_g_l3_plus_texture_buffer" ],
@@ -299,6 +301,7 @@ var namespace_ogre =
     [ "GLFBOMultiRenderTarget", "class_ogre_1_1_g_l_f_b_o_multi_render_target.html", "class_ogre_1_1_g_l_f_b_o_multi_render_target" ],
     [ "GLFBORenderTexture", "class_ogre_1_1_g_l_f_b_o_render_texture.html", "class_ogre_1_1_g_l_f_b_o_render_texture" ],
     [ "GLFrameBufferObject", "class_ogre_1_1_g_l_frame_buffer_object.html", "class_ogre_1_1_g_l_frame_buffer_object" ],
+    [ "GLFrameBufferObjectCommon", "class_ogre_1_1_g_l_frame_buffer_object_common.html", "class_ogre_1_1_g_l_frame_buffer_object_common" ],
     [ "GLGpuNvparseProgram", "class_ogre_1_1_g_l_gpu_nvparse_program.html", "class_ogre_1_1_g_l_gpu_nvparse_program" ],
     [ "GLGpuProgram", "class_ogre_1_1_g_l_gpu_program.html", "class_ogre_1_1_g_l_gpu_program" ],
     [ "GLGpuProgramManager", "class_ogre_1_1_g_l_gpu_program_manager.html", "class_ogre_1_1_g_l_gpu_program_manager" ],
@@ -317,6 +320,7 @@ var namespace_ogre =
     [ "GLRenderBuffer", "class_ogre_1_1_g_l_render_buffer.html", "class_ogre_1_1_g_l_render_buffer" ],
     [ "GLRenderSystem", "class_ogre_1_1_g_l_render_system.html", "class_ogre_1_1_g_l_render_system" ],
     [ "GLRenderSystemCommon", "class_ogre_1_1_g_l_render_system_common.html", "class_ogre_1_1_g_l_render_system_common" ],
+    [ "GLRenderTarget", "class_ogre_1_1_g_l_render_target.html", "class_ogre_1_1_g_l_render_target" ],
     [ "GLRenderTexture", "class_ogre_1_1_g_l_render_texture.html", "class_ogre_1_1_g_l_render_texture" ],
     [ "GLRenderToVertexBuffer", "class_ogre_1_1_g_l_render_to_vertex_buffer.html", "class_ogre_1_1_g_l_render_to_vertex_buffer" ],
     [ "GLRTTManager", "class_ogre_1_1_g_l_r_t_t_manager.html", "class_ogre_1_1_g_l_r_t_t_manager" ],
@@ -666,6 +670,7 @@ var namespace_ogre =
     [ "RotationAffectorFactory", "class_ogre_1_1_rotation_affector_factory.html", "class_ogre_1_1_rotation_affector_factory" ],
     [ "RotationalSpline", "class_ogre_1_1_rotational_spline.html", "class_ogre_1_1_rotational_spline" ],
     [ "RuntimeAssertionException", "class_ogre_1_1_runtime_assertion_exception.html", "class_ogre_1_1_runtime_assertion_exception" ],
+    [ "Sampler", "class_ogre_1_1_sampler.html", "class_ogre_1_1_sampler" ],
     [ "ScaleAffector", "class_ogre_1_1_scale_affector.html", "class_ogre_1_1_scale_affector" ],
     [ "ScaleAffectorFactory", "class_ogre_1_1_scale_affector_factory.html", "class_ogre_1_1_scale_affector_factory" ],
     [ "ScaleControllerFunction", "class_ogre_1_1_scale_controller_function.html", "class_ogre_1_1_scale_controller_function" ],
@@ -694,7 +699,6 @@ var namespace_ogre =
     [ "ShaderHelper", "class_ogre_1_1_shader_helper.html", "class_ogre_1_1_shader_helper" ],
     [ "ShaderHelperCg", "class_ogre_1_1_shader_helper_cg.html", "class_ogre_1_1_shader_helper_cg" ],
     [ "ShaderHelperGLSL", "class_ogre_1_1_shader_helper_g_l_s_l.html", "class_ogre_1_1_shader_helper_g_l_s_l" ],
-    [ "ShaderHelperHLSL", "class_ogre_1_1_shader_helper_h_l_s_l.html", "class_ogre_1_1_shader_helper_h_l_s_l" ],
     [ "ShaderManager", "class_ogre_1_1_shader_manager.html", "class_ogre_1_1_shader_manager" ],
     [ "ShaderPiecesManager", "class_ogre_1_1_shader_pieces_manager.html", "class_ogre_1_1_shader_pieces_manager" ],
     [ "ShaderTemplate", "class_ogre_1_1_shader_template.html", "class_ogre_1_1_shader_template" ],
@@ -772,10 +776,12 @@ var namespace_ogre =
     [ "UnimplementedException", "class_ogre_1_1_unimplemented_exception.html", "class_ogre_1_1_unimplemented_exception" ],
     [ "UserObjectBindings", "class_ogre_1_1_user_object_bindings.html", "class_ogre_1_1_user_object_bindings" ],
     [ "VariableAccessAbstractNode", "class_ogre_1_1_variable_access_abstract_node.html", "class_ogre_1_1_variable_access_abstract_node" ],
+    [ "Vector", "class_ogre_1_1_vector.html", "class_ogre_1_1_vector" ],
     [ "vector", "struct_ogre_1_1vector.html", "struct_ogre_1_1vector" ],
-    [ "Vector2", "class_ogre_1_1_vector2.html", "class_ogre_1_1_vector2" ],
-    [ "Vector3", "class_ogre_1_1_vector3.html", "class_ogre_1_1_vector3" ],
-    [ "Vector4", "class_ogre_1_1_vector4.html", "class_ogre_1_1_vector4" ],
+    [ "VectorBase", "struct_ogre_1_1_vector_base.html", "struct_ogre_1_1_vector_base" ],
+    [ "VectorBase< 2, Real >", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4" ],
+    [ "VectorBase< 3, Real >", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4" ],
+    [ "VectorBase< 4, Real >", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4" ],
     [ "VectorIterator", "class_ogre_1_1_vector_iterator.html", "class_ogre_1_1_vector_iterator" ],
     [ "VectorIteratorWrapper", "class_ogre_1_1_vector_iterator_wrapper.html", "class_ogre_1_1_vector_iterator_wrapper" ],
     [ "VectorSet", "struct_ogre_1_1_vector_set.html", "struct_ogre_1_1_vector_set" ],
