@@ -1,89 +1,94 @@
 var NAVTREEINDEX0 =
 {
-"_animation.html":[1,8],
-"_animation.html#Numeric-Value-Animation":[1,8,3],
-"_animation.html#SceneNode-Animation":[1,8,2],
-"_animation.html#Skeletal-Animation":[1,8,0],
-"_animation.html#Vertex-Animation":[1,8,1],
-"_compositor-_scripts.html":[1,2,3],
-"_compositor-_scripts.html#Applying-a-Compositor":[1,2,3,4],
-"_compositor-_scripts.html#Clear-Section":[1,2,3,2],
-"_compositor-_scripts.html#Compositor-Fundamentals":[1,2,3,0],
-"_compositor-_scripts.html#Compositor-Passes":[1,2,3,1,2],
-"_compositor-_scripts.html#Compositor-Target-Passes":[1,2,3,1,1],
-"_compositor-_scripts.html#Compositor-Techniques":[1,2,3,1,0],
-"_compositor-_scripts.html#Format-1":[1,2,3,1],
-"_compositor-_scripts.html#Stencil-Section":[1,2,3,3],
-"_direct3_d11_2include_2_ogre_min_g_w_support_8h.html":[8,0,367],
-"_direct3_d9_2include_2_ogre_min_g_w_support_8h.html":[8,0,368],
+"_animation.html":[1,9],
+"_animation.html#Animation-State":[1,9,0],
+"_animation.html#Combining-Skeletal-and-Vertex-Animation":[1,9,3,2],
+"_animation.html#Morph-Animation":[1,9,3,0],
+"_animation.html#Numeric-Value-Animation":[1,9,4],
+"_animation.html#Pose-Animation":[1,9,3,1],
+"_animation.html#SceneNode-Animation":[1,9,2],
+"_animation.html#Skeletal-Animation":[1,9,1],
+"_animation.html#Vertex-Animation":[1,9,3],
+"_compositor-_scripts.html":[1,3,3],
+"_compositor-_scripts.html#Applying-a-Compositor":[1,3,3,4],
+"_compositor-_scripts.html#Clear-Section":[1,3,3,3,0],
+"_compositor-_scripts.html#Compositor-Fundamentals":[1,3,3,0],
+"_compositor-_scripts.html#Compositor-Passes":[1,3,3,3],
+"_compositor-_scripts.html#Compositor-Target-Passes":[1,3,3,2],
+"_compositor-_scripts.html#Compositor-Techniques":[1,3,3,1],
+"_compositor-_scripts.html#Stencil-Section":[1,3,3,3,1],
+"_compositor-_scripts.html#compositor-texture":[1,3,3,1,0],
+"_direct3_d11_2include_2_ogre_min_g_w_support_8h.html":[8,0,368],
+"_direct3_d9_2include_2_ogre_min_g_w_support_8h.html":[8,0,369],
 "_external-_texture-_sources.html":[2,9],
-"_font-_definition-_scripts.html":[1,2,6],
-"_hardware-_buffers.html":[1,6],
-"_hardware-_buffers.html#Binding-the-Vertex-Buffer":[1,6,1,5],
-"_hardware-_buffers.html#Buffer-Usage":[1,6,0],
-"_hardware-_buffers.html#Colour-channels":[1,6,3,8],
-"_hardware-_buffers.html#Complete-list-of-pixel-formats":[1,6,3,9],
-"_hardware-_buffers.html#Creating-a-texture":[1,6,3,0,0],
-"_hardware-_buffers.html#Creating-the-Vertex-Buffer":[1,6,1,4],
-"_hardware-_buffers.html#Cube-map-textures":[1,6,3,6],
-"_hardware-_buffers.html#Direct-memory-locking":[1,6,3,4],
-"_hardware-_buffers.html#Getting-a-PixelBuffer":[1,6,3,1],
-"_hardware-_buffers.html#Hardware-Index-Buffers":[1,6,2],
-"_hardware-_buffers.html#Hardware-Pixel-Buffers":[1,6,3],
-"_hardware-_buffers.html#Hardware-Vertex-Buffers":[1,6,1],
-"_hardware-_buffers.html#Important-Considerations":[1,6,1,2],
-"_hardware-_buffers.html#Locking-buffers":[1,6,0,1],
-"_hardware-_buffers.html#Pixel-Formats":[1,6,3,7],
-"_hardware-_buffers.html#Pixel-boxes":[1,6,3,10],
-"_hardware-_buffers.html#Practical-Buffer-Tips":[1,6,0,2],
-"_hardware-_buffers.html#Shadow-Buffers":[1,6,0,0],
-"_hardware-_buffers.html#Texture-Types":[1,6,3,5],
-"_hardware-_buffers.html#Textures":[1,6,3,0],
-"_hardware-_buffers.html#The-IndexData-class":[1,6,2,0],
-"_hardware-_buffers.html#The-VertexData-class":[1,6,1,0],
-"_hardware-_buffers.html#Updating-Index-Buffers":[1,6,2,1],
-"_hardware-_buffers.html#Updating-Pixel-Buffers":[1,6,3,2],
-"_hardware-_buffers.html#Updating-Vertex-Buffers":[1,6,1,6],
-"_hardware-_buffers.html#Vertex-Buffer-Bindings":[1,6,1,3],
-"_hardware-_buffers.html#Vertex-Declarations":[1,6,1,1],
-"_hardware-_buffers.html#blitFromMemory":[1,6,3,3],
-"_high-level-_programs.html":[1,3],
-"_high-level-_programs.html#Accessing-OpenGL-states-in-GLSL":[1,3,2,2],
-"_high-level-_programs.html#Binding-vertex-attributes":[1,3,2,3],
-"_high-level-_programs.html#Cg":[1,3,0],
-"_high-level-_programs.html#GLSL":[1,3,2],
-"_high-level-_programs.html#GLSL-Geometry-shader-specification":[1,3,2,5],
-"_high-level-_programs.html#GLSL-Texture-Samplers":[1,3,2,0],
-"_high-level-_programs.html#HLSL":[1,3,1],
-"_high-level-_programs.html#Matrix-parameters":[1,3,2,1],
-"_high-level-_programs.html#Morph-Animation-in-Vertex-Programs":[1,3,7],
-"_high-level-_programs.html#Pose-Animation-in-Vertex-Programs":[1,3,8],
-"_high-level-_programs.html#Preprocessor-definitions":[1,3,2,4],
-"_high-level-_programs.html#Program-Parameter-Specification":[1,3,4,0],
-"_high-level-_programs.html#Shadows-and-Vertex-Programs":[1,3,5],
-"_high-level-_programs.html#Skeletal-Animation-in-Vertex-Programs":[1,3,6],
-"_high-level-_programs.html#Unified-High_002dlevel-Programs":[1,3,3],
-"_high-level-_programs.html#Using-Vertex_002fGeometry_002fFragment-Programs-in-a-Pass":[1,3,4],
-"_high-level-_programs.html#Vertex-Texture-Fetch":[1,3,10],
-"_high-level-_programs.html#Vertex-texture-fetching-in-vertex-programs":[1,3,9],
+"_font-_definition-_scripts.html":[1,3,6],
+"_hardware-_buffers.html":[1,7],
+"_hardware-_buffers.html#Binding-the-Vertex-Buffer":[1,7,1,5],
+"_hardware-_buffers.html#Buffer-Usage":[1,7,0],
+"_hardware-_buffers.html#Colour-channels":[1,7,3,8],
+"_hardware-_buffers.html#Complete-list-of-pixel-formats":[1,7,3,9],
+"_hardware-_buffers.html#Creating-a-texture":[1,7,3,0,0],
+"_hardware-_buffers.html#Creating-the-Vertex-Buffer":[1,7,1,4],
+"_hardware-_buffers.html#Cube-map-textures":[1,7,3,6],
+"_hardware-_buffers.html#Direct-memory-locking":[1,7,3,4],
+"_hardware-_buffers.html#Getting-a-PixelBuffer":[1,7,3,1],
+"_hardware-_buffers.html#Hardware-Index-Buffers":[1,7,2],
+"_hardware-_buffers.html#Hardware-Pixel-Buffers":[1,7,3],
+"_hardware-_buffers.html#Hardware-Vertex-Buffers":[1,7,1],
+"_hardware-_buffers.html#Important-Considerations":[1,7,1,2],
+"_hardware-_buffers.html#Locking-buffers":[1,7,0,1],
+"_hardware-_buffers.html#Pixel-Formats":[1,7,3,7],
+"_hardware-_buffers.html#Pixel-boxes":[1,7,3,10],
+"_hardware-_buffers.html#Practical-Buffer-Tips":[1,7,0,2],
+"_hardware-_buffers.html#Shadow-Buffers":[1,7,0,0],
+"_hardware-_buffers.html#Texture-Types":[1,7,3,5],
+"_hardware-_buffers.html#Textures":[1,7,3,0],
+"_hardware-_buffers.html#The-IndexData-class":[1,7,2,0],
+"_hardware-_buffers.html#The-VertexData-class":[1,7,1,0],
+"_hardware-_buffers.html#Updating-Index-Buffers":[1,7,2,1],
+"_hardware-_buffers.html#Updating-Pixel-Buffers":[1,7,3,2],
+"_hardware-_buffers.html#Updating-Vertex-Buffers":[1,7,1,6],
+"_hardware-_buffers.html#Vertex-Buffer-Bindings":[1,7,1,3],
+"_hardware-_buffers.html#Vertex-Declarations":[1,7,1,1],
+"_hardware-_buffers.html#blitFromMemory":[1,7,3,3],
+"_high-level-_programs.html":[1,4],
+"_high-level-_programs.html#Accessing-OpenGL-states-in-GLSL":[1,4,2,2],
+"_high-level-_programs.html#Binding-vertex-attributes":[1,4,2,3],
+"_high-level-_programs.html#Cg":[1,4,0],
+"_high-level-_programs.html#GLSL":[1,4,2],
+"_high-level-_programs.html#GLSL-Geometry-shader-specification":[1,4,2,5],
+"_high-level-_programs.html#GLSL-Texture-Samplers":[1,4,2,0],
+"_high-level-_programs.html#HLSL":[1,4,1],
+"_high-level-_programs.html#Matrix-parameters":[1,4,2,1],
+"_high-level-_programs.html#Morph-Animation-in-Vertex-Programs":[1,4,7],
+"_high-level-_programs.html#Pose-Animation-in-Vertex-Programs":[1,4,8],
+"_high-level-_programs.html#Preprocessor-definitions":[1,4,2,4],
+"_high-level-_programs.html#Program-Parameter-Specification":[1,4,4,0],
+"_high-level-_programs.html#Shadows-and-Vertex-Programs":[1,4,5],
+"_high-level-_programs.html#Skeletal-Animation-in-Vertex-Programs":[1,4,6],
+"_high-level-_programs.html#Unified-High_002dlevel-Programs":[1,4,3],
+"_high-level-_programs.html#Using-Vertex_002fGeometry_002fFragment-Programs-in-a-Pass":[1,4,4],
+"_high-level-_programs.html#Vertex-Texture-Fetch":[1,4,10],
+"_high-level-_programs.html#Vertex-texture-fetching-in-vertex-programs":[1,4,9],
 "_introduction.html":[1,0],
-"_material-_scripts.html":[1,2,2],
-"_material-_scripts.html#Adding-new-Techniques_002c-Passes_002c-to-copied-materials_003a":[1,2,2,8],
-"_material-_scripts.html#Declaring-Shared-Parameters":[1,2,2,7],
-"_material-_scripts.html#Declaring-Vertex_002fGeometry_002fFragment-Programs":[1,2,2,4],
-"_material-_scripts.html#Default-Program-Parameters":[1,2,2,6],
-"_material-_scripts.html#Identifying-Texture-Units-to-override-values":[1,2,2,9],
-"_material-_scripts.html#Material":[1,2,2,0],
-"_material-_scripts.html#Passes":[1,2,2,2],
-"_material-_scripts.html#Specifying-Named-Constants-for-Assembler-Shaders":[1,2,2,5],
-"_material-_scripts.html#Techniques":[1,2,2,1],
-"_material-_scripts.html#Texture-Aliases":[1,2,2,10],
-"_material-_scripts.html#Texture-Units":[1,2,2,3],
-"_material-_scripts.html#iteration":[1,2,2,2,0],
-"_mesh-_tools.html":[1,5],
-"_mesh-_tools.html#Exporters":[1,5,0],
-"_mesh-_tools.html#MeshUpgrader":[1,5,2],
-"_mesh-_tools.html#XMLConverter":[1,5,1],
+"_material-_scripts.html":[1,3,2],
+"_material-_scripts.html#Adding-new-Techniques_002c-Passes_002c-to-copied-materials_003a":[1,3,2,9],
+"_material-_scripts.html#Declaring-Shared-Parameters":[1,3,2,8],
+"_material-_scripts.html#Declaring-Vertex_002fGeometry_002fFragment-Programs":[1,3,2,5],
+"_material-_scripts.html#Default-Program-Parameters":[1,3,2,7],
+"_material-_scripts.html#Identifying-Texture-Units-to-override-values":[1,3,2,10],
+"_material-_scripts.html#Material":[1,3,2,0],
+"_material-_scripts.html#Passes":[1,3,2,2],
+"_material-_scripts.html#Samplers":[1,3,2,4],
+"_material-_scripts.html#Specifying-Named-Constants-for-Assembler-Shaders":[1,3,2,6],
+"_material-_scripts.html#Techniques":[1,3,2,1],
+"_material-_scripts.html#Texture-Aliases":[1,3,2,11],
+"_material-_scripts.html#Texture-Units":[1,3,2,3],
+"_material-_scripts.html#iteration":[1,3,2,2,0],
+"_mesh-_tools.html":[1,6],
+"_mesh-_tools.html#Exporters":[1,6,0],
+"_mesh-_tools.html#MeshUpgrader":[1,6,2],
+"_mesh-_tools.html#XMLConverter":[1,6,1],
 "_ogre_8h.html":[8,0,0],
 "_ogre_a_s_t_c_codec_8h.html":[8,0,14],
 "_ogre_advanced_render_controls_8h.html":[8,0,1],
@@ -244,10 +249,5 @@ var NAVTREEINDEX0 =
 "_ogre_com_ptr_8h.html#aab7a3e30a0294c44ce9f1ab0701b37ee":[8,0,62,1],
 "_ogre_com_ptr_8h.html#ga3b1a2ed80c33ac23b8894c35d8029160":[8,0,62,8],
 "_ogre_com_ptr_8h.html#ga43ecfebca81e0b8ad95201822f8643d7":[8,0,62,6],
-"_ogre_com_ptr_8h.html#ga675a4dbbd77978f9498570697c0f6dbf":[8,0,62,5],
-"_ogre_com_ptr_8h.html#ga80a53685c54f25a002db54a9368e02c6":[8,0,62,4],
-"_ogre_com_ptr_8h.html#ga8f81fcfbc204edbd0f2f52519068fe96":[8,0,62,2],
-"_ogre_com_ptr_8h.html#gaaa93ff4a9e74ef8d4570f20ae725bd81":[8,0,62,7],
-"_ogre_com_ptr_8h.html#gadf4d7e1076f4d7831f6671d3efc324ba":[8,0,62,3],
-"_ogre_common_8h.html":[8,0,53]
+"_ogre_com_ptr_8h.html#ga675a4dbbd77978f9498570697c0f6dbf":[8,0,62,5]
 };
