@@ -1,5 +1,41 @@
 var NAVTREEINDEX11 =
 {
+"class_ogre_1_1_a_p_k_file_system_archive_factory.html#a9654b843fa2ea996172993c389ce6f3a":[5,0,8,0,2],
+"class_ogre_1_1_a_p_k_file_system_archive_factory.html#ab0ebdeda7a7d199507fb11d3ca191d71":[5,0,8,0,4],
+"class_ogre_1_1_a_p_k_file_system_archive_factory.html#adb0ee59458754e564ec38d868fe2982f":[5,0,8,0,3],
+"class_ogre_1_1_a_s_t_c_codec.html":[5,0,3,0],
+"class_ogre_1_1_a_s_t_c_codec.html#a02c09d20cedebbd768784f4a07b1d528":[5,0,3,0,9],
+"class_ogre_1_1_a_s_t_c_codec.html#a06fa1827bc57846191e27849555b76e7":[5,0,3,0,11],
+"class_ogre_1_1_a_s_t_c_codec.html#a113b5f2d31e4ab38817b3cae401e9b44":[5,0,3,0,4],
+"class_ogre_1_1_a_s_t_c_codec.html#a19214cb3ea9412e615c59f055b311afe":[5,0,3,0,6],
+"class_ogre_1_1_a_s_t_c_codec.html#a217e39b5c41d63eb4a800352485e1306":[5,0,3,0,3],
+"class_ogre_1_1_a_s_t_c_codec.html#a21f4b8a16d070793d576f827c9fee218":[5,0,3,0,1],
+"class_ogre_1_1_a_s_t_c_codec.html#a270be35471eb9ef28fdbd4b7dced21b9":[5,0,3,0,21],
+"class_ogre_1_1_a_s_t_c_codec.html#a29e31ad112b08ea7fb648b63f426ff1f":[5,0,3,0,0],
+"class_ogre_1_1_a_s_t_c_codec.html#a3a70a9e70e1f0e2a4b6b0e249242fedf":[5,0,3,0,5],
+"class_ogre_1_1_a_s_t_c_codec.html#a3d41ee013b8d13485188f3b43de8a3c5":[5,0,3,0,10],
+"class_ogre_1_1_a_s_t_c_codec.html#a55bf1d49e91958f8e412a583666bbd58":[5,0,3,0,17],
+"class_ogre_1_1_a_s_t_c_codec.html#a6092324fd74dd0221f7c63ca8bec4fc1":[5,0,3,0,18],
+"class_ogre_1_1_a_s_t_c_codec.html#a60f445cc6919df56af6611fd14eec47d":[5,0,3,0,14],
+"class_ogre_1_1_a_s_t_c_codec.html#a6e9a3bb697c7249e822725eda274615c":[5,0,3,0,13],
+"class_ogre_1_1_a_s_t_c_codec.html#a7aa2599cd9db05e590fb7f7786076852":[5,0,3,0,16],
+"class_ogre_1_1_a_s_t_c_codec.html#a8cc81c85bd7d4e25393aa153c5e01454":[5,0,3,0,2],
+"class_ogre_1_1_a_s_t_c_codec.html#aaf530dfcac7b4c9c8c4a64b87c6dd1ab":[5,0,3,0,7],
+"class_ogre_1_1_a_s_t_c_codec.html#ac8775b1052fb8ba72abdfb55df20a6af":[5,0,3,0,20],
+"class_ogre_1_1_a_s_t_c_codec.html#acc4ee751f92b6e54051393e74e0a2884":[5,0,3,0,19],
+"class_ogre_1_1_a_s_t_c_codec.html#ad9072a8530d43873924eb02ebae91569":[5,0,3,0,8],
+"class_ogre_1_1_a_s_t_c_codec.html#ad9edeb74111f2f4a8efcbf7ed7f3be74":[5,0,3,0,12],
+"class_ogre_1_1_a_s_t_c_codec.html#ae5b74cfd0cb797a2ac139b4adb7ac557":[5,0,3,0,15],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html":[7,0,0,6],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a0834dd85d740a9f6783e10a70dfccc1b":[7,0,0,6,4],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a0ccfb0445484d40af5e3d5fb346e1bdd":[7,0,0,6,0],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a0cf2f9d97bc32d32674038b112b405d1":[7,0,0,6,7],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a4c359b8fd0935b31bfc3a0eb61bd61e8":[7,0,0,6,5],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a60e9908806b839380729aae13b9a959a":[7,0,0,6,10],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a6ffe63d24cfcaf5c0d6028fe61baa80e":[7,0,0,6,13],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#aa2d73aba1ed139a1a83c0dcdd889a492":[7,0,0,6,2],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ab3a486ff7212d5175828e4fef82ca37c":[7,0,0,6,12],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ac2237491a332c7214c70648df44810ee":[7,0,0,6,8],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ac42ff485cbc07a6f48ad1cbc8347270e":[7,0,0,6,1],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ad3f99e9040b94b0ce0cb13ab3deb6efd":[7,0,0,6,3],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#adeb7d40e283838e2f04139fc183c95d0":[7,0,0,6,11],
@@ -19,34 +55,35 @@ var NAVTREEINDEX11 =
 "class_ogre_1_1_affine3.html#a0ea806400969075b54313aed739cdce6":[5,0,6,0,12],
 "class_ogre_1_1_affine3.html#a23c6bb6170cd619be269bec8ed434ef4":[5,0,6,0,2],
 "class_ogre_1_1_affine3.html#a2511bc98e0348413c8fc00712086b8c5":[5,0,6,0,4],
-"class_ogre_1_1_affine3.html#a2a5aa7dda4dbac2401fb251f22b9b038":[5,0,6,0,19],
+"class_ogre_1_1_affine3.html#a2a5aa7dda4dbac2401fb251f22b9b038":[5,0,6,0,20],
 "class_ogre_1_1_affine3.html#a2a72dd6d84a4f57a881f94de62bc8a34":[5,0,6,0,8],
 "class_ogre_1_1_affine3.html#a30b0a43638d438c54c335453a3bf4636":[5,0,6,0,0],
 "class_ogre_1_1_affine3.html#a44f73afce352e88d8b8463475baf6b5a":[5,0,6,0,6],
-"class_ogre_1_1_affine3.html#a46525728e27cbc3aeb2cbf1c75912174":[5,0,6,0,16],
+"class_ogre_1_1_affine3.html#a46525728e27cbc3aeb2cbf1c75912174":[5,0,6,0,17],
 "class_ogre_1_1_affine3.html#a4cce7fb866e2a35fc2c425f897d03ca2":[5,0,6,0,9],
-"class_ogre_1_1_affine3.html#a4fce454d3b27bb2ebc5e3cabf4b931eb":[5,0,6,0,22],
-"class_ogre_1_1_affine3.html#a54652722d399be755ebfd3fa1af886f1":[5,0,6,0,20],
+"class_ogre_1_1_affine3.html#a4fce454d3b27bb2ebc5e3cabf4b931eb":[5,0,6,0,23],
+"class_ogre_1_1_affine3.html#a54652722d399be755ebfd3fa1af886f1":[5,0,6,0,21],
 "class_ogre_1_1_affine3.html#a5ce74f781c8c3ce99976c31fba9a6eb0":[5,0,6,0,1],
-"class_ogre_1_1_affine3.html#a633f5ace5a3b3870d60d1b3d08dc1477":[5,0,6,0,23],
-"class_ogre_1_1_affine3.html#a7703077c23c37d7eb1889f9c9f5197c0":[5,0,6,0,17],
-"class_ogre_1_1_affine3.html#a7fea969b4c39eb571b5798a7ff23d16e":[5,0,6,0,25],
-"class_ogre_1_1_affine3.html#a804a6a6e44386202d103a516149eb4be":[5,0,6,0,28],
-"class_ogre_1_1_affine3.html#a84c9eb0fd3027630e299615e9ea6efb0":[5,0,6,0,24],
-"class_ogre_1_1_affine3.html#a9115cefcc7321c90659b976bcce542f3":[5,0,6,0,27],
-"class_ogre_1_1_affine3.html#a9a771b8258d88c5a37f58494de1b0597":[5,0,6,0,29],
+"class_ogre_1_1_affine3.html#a633f5ace5a3b3870d60d1b3d08dc1477":[5,0,6,0,24],
+"class_ogre_1_1_affine3.html#a7703077c23c37d7eb1889f9c9f5197c0":[5,0,6,0,18],
+"class_ogre_1_1_affine3.html#a7fea969b4c39eb571b5798a7ff23d16e":[5,0,6,0,26],
+"class_ogre_1_1_affine3.html#a804a6a6e44386202d103a516149eb4be":[5,0,6,0,29],
+"class_ogre_1_1_affine3.html#a84c9eb0fd3027630e299615e9ea6efb0":[5,0,6,0,25],
+"class_ogre_1_1_affine3.html#a9115cefcc7321c90659b976bcce542f3":[5,0,6,0,28],
+"class_ogre_1_1_affine3.html#a9a771b8258d88c5a37f58494de1b0597":[5,0,6,0,30],
 "class_ogre_1_1_affine3.html#a9fcc18e98ded8a18261e66f92fc2dfe8":[5,0,6,0,13],
-"class_ogre_1_1_affine3.html#aa21a63d88ef4ffc429f2c8edbabe1a1f":[5,0,6,0,14],
+"class_ogre_1_1_affine3.html#aa21a63d88ef4ffc429f2c8edbabe1a1f":[5,0,6,0,15],
 "class_ogre_1_1_affine3.html#aa9ab6eb8ff75222d1154f14bdd3d2a8e":[5,0,6,0,10],
 "class_ogre_1_1_affine3.html#aad8e3b12ac04a0229d5a2af84f358883":[5,0,6,0,7],
-"class_ogre_1_1_affine3.html#aadd0be612b9026d71e25c667123c38fd":[5,0,6,0,21],
-"class_ogre_1_1_affine3.html#ad5400b5a490eb1df3e80d7d5d193b2aa":[5,0,6,0,18],
-"class_ogre_1_1_affine3.html#ad6af815a07b45f0459cc223b7aab8d21":[5,0,6,0,15],
+"class_ogre_1_1_affine3.html#aadd0be612b9026d71e25c667123c38fd":[5,0,6,0,14],
+"class_ogre_1_1_affine3.html#aadd0be612b9026d71e25c667123c38fd":[5,0,6,0,22],
+"class_ogre_1_1_affine3.html#ad5400b5a490eb1df3e80d7d5d193b2aa":[5,0,6,0,19],
+"class_ogre_1_1_affine3.html#ad6af815a07b45f0459cc223b7aab8d21":[5,0,6,0,16],
 "class_ogre_1_1_affine3.html#ae0ff2f252c8642916d15316ff0e2107c":[5,0,6,0,5],
 "class_ogre_1_1_affine3.html#ae45c5a41dd3e6b752e406a5597a1990d":[5,0,6,0,11],
-"class_ogre_1_1_affine3.html#af37f4f9d112151323e0f53d135c13612":[5,0,6,0,30],
+"class_ogre_1_1_affine3.html#af37f4f9d112151323e0f53d135c13612":[5,0,6,0,31],
 "class_ogre_1_1_affine3.html#aff614a967fe24db7a8059be148f9c8a1":[5,0,6,0,3],
-"class_ogre_1_1_affine3.html#ga1e597cc58a82b0966165b5cf783ed852":[5,0,6,0,26],
+"class_ogre_1_1_affine3.html#ga1e597cc58a82b0966165b5cf783ed852":[5,0,6,0,27],
 "class_ogre_1_1_aligned_memory.html":[5,0,2,3],
 "class_ogre_1_1_aligned_memory.html#a63bd1c2f3f55b989331a04fccc07356a":[5,0,2,3,0],
 "class_ogre_1_1_aligned_memory.html#ad13640994e404f2befc9b7eb72f8659c":[5,0,2,3,1],
@@ -182,10 +219,11 @@ var NAVTREEINDEX11 =
 "class_ogre_1_1_animation_container.html#ac1469c7aff1e39df3e99a69ba99ff61f":[5,0,0,3,4],
 "class_ogre_1_1_animation_container.html#ae31ca8ef4dfaa0904a9f5aa05e12e455":[5,0,0,3,5],
 "class_ogre_1_1_animation_controller_function.html":[5,0,2,4],
-"class_ogre_1_1_animation_controller_function.html#a4f3ff1b57eba7e774d10b833273ec137":[5,0,2,4,1],
-"class_ogre_1_1_animation_controller_function.html#a6185e4121c1ba411a09834d3950be32e":[5,0,2,4,3],
+"class_ogre_1_1_animation_controller_function.html#a4f3ff1b57eba7e774d10b833273ec137":[5,0,2,4,2],
+"class_ogre_1_1_animation_controller_function.html#a6185e4121c1ba411a09834d3950be32e":[5,0,2,4,4],
 "class_ogre_1_1_animation_controller_function.html#a960ce93c9ad39f7a1eec98d0fce5c6c8":[5,0,2,4,0],
-"class_ogre_1_1_animation_controller_function.html#aee7d37308bff5172e3b7e58a7d31627a":[5,0,2,4,2],
+"class_ogre_1_1_animation_controller_function.html#ae5b3c53fb3ffea9f2dba73272e2a7b45":[5,0,2,4,1],
+"class_ogre_1_1_animation_controller_function.html#aee7d37308bff5172e3b7e58a7d31627a":[5,0,2,4,3],
 "class_ogre_1_1_animation_state.html":[5,0,0,4],
 "class_ogre_1_1_animation_state.html#a06594a53335afbe8ccb67331e35a32fd":[5,0,0,4,20],
 "class_ogre_1_1_animation_state.html#a0a78387f3637ec52d9eda6614adbf479":[5,0,0,4,1],
@@ -211,43 +249,5 @@ var NAVTREEINDEX11 =
 "class_ogre_1_1_animation_state.html#ae4b159b5488a0ddb7d10f0d2a4208cf5":[5,0,0,4,8],
 "class_ogre_1_1_animation_state.html#ae4fd5f5523ac2428599220ab2ff0bd59":[5,0,0,4,24],
 "class_ogre_1_1_animation_state.html#ae69ff5a068d086be7ecc048a71ed8efc":[5,0,0,4,5],
-"class_ogre_1_1_animation_state.html#aeb2b66c49de14384860c6599db5b7f30":[5,0,0,4,3],
-"class_ogre_1_1_animation_state.html#aeb306a097ff05af022b8d55a660812f2":[5,0,0,4,17],
-"class_ogre_1_1_animation_state.html#af1910e8bbaebe61359ac7edb638e5cbc":[5,0,0,4,7],
-"class_ogre_1_1_animation_state.html#af8670094f9bedeea874ca9997982829b":[5,0,0,4,12],
-"class_ogre_1_1_animation_state_controller_value.html":[5,0,0,5],
-"class_ogre_1_1_animation_state_controller_value.html#a86fae07d933638c3dfc1fd5751c4a469":[5,0,0,5,1],
-"class_ogre_1_1_animation_state_controller_value.html#a91cba7b97509704127ccbbb712a5df6c":[5,0,0,5,2],
-"class_ogre_1_1_animation_state_controller_value.html#aeb2ae06f4c83bb901a21a60e8071b2ae":[5,0,0,5,0],
-"class_ogre_1_1_animation_state_set.html":[5,0,0,6],
-"class_ogre_1_1_animation_state_set.html#a146fea0c5c0ccca83e70e9b0de2c5291":[5,0,0,6,1],
-"class_ogre_1_1_animation_state_set.html#a22d9922ebdb8b3b3d70ca7e58acbd95d":[5,0,0,6,5],
-"class_ogre_1_1_animation_state_set.html#a3651ad254b49b98e8d590da1bc22735a":[5,0,0,6,6],
-"class_ogre_1_1_animation_state_set.html#a49af4b5b62648c598fe631fda6984ea4":[5,0,0,6,7],
-"class_ogre_1_1_animation_state_set.html#a506078aa0b1b78cb3296f81d0641c82b":[5,0,0,6,15],
-"class_ogre_1_1_animation_state_set.html#a55b3e321b7cfcbccd56ca600407bfd19":[5,0,0,6,11],
-"class_ogre_1_1_animation_state_set.html#a5a3783be35f983e5cc923a5719ac69fb":[5,0,0,6,4],
-"class_ogre_1_1_animation_state_set.html#a5fa87d7359ffda15c0940ea2694aa464":[5,0,0,6,17],
-"class_ogre_1_1_animation_state_set.html#a66f959e4399f4f2d66239fadc1382503":[5,0,0,6,12],
-"class_ogre_1_1_animation_state_set.html#a7df9fa3be7dfeb3902108c9be5757cfc":[5,0,0,6,10],
-"class_ogre_1_1_animation_state_set.html#a8b578dae12588b8b82e44af331c88dde":[5,0,0,6,2],
-"class_ogre_1_1_animation_state_set.html#aa34f77e2497d0805649096655e60c2a2":[5,0,0,6,13],
-"class_ogre_1_1_animation_state_set.html#aa4ab9e1b440f5d15e91307e01d0b5a72":[5,0,0,6,8],
-"class_ogre_1_1_animation_state_set.html#aa8c6dd75b3600a357c0a4d64150817b2":[5,0,0,6,14],
-"class_ogre_1_1_animation_state_set.html#aace4ed7ea8cf68001cf3d86d6f1f0974":[5,0,0,6,16],
-"class_ogre_1_1_animation_state_set.html#ad8aa2b6241e2e6c1298055a48e3f600b":[5,0,0,6,3],
-"class_ogre_1_1_animation_state_set.html#aee2117dbc4a0615650712ca0924742e5":[5,0,0,6,18],
-"class_ogre_1_1_animation_state_set.html#aef27479f3fb8b03557d3e59547237c4f":[5,0,0,6,9],
-"class_ogre_1_1_animation_state_set.html#af10b8cc7ba08ef360f5ca9d8f99ced0a":[5,0,0,6,0],
-"class_ogre_1_1_animation_track.html":[5,0,0,7],
-"class_ogre_1_1_animation_track.html#a0209b4a0d1461af76fdfcbf31b0537f2":[5,0,0,7,1],
-"class_ogre_1_1_animation_track.html#a1acb5172b8cb3624266e743d15cc2019":[5,0,0,7,12],
-"class_ogre_1_1_animation_track.html#a28fb904ec7b101ad71fae5c6930b0d34":[5,0,0,7,2],
-"class_ogre_1_1_animation_track.html#a2fae315ab3444ab494d9b6c66280cd5b":[5,0,0,7,3],
-"class_ogre_1_1_animation_track.html#a331ce755fa99ee26c1e2091ca60cb4d9":[5,0,0,7,4],
-"class_ogre_1_1_animation_track.html#a3c8653dade6e58c26570ce8aad81b540":[5,0,0,7,6],
-"class_ogre_1_1_animation_track.html#a3e1ccd99179d804992a5224fe811c2dd":[5,0,0,7,8],
-"class_ogre_1_1_animation_track.html#a4517a1b16d6cb601754d98841bb4d7d6":[5,0,0,7,7],
-"class_ogre_1_1_animation_track.html#a48a8e96d4cb65f050dfed427f4442aa4":[5,0,0,7,10],
-"class_ogre_1_1_animation_track.html#a6f341ad134c0254f15a0cba2bbae4097":[5,0,0,7,16]
+"class_ogre_1_1_animation_state.html#aeb2b66c49de14384860c6599db5b7f30":[5,0,0,4,3]
 };
