@@ -1,5 +1,47 @@
 var NAVTREEINDEX17 =
 {
+"class_ogre_1_1_border_panel_overlay_element.html":[5,1,3,1],
+"class_ogre_1_1_border_panel_overlay_element.html#a000e571565ca93dc4ec617a32f632946":[5,1,3,1,13],
+"class_ogre_1_1_border_panel_overlay_element.html#a00b0ec54310848d495c630b7a010d748":[5,1,3,1,41],
+"class_ogre_1_1_border_panel_overlay_element.html#a04f1243431dbba1a91f4bff5e7c632fb":[5,1,3,1,45],
+"class_ogre_1_1_border_panel_overlay_element.html#a08d117bf25f011f96d81f1f4ecb25113":[5,1,3,1,138],
+"class_ogre_1_1_border_panel_overlay_element.html#a0951728a2782426b57bc346141a532dd":[5,1,3,1,18],
+"class_ogre_1_1_border_panel_overlay_element.html#a0984444e5ea957fea4880a8a2855e5d3":[5,1,3,1,103],
+"class_ogre_1_1_border_panel_overlay_element.html#a0c726a0326e8a7d9e80d030541b6bddf":[5,1,3,1,153],
+"class_ogre_1_1_border_panel_overlay_element.html#a0caeaa1d1379dec4133849d2c91e258e":[5,1,3,1,31],
+"class_ogre_1_1_border_panel_overlay_element.html#a0d5508d74e0d742ed04ba5ba6c1a7113":[5,1,3,1,108],
+"class_ogre_1_1_border_panel_overlay_element.html#a0e3fe5ec8406c5824cd4e4fa25f9e783":[5,1,3,1,127],
+"class_ogre_1_1_border_panel_overlay_element.html#a0f55da0550a7e1ab70a1c8bf598a3e20":[5,1,3,1,136],
+"class_ogre_1_1_border_panel_overlay_element.html#a142c71975a49dc2712e71b7a15bb6ad6":[5,1,3,1,76],
+"class_ogre_1_1_border_panel_overlay_element.html#a149ed9dba547535540a515c0936cc1f2":[5,1,3,1,112],
+"class_ogre_1_1_border_panel_overlay_element.html#a14e63d4c3d587b01ea94904a9e4d1c6b":[5,1,3,1,88],
+"class_ogre_1_1_border_panel_overlay_element.html#a153af53d919497af7340413866470613":[5,1,3,1,84],
+"class_ogre_1_1_border_panel_overlay_element.html#a1548c9c20d0c4e4ff2c73590681dbddb":[5,1,3,1,106],
+"class_ogre_1_1_border_panel_overlay_element.html#a1abfd6cb3ac45d219cab0c842045c06a":[5,1,3,1,37],
+"class_ogre_1_1_border_panel_overlay_element.html#a1ae2c9bb50399abf5752ab26c171d8b3":[5,1,3,1,52],
+"class_ogre_1_1_border_panel_overlay_element.html#a1b22eddee9083be54a60c09b3a129e9d":[5,1,3,1,63],
+"class_ogre_1_1_border_panel_overlay_element.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8":[5,1,3,1,142],
+"class_ogre_1_1_border_panel_overlay_element.html#a1c4711038030d7464ca3c2b60c380175":[5,1,3,1,64],
+"class_ogre_1_1_border_panel_overlay_element.html#a1cb930e3203523e799bab77cc484f589":[5,1,3,1,32],
+"class_ogre_1_1_border_panel_overlay_element.html#a1d078304c38a9f85d483fc8ed0cdf1fe":[5,1,3,1,140],
+"class_ogre_1_1_border_panel_overlay_element.html#a1d18a26a0680bd724220ea282722d48c":[5,1,3,1,100],
+"class_ogre_1_1_border_panel_overlay_element.html#a1d6627fa3a9690df18fbd0010ad161b7":[5,1,3,1,53],
+"class_ogre_1_1_border_panel_overlay_element.html#a1e819a321a51a47238428307510559b7":[5,1,3,1,86],
+"class_ogre_1_1_border_panel_overlay_element.html#a1fff3e0b4ad1470a0cb25a73779d3291":[5,1,3,1,90],
+"class_ogre_1_1_border_panel_overlay_element.html#a25345420a3a217103f2624080cb48f45":[5,1,3,1,120],
+"class_ogre_1_1_border_panel_overlay_element.html#a25a338c0ecebf4057fb0f1a60c47f22b":[5,1,3,1,54],
+"class_ogre_1_1_border_panel_overlay_element.html#a27ee755fb36de22d7866f1ca994d8391":[5,1,3,1,129],
+"class_ogre_1_1_border_panel_overlay_element.html#a2a11b6d6153cdada71a50c2fb3f13399":[5,1,3,1,73],
+"class_ogre_1_1_border_panel_overlay_element.html#a2a7bfb2c2dea0e1c13ce51d102967f61":[5,1,3,1,118],
+"class_ogre_1_1_border_panel_overlay_element.html#a2b017beabc9a6db3e556f92eb207a565":[5,1,3,1,51],
+"class_ogre_1_1_border_panel_overlay_element.html#a2ed9a2f3c1decac6286f8af974ce2ffc":[5,1,3,1,161],
+"class_ogre_1_1_border_panel_overlay_element.html#a2f770d6ba9b3d97bdc63ecf0e3888aab":[5,1,3,1,157],
+"class_ogre_1_1_border_panel_overlay_element.html#a321316349fac8be33a25b27b300b42c5":[5,1,3,1,56],
+"class_ogre_1_1_border_panel_overlay_element.html#a33d8945bd771e80d61bd3d36a32738eb":[5,1,3,1,81],
+"class_ogre_1_1_border_panel_overlay_element.html#a3477f4afc62d5bbd5f73017c210ac20a":[5,1,3,1,27],
+"class_ogre_1_1_border_panel_overlay_element.html#a34cbfdb610c9f91d01c1b4adff0844ab":[5,1,3,1,165],
+"class_ogre_1_1_border_panel_overlay_element.html#a34f87bb5dee0eeaddefa30c7251e9dd7":[5,1,3,1,19],
+"class_ogre_1_1_border_panel_overlay_element.html#a35178b40251066c1fd27d6573603638c":[5,1,3,1,121],
 "class_ogre_1_1_border_panel_overlay_element.html#a393ea3e5d74c4b93dc9bcf364e1b52e0":[5,1,3,1,50],
 "class_ogre_1_1_border_panel_overlay_element.html#a3d5e8933145d36977b8c2b64e307bc59":[5,1,3,1,151],
 "class_ogre_1_1_border_panel_overlay_element.html#a3dc69374127d00ea2c2f9f39cf2105bb":[5,1,3,1,164],
@@ -207,47 +249,5 @@ var NAVTREEINDEX17 =
 "class_ogre_1_1_box_emitter.html#a27abb24bce18934c89568cb3e10dd08f":[5,2,6,1,60],
 "class_ogre_1_1_box_emitter.html#a2ed1a99178ad112142f9ff9ac95c553e":[5,2,6,1,52],
 "class_ogre_1_1_box_emitter.html#a2fc108cba4892f8ae091ffd70a65a150":[5,2,6,1,63],
-"class_ogre_1_1_box_emitter.html#a3287cdd56f081a2e7e8a43ad802530bb":[5,2,6,1,67],
-"class_ogre_1_1_box_emitter.html#a32fb0fa2c3adb521e1f3728990472da3":[5,2,6,1,92],
-"class_ogre_1_1_box_emitter.html#a334b3e2619d23844739a29bcad603e00":[5,2,6,1,20],
-"class_ogre_1_1_box_emitter.html#a3d9141e9851a449cccf480e7a30826df":[5,2,6,1,44],
-"class_ogre_1_1_box_emitter.html#a44700655800282c23c7f3f97debfacf7":[5,2,6,1,88],
-"class_ogre_1_1_box_emitter.html#a47b1c383608e0aca4859c6ecd11d9ef5":[5,2,6,1,5],
-"class_ogre_1_1_box_emitter.html#a4a7903addb8535a17cf0d79cb43ce7dd":[5,2,6,1,59],
-"class_ogre_1_1_box_emitter.html#a4e0b837e02c70c0cfc880f83ce6b6739":[5,2,6,1,36],
-"class_ogre_1_1_box_emitter.html#a51159bb05720260843eb80fde34261fd":[5,2,6,1,57],
-"class_ogre_1_1_box_emitter.html#a58bee75a698865e094bd338ad260ff8a":[5,2,6,1,85],
-"class_ogre_1_1_box_emitter.html#a595cb72cb60c6566bee7204ef7d92ebd":[5,2,6,1,16],
-"class_ogre_1_1_box_emitter.html#a5aef511f7bcbada271780f42ccfe717e":[5,2,6,1,96],
-"class_ogre_1_1_box_emitter.html#a5b7e2e8dd8e695736a1038588c382fbe":[5,2,6,1,31],
-"class_ogre_1_1_box_emitter.html#a64d38a64642017c5ca73213b129aa8d8":[5,2,6,1,69],
-"class_ogre_1_1_box_emitter.html#a659edec094aae09a7f1325e7e8fbc29a":[5,2,6,1,23],
-"class_ogre_1_1_box_emitter.html#a6607b5a35ab594e8e5e01df766cd5462":[5,2,6,1,37],
-"class_ogre_1_1_box_emitter.html#a666a8c8c660ffc55ff338b59a416f682":[5,2,6,1,43],
-"class_ogre_1_1_box_emitter.html#a674566db12d25f32513a382a4118b5da":[5,2,6,1,42],
-"class_ogre_1_1_box_emitter.html#a691070e7cdb1ca6d61e687ca3c510123":[5,2,6,1,45],
-"class_ogre_1_1_box_emitter.html#a6a2bc4941c3c346f6d9936e447dde3c9":[5,2,6,1,79],
-"class_ogre_1_1_box_emitter.html#a7063e13cbae9dd5a667f2a05d48fdf43":[5,2,6,1,9],
-"class_ogre_1_1_box_emitter.html#a7151224f33967bb60d9bdf631cc432b9":[5,2,6,1,34],
-"class_ogre_1_1_box_emitter.html#a73fc7ce8c6dc5bba68d5da1cca779c33":[5,2,6,1,18],
-"class_ogre_1_1_box_emitter.html#a74daf160185c31ecee5481b50f976a1c":[5,2,6,1,25],
-"class_ogre_1_1_box_emitter.html#a777c4c5c065aae3d07637819300b15b5":[5,2,6,1,56],
-"class_ogre_1_1_box_emitter.html#a79a2560fdff854fce4e0daf7ebc91291":[5,2,6,1,54],
-"class_ogre_1_1_box_emitter.html#a7c3c26866ccd70672c01debaa9e398bb":[5,2,6,1,82],
-"class_ogre_1_1_box_emitter.html#a7c797e53bdbb8505739ef1923b022581":[5,2,6,1,84],
-"class_ogre_1_1_box_emitter.html#a7e54feab62fa032b0190f3817d9e3d7f":[5,2,6,1,51],
-"class_ogre_1_1_box_emitter.html#a7f442353f518bf6caae127dac6d0b6ee":[5,2,6,1,40],
-"class_ogre_1_1_box_emitter.html#a857218f119755b72b9d3afbc1d896446":[5,2,6,1,39],
-"class_ogre_1_1_box_emitter.html#a872608a91795338bb63962d696289eea":[5,2,6,1,8],
-"class_ogre_1_1_box_emitter.html#a8ada445a7c60d99d81304417a386f787":[5,2,6,1,7],
-"class_ogre_1_1_box_emitter.html#a8d8c2e2e39187abc715d911cfa802780":[5,2,6,1,24],
-"class_ogre_1_1_box_emitter.html#a8f9062c067ecb49776d4ce73cf41990d":[5,2,6,1,49],
-"class_ogre_1_1_box_emitter.html#a8f94512cf66c84a243f3cd6383bb9c68":[5,2,6,1,93],
-"class_ogre_1_1_box_emitter.html#a9194f48e306289c7f3c7f77374febb01":[5,2,6,1,55],
-"class_ogre_1_1_box_emitter.html#a93027e6a8be2be918488edf6c88217c0":[5,2,6,1,91],
-"class_ogre_1_1_box_emitter.html#a931a2be6077dd30e596f19a5f5646ba5":[5,2,6,1,97],
-"class_ogre_1_1_box_emitter.html#a95517da295f74f765f031f63b4964fdf":[5,2,6,1,58],
-"class_ogre_1_1_box_emitter.html#a96b7ceb94e86301975d9f2b47baee906":[5,2,6,1,48],
-"class_ogre_1_1_box_emitter.html#a98d3f921cd9061414149636172557d71":[5,2,6,1,29],
-"class_ogre_1_1_box_emitter.html#a9aac32f93bd149a34b809a57a9f01f8f":[5,2,6,1,75]
+"class_ogre_1_1_box_emitter.html#a3287cdd56f081a2e7e8a43ad802530bb":[5,2,6,1,67]
 };
