@@ -1,5 +1,47 @@
 var NAVTREEINDEX19 =
 {
+"class_ogre_1_1_bsp_scene_manager.html#a1b70c6f65674e3e33f88d9fb7d8bc527":[5,2,0,5,20],
+"class_ogre_1_1_bsp_scene_manager.html#a1eaa9f147fe2c97f159ffa1896a1be88":[5,2,0,5,265],
+"class_ogre_1_1_bsp_scene_manager.html#a205550aaa9967b7ee80baf44f4fe1ffd":[5,2,0,5,127],
+"class_ogre_1_1_bsp_scene_manager.html#a22b489f7b4262b530c35435527ca11ea":[5,2,0,5,231],
+"class_ogre_1_1_bsp_scene_manager.html#a22fcb8a9ddb7efe79d053a975a685111":[5,2,0,5,2],
+"class_ogre_1_1_bsp_scene_manager.html#a236f1b0c5eb684a67d04593b8e9c6a9b":[5,2,0,5,10],
+"class_ogre_1_1_bsp_scene_manager.html#a23a02fc191d8dacf508515c0116b45b1":[5,2,0,5,118],
+"class_ogre_1_1_bsp_scene_manager.html#a24754c64740724fbbe901b0455d02639":[5,2,0,5,171],
+"class_ogre_1_1_bsp_scene_manager.html#a24ad98304368771d852a5ef62eb8d277":[5,2,0,5,108],
+"class_ogre_1_1_bsp_scene_manager.html#a25cc1bb36997b722fc60efc7903f3760":[5,2,0,5,295],
+"class_ogre_1_1_bsp_scene_manager.html#a25f052046f0d421ac78a89730fd766e1":[5,2,0,5,215],
+"class_ogre_1_1_bsp_scene_manager.html#a260738557c9a32aed8d5ca14c28d300f":[5,2,0,5,1],
+"class_ogre_1_1_bsp_scene_manager.html#a272d1a76e7854e51f824f0099a4910cf":[5,2,0,5,298],
+"class_ogre_1_1_bsp_scene_manager.html#a29772b72321f0f9ffc7f2fb0b46bcbad":[5,2,0,5,64],
+"class_ogre_1_1_bsp_scene_manager.html#a29ba8a2cad151d307d04781f749e7e84":[5,2,0,5,112],
+"class_ogre_1_1_bsp_scene_manager.html#a2a86925fa4cbbb667f29473d5fd4a4c2":[5,2,0,5,158],
+"class_ogre_1_1_bsp_scene_manager.html#a2ac761cb112de51be26c54609de3c83a":[5,2,0,5,294],
+"class_ogre_1_1_bsp_scene_manager.html#a2ac8cbf2f621bc71f97d0bdffdf45259":[5,2,0,5,218],
+"class_ogre_1_1_bsp_scene_manager.html#a2b4a3f7bbd31ecd067ae017e6571da1b":[5,2,0,5,233],
+"class_ogre_1_1_bsp_scene_manager.html#a2b993e97d08dd4534ce1288c8de183e0":[5,2,0,5,208],
+"class_ogre_1_1_bsp_scene_manager.html#a2ce4075335fd6e1580cd1f293cd83a4e":[5,2,0,5,62],
+"class_ogre_1_1_bsp_scene_manager.html#a2d3831103729210e5ddd4e4e82c6044e":[5,2,0,5,268],
+"class_ogre_1_1_bsp_scene_manager.html#a2ea53a860f373185f5a46239f579a361":[5,2,0,5,104],
+"class_ogre_1_1_bsp_scene_manager.html#a2ec74da408f8eb47a84eb0a35f21450d":[5,2,0,5,90],
+"class_ogre_1_1_bsp_scene_manager.html#a326e7192cb5d4cc36c035f1a1dfa01a5":[5,2,0,5,266],
+"class_ogre_1_1_bsp_scene_manager.html#a3339b949a5f7927d80b48fb19044e1cb":[5,2,0,5,33],
+"class_ogre_1_1_bsp_scene_manager.html#a344a49c8ef3b09b290b2e14c2bfa500d":[5,2,0,5,18],
+"class_ogre_1_1_bsp_scene_manager.html#a34f3ddda75dcf75d5c5176446b3316a8":[5,2,0,5,103],
+"class_ogre_1_1_bsp_scene_manager.html#a3596ae101fe86d686cc67e9b3aad58cb":[5,2,0,5,213],
+"class_ogre_1_1_bsp_scene_manager.html#a35b475390db15397c62881e4951b9051":[5,2,0,5,19],
+"class_ogre_1_1_bsp_scene_manager.html#a35ee911c94feb9c384dd34bd3bda93d9":[5,2,0,5,167],
+"class_ogre_1_1_bsp_scene_manager.html#a35f9c0406735f847c0588c7ce90a7e4c":[5,2,0,5,172],
+"class_ogre_1_1_bsp_scene_manager.html#a361c61a0f17ac50c8fd49bc0dd3ff622":[5,2,0,5,0],
+"class_ogre_1_1_bsp_scene_manager.html#a3651971e998b578168b51ad57cc7f09e":[5,2,0,5,224],
+"class_ogre_1_1_bsp_scene_manager.html#a369ad7a1b8e0455052ea0bca0383942e":[5,2,0,5,305],
+"class_ogre_1_1_bsp_scene_manager.html#a370c23fff9cc351b150632c707a46700":[5,2,0,5,123],
+"class_ogre_1_1_bsp_scene_manager.html#a372aa23ce7f0d6c29b32e718f51b595c":[5,2,0,5,146],
+"class_ogre_1_1_bsp_scene_manager.html#a39bf64e686d94b6856d3ff06d627b61c":[5,2,0,5,186],
+"class_ogre_1_1_bsp_scene_manager.html#a39c2c5902cd0eb7e86f272ed421cb408":[5,2,0,5,199],
+"class_ogre_1_1_bsp_scene_manager.html#a3a720414f68274bb9c5026911e27135d":[5,2,0,5,3],
+"class_ogre_1_1_bsp_scene_manager.html#a3c11f4546d5bcad35fa37ad778bb5cbe":[5,2,0,5,254],
+"class_ogre_1_1_bsp_scene_manager.html#a3c41db9da4c31fe9ff423d5696c87901":[5,2,0,5,128],
 "class_ogre_1_1_bsp_scene_manager.html#a3cd49635820ce79a611199c6234aef01":[5,2,0,5,240],
 "class_ogre_1_1_bsp_scene_manager.html#a3dce9a03ecad77d52ed0a8ef0e8b742c":[5,2,0,5,111],
 "class_ogre_1_1_bsp_scene_manager.html#a3e8986eedf7c35625f4a83693754a46f":[5,2,0,5,134],
@@ -10,11 +52,12 @@ var NAVTREEINDEX19 =
 "class_ogre_1_1_bsp_scene_manager.html#a417b2f6c5273748fe22f4b6a75fe8245":[5,2,0,5,257],
 "class_ogre_1_1_bsp_scene_manager.html#a417bdd216730a8d171c3184b0d49c32e":[5,2,0,5,38],
 "class_ogre_1_1_bsp_scene_manager.html#a41b9358cdad6fd7113b2a0cad8112f67":[5,2,0,5,35],
+"class_ogre_1_1_bsp_scene_manager.html#a4222a0689cb56011c11faa9976192f11":[5,2,0,5,135],
 "class_ogre_1_1_bsp_scene_manager.html#a4249682ae2a69255ed225383d930aec1":[5,2,0,5,4],
 "class_ogre_1_1_bsp_scene_manager.html#a4257eae21878329ae84446332443366a":[5,2,0,5,152],
 "class_ogre_1_1_bsp_scene_manager.html#a436a99beba747d203841471d90e5be2e":[5,2,0,5,177],
 "class_ogre_1_1_bsp_scene_manager.html#a43c5ca986d31852a89c6e2d06a025ee3":[5,2,0,5,214],
-"class_ogre_1_1_bsp_scene_manager.html#a43d0ee887419ee93d24975b906eb2783":[5,2,0,5,302],
+"class_ogre_1_1_bsp_scene_manager.html#a43d0ee887419ee93d24975b906eb2783":[5,2,0,5,303],
 "class_ogre_1_1_bsp_scene_manager.html#a4444e8e94c01206790db4bfad8c487ea":[5,2,0,5,11],
 "class_ogre_1_1_bsp_scene_manager.html#a463538c28db2d1c3b853c4637aecb693":[5,2,0,5,92],
 "class_ogre_1_1_bsp_scene_manager.html#a46687a92d3fa8b4b106f01899a9e9025":[5,2,0,5,74],
@@ -82,6 +125,7 @@ var NAVTREEINDEX19 =
 "class_ogre_1_1_bsp_scene_manager.html#a7b0f316813a3291964abd93ca2372f3d":[5,2,0,5,149],
 "class_ogre_1_1_bsp_scene_manager.html#a7c26cdbb5703cf10a99add1f6a930ca2":[5,2,0,5,99],
 "class_ogre_1_1_bsp_scene_manager.html#a7c8ff6b5c19eb9eeef9d5a6c9fca9fe8":[5,2,0,5,107],
+"class_ogre_1_1_bsp_scene_manager.html#a7dc7403de6c07fbb0f5e8e7d5667ece0":[5,2,0,5,301],
 "class_ogre_1_1_bsp_scene_manager.html#a80690a9450039852c9dc56a07688eb8b":[5,2,0,5,161],
 "class_ogre_1_1_bsp_scene_manager.html#a81238e49e69e53ccbc650413410f3f92":[5,2,0,5,192],
 "class_ogre_1_1_bsp_scene_manager.html#a813346e505716ae5d24f714cfc4a5069":[5,2,0,5,55],
@@ -161,7 +205,6 @@ var NAVTREEINDEX19 =
 "class_ogre_1_1_bsp_scene_manager.html#ab4c2ff4f6c76f7fe0a8eae76f2a84cbfaf0fb654fb98508a564c17d3d5b2feee3":[5,2,0,5,7,0],
 "class_ogre_1_1_bsp_scene_manager.html#ab6484f3062661e421b242705dbef9054":[5,2,0,5,291],
 "class_ogre_1_1_bsp_scene_manager.html#ab7f2ff2c074c944a8fca85bc9ef0e8b8":[5,2,0,5,236],
-"class_ogre_1_1_bsp_scene_manager.html#ab804195c05873da617dcd16198a63d1c":[5,2,0,5,135],
 "class_ogre_1_1_bsp_scene_manager.html#ab8511a16f5e93699cd1dfb8bd93e98f2":[5,2,0,5,113],
 "class_ogre_1_1_bsp_scene_manager.html#ab8ebc8d2fdc6798152ac6a31282de210":[5,2,0,5,110],
 "class_ogre_1_1_bsp_scene_manager.html#abb611654fb25d3bcef44f449d1d1bfb5":[5,2,0,5,41],
@@ -170,7 +213,7 @@ var NAVTREEINDEX19 =
 "class_ogre_1_1_bsp_scene_manager.html#abd8b3284334279f65fa12b5ff2571eca":[5,2,0,5,197],
 "class_ogre_1_1_bsp_scene_manager.html#abe1ca9b5f8ea5a7256b1d0ca1a2d8f6c":[5,2,0,5,198],
 "class_ogre_1_1_bsp_scene_manager.html#abf8ee07ad398b2060f80a049a8cc579a":[5,2,0,5,91],
-"class_ogre_1_1_bsp_scene_manager.html#ac036d861c2df264375b88e9f3a407b1e":[5,2,0,5,303],
+"class_ogre_1_1_bsp_scene_manager.html#ac036d861c2df264375b88e9f3a407b1e":[5,2,0,5,304],
 "class_ogre_1_1_bsp_scene_manager.html#ac1c49622909068c8c7551d5a896ada43":[5,2,0,5,129],
 "class_ogre_1_1_bsp_scene_manager.html#ac6008a2910a810dd022e1751bcb3c38f":[5,2,0,5,281],
 "class_ogre_1_1_bsp_scene_manager.html#ac6e42c947472bf09620ef974c3ac26a5":[5,2,0,5,51],
@@ -201,53 +244,10 @@ var NAVTREEINDEX19 =
 "class_ogre_1_1_bsp_scene_manager.html#ad977a4b406ff9e941ad212fee9f46802":[5,2,0,5,212],
 "class_ogre_1_1_bsp_scene_manager.html#ad9d1a1bfe27c7ba67e5f1aa75219529f":[5,2,0,5,57],
 "class_ogre_1_1_bsp_scene_manager.html#ada03395dc13501ec3ccc65fe0c69c8ab":[5,2,0,5,162],
-"class_ogre_1_1_bsp_scene_manager.html#ada8f4ecc06b8ffe99834d8e1db66c123":[5,2,0,5,301],
+"class_ogre_1_1_bsp_scene_manager.html#ada8f4ecc06b8ffe99834d8e1db66c123":[5,2,0,5,302],
 "class_ogre_1_1_bsp_scene_manager.html#adbfddc51019b4de6e7ca7597533697f4":[5,2,0,5,63],
 "class_ogre_1_1_bsp_scene_manager.html#add34db1d0d5398ef48b0f186ef8c575f":[5,2,0,5,280],
 "class_ogre_1_1_bsp_scene_manager.html#add6959f7447251600bd189008636e887":[5,2,0,5,225],
 "class_ogre_1_1_bsp_scene_manager.html#ade2cace27566a8b42b14bb591503864f":[5,2,0,5,156],
-"class_ogre_1_1_bsp_scene_manager.html#ae062b43898ab86a6b2b3de5903965bed":[5,2,0,5,287],
-"class_ogre_1_1_bsp_scene_manager.html#ae0f8858848acb8c595f495db753facb9":[5,2,0,5,306],
-"class_ogre_1_1_bsp_scene_manager.html#ae188c7cbe7a660db8b721f54a0ede2d1":[5,2,0,5,274],
-"class_ogre_1_1_bsp_scene_manager.html#ae1a1a8b7b1a932325bc58f67fac74604":[5,2,0,5,24],
-"class_ogre_1_1_bsp_scene_manager.html#ae291393bc0c5bd48a8c6e79742180c93":[5,2,0,5,106],
-"class_ogre_1_1_bsp_scene_manager.html#ae4b6a7748dc4273fd6c160fb162c544f":[5,2,0,5,296],
-"class_ogre_1_1_bsp_scene_manager.html#ae4e9873e472d78e7595adc3cbbad643a":[5,2,0,5,76],
-"class_ogre_1_1_bsp_scene_manager.html#ae69c13aa2d87cf90bf74e5342e253894":[5,2,0,5,17],
-"class_ogre_1_1_bsp_scene_manager.html#ae7115dce2e4a2c2dc49b0996b9279a21":[5,2,0,5,276],
-"class_ogre_1_1_bsp_scene_manager.html#ae87a0ee032dd09c82fa13e503711cc2b":[5,2,0,5,114],
-"class_ogre_1_1_bsp_scene_manager.html#aea3103164ed0f27baeb67a3ae2fe429b":[5,2,0,5,67],
-"class_ogre_1_1_bsp_scene_manager.html#aea949bdea7d1547fe4316af3579b836e":[5,2,0,5,80],
-"class_ogre_1_1_bsp_scene_manager.html#aeaff7cf546903bc22c4113c1ae4a7ee4":[5,2,0,5,136],
-"class_ogre_1_1_bsp_scene_manager.html#aeb00e5cde673e9bcf74ec69027cf8039":[5,2,0,5,305],
-"class_ogre_1_1_bsp_scene_manager.html#aebb644c23f059b8bfa3702356d19c6be":[5,2,0,5,117],
-"class_ogre_1_1_bsp_scene_manager.html#aec115af3cb3741397c4bdbf468cb010b":[5,2,0,5,87],
-"class_ogre_1_1_bsp_scene_manager.html#aeca662aaa6dc25f7115ef1c675e34485":[5,2,0,5,204],
-"class_ogre_1_1_bsp_scene_manager.html#aedd1260e1997578aa6dc887d12e16fd5":[5,2,0,5,253],
-"class_ogre_1_1_bsp_scene_manager.html#aef6a32233813f424dcc1803167fa8d8c":[5,2,0,5,83],
-"class_ogre_1_1_bsp_scene_manager.html#aef6d26cb64e7a1984ebff9b56c45c6e5":[5,2,0,5,44],
-"class_ogre_1_1_bsp_scene_manager.html#af1a5829a519ed4c752abd7619685d67b":[5,2,0,5,227],
-"class_ogre_1_1_bsp_scene_manager.html#af1ff02f94ffe6e128f9e9b179737c652":[5,2,0,5,170],
-"class_ogre_1_1_bsp_scene_manager.html#af215cf844dc1f3a2cb67b2149938847d":[5,2,0,5,47],
-"class_ogre_1_1_bsp_scene_manager.html#af24677a56a91713c40c3bdb9025da38d":[5,2,0,5,292],
-"class_ogre_1_1_bsp_scene_manager.html#af269d1bd931e309ef0d8816fe13e300b":[5,2,0,5,39],
-"class_ogre_1_1_bsp_scene_manager.html#af32931f7a0eaed595c5dfe24b84f37b4":[5,2,0,5,141],
-"class_ogre_1_1_bsp_scene_manager.html#af32fab74832905ca7c206f81c88f24fa":[5,2,0,5,206],
-"class_ogre_1_1_bsp_scene_manager.html#af3f5c14031ae9126a0c746028f9edb5c":[5,2,0,5,187],
-"class_ogre_1_1_bsp_scene_manager.html#af44261df34c54464203319f67c06a7bb":[5,2,0,5,283],
-"class_ogre_1_1_bsp_scene_manager.html#af54ce36272c2b70a1ceeb77ace86eb44":[5,2,0,5,139],
-"class_ogre_1_1_bsp_scene_manager.html#af55b7d8cf3daf68db0266139faf73492":[5,2,0,5,286],
-"class_ogre_1_1_bsp_scene_manager.html#af55b958c50f23943eca3132c8f154147":[5,2,0,5,22],
-"class_ogre_1_1_bsp_scene_manager.html#af5bab37a967b021bb03c3c5d840b56ea":[5,2,0,5,243],
-"class_ogre_1_1_bsp_scene_manager.html#af5efe579331ee28f3cbe3919db52751f":[5,2,0,5,190],
-"class_ogre_1_1_bsp_scene_manager.html#af63c901b00fbf75746a00dad7e124065":[5,2,0,5,246],
-"class_ogre_1_1_bsp_scene_manager.html#af6c350b864e2bca3132abfd05b9a4b5e":[5,2,0,5,210],
-"class_ogre_1_1_bsp_scene_manager.html#afb393cca49de8b928f7dd60838047185":[5,2,0,5,59],
-"class_ogre_1_1_bsp_scene_manager.html#afbed035d6e010f7df4727b2ff76e0750":[5,2,0,5,16],
-"class_ogre_1_1_bsp_scene_manager.html#afce67977a494e9d9314530c0edeb18eb":[5,2,0,5,98],
-"class_ogre_1_1_bsp_scene_manager_factory.html":[5,2,0,6],
-"class_ogre_1_1_bsp_scene_manager_factory.html#a00c4e589af4d4dabea98be3556c71382":[5,2,0,6,5],
-"class_ogre_1_1_bsp_scene_manager_factory.html#a3e376c2843080b32350e6e894460edee":[5,2,0,6,2],
-"class_ogre_1_1_bsp_scene_manager_factory.html#ab780ae3c79b078808915b7bdf14e4814":[5,2,0,6,3],
-"class_ogre_1_1_bsp_scene_manager_factory.html#ac3cfb57b3ddfcff9c72723d62df466e4":[5,2,0,6,0]
+"class_ogre_1_1_bsp_scene_manager.html#ae062b43898ab86a6b2b3de5903965bed":[5,2,0,5,287]
 };
