@@ -1,8 +1,53 @@
 var NAVTREEINDEX22 =
 {
-"class_ogre_1_1_cg_program.html#ae0a0007de944eb3c2f933a372a752b35":[5,2,1,1,67],
+"class_ogre_1_1_cg_program.html#a463bffd1f68fc8ae3c29d64402e9ca8d":[5,2,1,1,46],
+"class_ogre_1_1_cg_program.html#a5016aec1762b026997ddd346775879ef":[5,2,1,1,57],
+"class_ogre_1_1_cg_program.html#a5513ffce404b14cff72846318b018d32":[5,2,1,1,70],
+"class_ogre_1_1_cg_program.html#a5b9074b10dd674d98666fee888cd6bb3":[5,2,1,1,12],
+"class_ogre_1_1_cg_program.html#a60ce96525ac730a0f7b466ed287beef3":[5,2,1,1,67],
+"class_ogre_1_1_cg_program.html#a62ecd906ba236975ddec42c62d0b4e2b":[5,2,1,1,30],
+"class_ogre_1_1_cg_program.html#a65a32235ed550af62066095e5e7735b5":[5,2,1,1,6],
+"class_ogre_1_1_cg_program.html#a65a86c6f911a8ac4b0c6d7366fb44f26":[5,2,1,1,26],
+"class_ogre_1_1_cg_program.html#a699d1c851f494a8d5d23d23b695ceb47":[5,2,1,1,56],
+"class_ogre_1_1_cg_program.html#a6e4126e3d4bdc85eb3bfb4530c8e8249":[5,2,1,1,48],
+"class_ogre_1_1_cg_program.html#a74138c0203835513613af73cdb08890d":[5,2,1,1,64],
+"class_ogre_1_1_cg_program.html#a74fe58cd0a7dcfcc55902fc3d9890b82":[5,2,1,1,33],
+"class_ogre_1_1_cg_program.html#a7b7db741c7eab2838fd53149c41357e5":[5,2,1,1,36],
+"class_ogre_1_1_cg_program.html#a7ce0be99072f2ffd6055cd3bbd20b625":[5,2,1,1,25],
+"class_ogre_1_1_cg_program.html#a7e248a1cca0662418d4ab3f63c2e7cf6":[5,2,1,1,76],
+"class_ogre_1_1_cg_program.html#a843c706f65d219c1d04b8aeacc4bd3c8":[5,2,1,1,43],
+"class_ogre_1_1_cg_program.html#a848bf4164963cf8c0435c972eb717e0f":[5,2,1,1,44],
+"class_ogre_1_1_cg_program.html#a84c3904bfaeeb1166dbca41e0c9f3b29":[5,2,1,1,49],
+"class_ogre_1_1_cg_program.html#a86dfdb6d47afc2196ceaae0751942883":[5,2,1,1,15],
+"class_ogre_1_1_cg_program.html#a8d265ebc2472f77cf9675dec005a123a":[5,2,1,1,34],
+"class_ogre_1_1_cg_program.html#a8eb34a9034aab62fd537c021a79e3366":[5,2,1,1,58],
+"class_ogre_1_1_cg_program.html#a8f541900f7e1f73f4c313a732199029a":[5,2,1,1,59],
+"class_ogre_1_1_cg_program.html#a8fe80144b24cde184f0a07f6f3f290d1":[5,2,1,1,24],
+"class_ogre_1_1_cg_program.html#a9461e01449c3773e502cb5071bbca2ae":[5,2,1,1,13],
+"class_ogre_1_1_cg_program.html#a94fbe95dc398989b4de6d981a17fbc6d":[5,2,1,1,20],
+"class_ogre_1_1_cg_program.html#a9584e7691cce3a52b8d26e4540359892":[5,2,1,1,21],
+"class_ogre_1_1_cg_program.html#a9aac32f93bd149a34b809a57a9f01f8f":[5,2,1,1,86],
+"class_ogre_1_1_cg_program.html#a9bb5c2cd8a2d4e76794c7596d0c9d57e":[5,2,1,1,18],
+"class_ogre_1_1_cg_program.html#aa31bef1bfaa87731622e56f11b548e27":[5,2,1,1,60],
+"class_ogre_1_1_cg_program.html#aa448e3603f9f6cad8cfe40818888227a":[5,2,1,1,27],
+"class_ogre_1_1_cg_program.html#aa5d6f3f7e73b77b233fc62b11f270e4d":[5,2,1,1,73],
+"class_ogre_1_1_cg_program.html#aa68664db6b8723dc198beef3d21d4ef5":[5,2,1,1,79],
+"class_ogre_1_1_cg_program.html#aaaf0cd27fd6604cc644e66f101844f08":[5,2,1,1,14],
+"class_ogre_1_1_cg_program.html#aad68d8b18faad14e8286a67527094654":[5,2,1,1,88],
+"class_ogre_1_1_cg_program.html#aaf3746937cd11864f53bc1c3b4437541":[5,2,1,1,81],
+"class_ogre_1_1_cg_program.html#aaf63d096584ac7d97fe1d1b0226c9561":[5,2,1,1,80],
+"class_ogre_1_1_cg_program.html#ab6e377a3964d566ea112fe63bf1d7678":[5,2,1,1,74],
+"class_ogre_1_1_cg_program.html#abf8f87f03e2d3b147b7f28c76c1307a7":[5,2,1,1,31],
+"class_ogre_1_1_cg_program.html#ac281d547b47b872fe35e1e60fe07612a":[5,2,1,1,29],
+"class_ogre_1_1_cg_program.html#ac7b2745e88eabb52b640a77f03e0f896":[5,2,1,1,37],
+"class_ogre_1_1_cg_program.html#acd74bfad569b567e99cfe44cb2bb99ad":[5,2,1,1,10],
+"class_ogre_1_1_cg_program.html#ad37956c9bababb03b8ce7aaf13d0f39b":[5,2,1,1,32],
+"class_ogre_1_1_cg_program.html#ad4b984bfbf148ddb3310b3d0ba8a9d5d":[5,2,1,1,84],
+"class_ogre_1_1_cg_program.html#ade85e4d5579519e4117a84789c0ae8fd":[5,2,1,1,77],
+"class_ogre_1_1_cg_program.html#ae0630743f8c509bc341d294ebfc433f4":[5,2,1,1,53],
+"class_ogre_1_1_cg_program.html#ae0a0007de944eb3c2f933a372a752b35":[5,2,1,1,68],
 "class_ogre_1_1_cg_program.html#ae376230400171f70c3270f67f476b1bf":[5,2,1,1,23],
-"class_ogre_1_1_cg_program.html#ae3e13925bde11db245f6c9bbf5031a93":[5,2,1,1,81],
+"class_ogre_1_1_cg_program.html#ae3e13925bde11db245f6c9bbf5031a93":[5,2,1,1,82],
 "class_ogre_1_1_cg_program.html#ae4968f949a99e5e10f82bfc904479bd5":[5,2,1,1,11],
 "class_ogre_1_1_cg_program.html#aeaa52d1e75245cee8186841eb983a0da":[5,2,1,1,17],
 "class_ogre_1_1_cg_program.html#aef3513510b1e8d34dc95f28b589e7b02":[5,2,1,1,8],
@@ -11,7 +56,7 @@ var NAVTREEINDEX22 =
 "class_ogre_1_1_cg_program.html#af2b6c0ff81145fa460079c716e0ba84e":[5,2,1,1,40],
 "class_ogre_1_1_cg_program.html#af337509a5342cb707df4df78337756ae":[5,2,1,1,42],
 "class_ogre_1_1_cg_program.html#af420c447afb13728b4ddfcb8d8d7d812":[5,2,1,1,52],
-"class_ogre_1_1_cg_program.html#afcb4a61b965600a67ca2c2f060821db9":[5,2,1,1,77],
+"class_ogre_1_1_cg_program.html#afcb4a61b965600a67ca2c2f060821db9":[5,2,1,1,78],
 "class_ogre_1_1_cg_program_1_1_cmd_args.html":[5,2,1,1,0],
 "class_ogre_1_1_cg_program_1_1_cmd_args.html#a4d20dfa73d5b6f13c078999b79271c4e":[5,2,1,1,0,1],
 "class_ogre_1_1_cg_program_1_1_cmd_args.html#a9ad1f0e009c56553ff19116413999b01":[5,2,1,1,0,0],
@@ -156,98 +201,53 @@ var NAVTREEINDEX22 =
 "class_ogre_1_1_colour_fader_affector_1_1_cmd_red_adjust.html":[5,2,6,2,3],
 "class_ogre_1_1_colour_fader_affector_1_1_cmd_red_adjust.html#a642964b6d6530d4808866bb0d56e5b83":[5,2,6,2,3,0],
 "class_ogre_1_1_colour_fader_affector_1_1_cmd_red_adjust.html#ae1a6474819a56265737e7bfd49b680db":[5,2,6,2,3,1],
-"class_ogre_1_1_colour_fader_affector_factory.html":[7,0,0,72],
-"class_ogre_1_1_colour_fader_affector_factory.html#a073f267f4efff156cac2d0a2ef40f7dd":[7,0,0,72,0],
-"class_ogre_1_1_colour_fader_affector_factory2.html":[7,0,0,73],
-"class_ogre_1_1_colour_fader_affector_factory2.html#a073f267f4efff156cac2d0a2ef40f7dd":[7,0,0,73,0],
-"class_ogre_1_1_colour_image_affector.html":[7,0,0,74],
-"class_ogre_1_1_colour_image_affector.html#a08d117bf25f011f96d81f1f4ecb25113":[7,0,0,74,10],
-"class_ogre_1_1_colour_image_affector.html#a0f55da0550a7e1ab70a1c8bf598a3e20":[7,0,0,74,8],
-"class_ogre_1_1_colour_image_affector.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8":[7,0,0,74,14],
-"class_ogre_1_1_colour_image_affector.html#a1d078304c38a9f85d483fc8ed0cdf1fe":[7,0,0,74,12],
-"class_ogre_1_1_colour_image_affector.html#a1f75f89834ef18b62b909b4682e6a812":[7,0,0,74,15],
-"class_ogre_1_1_colour_image_affector.html#a2fb5b54b08efe8a456d4e57dfa7860d4":[7,0,0,74,4],
-"class_ogre_1_1_colour_image_affector.html#a52df9990e8c3cdeda702bcefc77f67d6":[7,0,0,74,5],
-"class_ogre_1_1_colour_image_affector.html#a7118e0cf5c7cefcbbf004580add48ae5":[7,0,0,74,1],
-"class_ogre_1_1_colour_image_affector.html#a984fc468041419661aa75af91d0d2757":[7,0,0,74,2],
-"class_ogre_1_1_colour_image_affector.html#a9aac32f93bd149a34b809a57a9f01f8f":[7,0,0,74,11],
-"class_ogre_1_1_colour_image_affector.html#a9c00c2785abad52b3c006988196a2cd4":[7,0,0,74,3],
-"class_ogre_1_1_colour_image_affector.html#aad68d8b18faad14e8286a67527094654":[7,0,0,74,13],
-"class_ogre_1_1_colour_image_affector.html#ab38dc9df81b23a9b041b56d7329cb5b9":[7,0,0,74,6],
-"class_ogre_1_1_colour_image_affector.html#ad4b984bfbf148ddb3310b3d0ba8a9d5d":[7,0,0,74,9],
-"class_ogre_1_1_colour_image_affector.html#ae3e13925bde11db245f6c9bbf5031a93":[7,0,0,74,7],
-"class_ogre_1_1_colour_image_affector_1_1_cmd_image_adjust.html":[7,0,0,74,0],
-"class_ogre_1_1_colour_image_affector_1_1_cmd_image_adjust.html#a73b813ac40e8327d3e67d33aeb7264c9":[7,0,0,74,0,0],
-"class_ogre_1_1_colour_image_affector_1_1_cmd_image_adjust.html#a974c2899b3b9e87f09cc583c11f7be99":[7,0,0,74,0,1],
-"class_ogre_1_1_colour_image_affector_factory.html":[7,0,0,75],
-"class_ogre_1_1_colour_image_affector_factory.html#a073f267f4efff156cac2d0a2ef40f7dd":[7,0,0,75,0],
-"class_ogre_1_1_colour_interpolator_affector.html":[7,0,0,76],
-"class_ogre_1_1_colour_interpolator_affector.html#a055f5f5bbe49e66d40c84c257e78b340":[7,0,0,76,19],
-"class_ogre_1_1_colour_interpolator_affector.html#a08d117bf25f011f96d81f1f4ecb25113":[7,0,0,76,14],
-"class_ogre_1_1_colour_interpolator_affector.html#a0f55da0550a7e1ab70a1c8bf598a3e20":[7,0,0,76,12],
-"class_ogre_1_1_colour_interpolator_affector.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8":[7,0,0,76,18],
-"class_ogre_1_1_colour_interpolator_affector.html#a1d078304c38a9f85d483fc8ed0cdf1fe":[7,0,0,76,16],
-"class_ogre_1_1_colour_interpolator_affector.html#a23342275feed700c10a601e5edb17152":[7,0,0,76,3],
-"class_ogre_1_1_colour_interpolator_affector.html#a28d59576dcb488c86373eb74d6f0e1ed":[7,0,0,76,4],
-"class_ogre_1_1_colour_interpolator_affector.html#a3534e0793f6d1aa89477c58e16a822a9":[7,0,0,76,5],
-"class_ogre_1_1_colour_interpolator_affector.html#a4ebe10757356bf52a3debdfffa4c9b80":[7,0,0,76,7],
-"class_ogre_1_1_colour_interpolator_affector.html#a5f401d9023e7bb484ff3ff49e70c9510":[7,0,0,76,9],
-"class_ogre_1_1_colour_interpolator_affector.html#a7f3dfd3656eb976353b98ed34319d60a":[7,0,0,76,8],
-"class_ogre_1_1_colour_interpolator_affector.html#a9aac32f93bd149a34b809a57a9f01f8f":[7,0,0,76,15],
-"class_ogre_1_1_colour_interpolator_affector.html#aad68d8b18faad14e8286a67527094654":[7,0,0,76,17],
-"class_ogre_1_1_colour_interpolator_affector.html#ab38dc9df81b23a9b041b56d7329cb5b9":[7,0,0,76,10],
-"class_ogre_1_1_colour_interpolator_affector.html#ad49b2e241fcbe4e8061135e58b3d6bf3":[7,0,0,76,20],
-"class_ogre_1_1_colour_interpolator_affector.html#ad4b984bfbf148ddb3310b3d0ba8a9d5d":[7,0,0,76,13],
-"class_ogre_1_1_colour_interpolator_affector.html#ae3e13925bde11db245f6c9bbf5031a93":[7,0,0,76,11],
-"class_ogre_1_1_colour_interpolator_affector.html#ae62b5c03df14079e3c375612efb823fc":[7,0,0,76,6],
-"class_ogre_1_1_colour_interpolator_affector.html#af0805a4befafbcdd9e26f53095639683a8bf32ea3e3c96b8616c44bdf5d47fb28":[7,0,0,76,2],
-"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_colour_adjust.html":[7,0,0,76,0],
-"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_colour_adjust.html#a2c63d0f346cb31156d7fccc5029e9724":[7,0,0,76,0,2],
-"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_colour_adjust.html#a374c2c852858ed7d95de755b6e31fbe8":[7,0,0,76,0,0],
-"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_colour_adjust.html#a9e638b6b97f5c2a7013738d9636b0e4f":[7,0,0,76,0,1],
-"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_time_adjust.html":[7,0,0,76,1],
-"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_time_adjust.html#a2864f03f51a1402c01eaa9e84a9e6fbd":[7,0,0,76,1,2],
-"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_time_adjust.html#a582c637990caf9c9d7230ff6fb5b36c0":[7,0,0,76,1,0],
-"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_time_adjust.html#ac0ebafd72c0d0809494fa5fa224c97be":[7,0,0,76,1,1],
-"class_ogre_1_1_colour_interpolator_affector_factory.html":[7,0,0,77],
-"class_ogre_1_1_colour_interpolator_affector_factory.html#a073f267f4efff156cac2d0a2ef40f7dd":[7,0,0,77,0],
-"class_ogre_1_1_colour_value.html":[5,0,2,10],
-"class_ogre_1_1_colour_value.html#a00384a789ac354ea8dd252c62cb17aa4":[5,0,2,10,36],
-"class_ogre_1_1_colour_value.html#a11c1455b2d4bc0bb0fc4fb20ba6fa099":[5,0,2,10,28],
-"class_ogre_1_1_colour_value.html#a122a85bcbd72a99321225fc0decd9e6e":[5,0,2,10,31],
-"class_ogre_1_1_colour_value.html#a13fbd050af26b8bd549ccb46aa699e07":[5,0,2,10,39],
-"class_ogre_1_1_colour_value.html#a170729634175d1cea8bd8c882bdde71e":[5,0,2,10,5],
-"class_ogre_1_1_colour_value.html#a1cf6b673afb17fe889e4255a938c3cbb":[5,0,2,10,6],
-"class_ogre_1_1_colour_value.html#a21875c1d92c3ad0cba9cafd5776f42a0":[5,0,2,10,11],
-"class_ogre_1_1_colour_value.html#a27b26fbfa1098376c47e337192d04f27":[5,0,2,10,4],
-"class_ogre_1_1_colour_value.html#a3595487122e676dae5786151b169e213":[5,0,2,10,8],
-"class_ogre_1_1_colour_value.html#a3d17eedbff96cef8dbd4414183e15cb3":[5,0,2,10,26],
-"class_ogre_1_1_colour_value.html#a435d20368c31728dea21469d1db036f6":[5,0,2,10,21],
-"class_ogre_1_1_colour_value.html#a438810466e8d1c29eb6b84f372ceb2e7":[5,0,2,10,3],
-"class_ogre_1_1_colour_value.html#a4825d1fb89ea5aae7f2e18e108aa7f23":[5,0,2,10,2],
-"class_ogre_1_1_colour_value.html#a4d74a64ed7b9e2c1235a05bc28d67f7b":[5,0,2,10,16],
-"class_ogre_1_1_colour_value.html#a5b0ed5d4289ec1f56295380a0a334e4f":[5,0,2,10,30],
-"class_ogre_1_1_colour_value.html#a5dde8a74df3cbfd55cb0e5ca90aafafe":[5,0,2,10,15],
-"class_ogre_1_1_colour_value.html#a67ef25ecd0fa97e7e51e5bd87b29ae65":[5,0,2,10,37],
-"class_ogre_1_1_colour_value.html#a6e086633637e335238d517e0ec9f2cd2":[5,0,2,10,38],
-"class_ogre_1_1_colour_value.html#a788549742c1f030184c53008423c7b9c":[5,0,2,10,19],
-"class_ogre_1_1_colour_value.html#a7c80a19ac61f97f217d5b39d8f1dd39b":[5,0,2,10,1],
-"class_ogre_1_1_colour_value.html#a7ced6ef07e9a1e6de8ea50ef824ed9b1":[5,0,2,10,10],
-"class_ogre_1_1_colour_value.html#a7f86f695818890ba2f857618b1af9f59":[5,0,2,10,9],
-"class_ogre_1_1_colour_value.html#a7f8a06f2a9dd645417c36b560f496c1a":[5,0,2,10,33],
-"class_ogre_1_1_colour_value.html#a854058a76927880ae345ac1c465f9713":[5,0,2,10,41],
-"class_ogre_1_1_colour_value.html#a8638135228e5ddcd1dc7db320542cf72":[5,0,2,10,17],
-"class_ogre_1_1_colour_value.html#a8bf64c97ca14f64127cb3f5f95e856cf":[5,0,2,10,20],
-"class_ogre_1_1_colour_value.html#a8da50314432c59dee0aa3e6a72183e34":[5,0,2,10,23],
-"class_ogre_1_1_colour_value.html#a8eba66b2908f44f00f8d9c9ec25877de":[5,0,2,10,34],
-"class_ogre_1_1_colour_value.html#aa8bbc191b3de291abe02fce7e0d619c2":[5,0,2,10,12],
-"class_ogre_1_1_colour_value.html#aae078d77b654f76e3b760174f93474ec":[5,0,2,10,40],
-"class_ogre_1_1_colour_value.html#aaf5cc43741699cd3c0c7e81a1dc349a2":[5,0,2,10,7],
-"class_ogre_1_1_colour_value.html#ab9c2a36f53ac599850f1cf8b822f750d":[5,0,2,10,35],
-"class_ogre_1_1_colour_value.html#abbc9a8f5cc1c054eb5b4633d6b0b2262":[5,0,2,10,24],
-"class_ogre_1_1_colour_value.html#abc5d5f80d4d99438863cc808169283b5":[5,0,2,10,32],
-"class_ogre_1_1_colour_value.html#ac8e68543a87fcc6e1c0789c052fa45ba":[5,0,2,10,13],
-"class_ogre_1_1_colour_value.html#acc033c4828ad9f7469269933d24850f5":[5,0,2,10,0],
-"class_ogre_1_1_colour_value.html#ad33e4ae6c7e6d223545613c4991c91ed":[5,0,2,10,22],
-"class_ogre_1_1_colour_value.html#ae256d6a81e87d0f33a0c27c10d6b78f6":[5,0,2,10,27]
+"class_ogre_1_1_colour_fader_affector_factory.html":[7,0,0,73],
+"class_ogre_1_1_colour_fader_affector_factory.html#a073f267f4efff156cac2d0a2ef40f7dd":[7,0,0,73,0],
+"class_ogre_1_1_colour_fader_affector_factory2.html":[7,0,0,74],
+"class_ogre_1_1_colour_fader_affector_factory2.html#a073f267f4efff156cac2d0a2ef40f7dd":[7,0,0,74,0],
+"class_ogre_1_1_colour_image_affector.html":[7,0,0,75],
+"class_ogre_1_1_colour_image_affector.html#a08d117bf25f011f96d81f1f4ecb25113":[7,0,0,75,10],
+"class_ogre_1_1_colour_image_affector.html#a0f55da0550a7e1ab70a1c8bf598a3e20":[7,0,0,75,8],
+"class_ogre_1_1_colour_image_affector.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8":[7,0,0,75,14],
+"class_ogre_1_1_colour_image_affector.html#a1d078304c38a9f85d483fc8ed0cdf1fe":[7,0,0,75,12],
+"class_ogre_1_1_colour_image_affector.html#a1f75f89834ef18b62b909b4682e6a812":[7,0,0,75,15],
+"class_ogre_1_1_colour_image_affector.html#a2fb5b54b08efe8a456d4e57dfa7860d4":[7,0,0,75,4],
+"class_ogre_1_1_colour_image_affector.html#a52df9990e8c3cdeda702bcefc77f67d6":[7,0,0,75,5],
+"class_ogre_1_1_colour_image_affector.html#a7118e0cf5c7cefcbbf004580add48ae5":[7,0,0,75,1],
+"class_ogre_1_1_colour_image_affector.html#a984fc468041419661aa75af91d0d2757":[7,0,0,75,2],
+"class_ogre_1_1_colour_image_affector.html#a9aac32f93bd149a34b809a57a9f01f8f":[7,0,0,75,11],
+"class_ogre_1_1_colour_image_affector.html#a9c00c2785abad52b3c006988196a2cd4":[7,0,0,75,3],
+"class_ogre_1_1_colour_image_affector.html#aad68d8b18faad14e8286a67527094654":[7,0,0,75,13],
+"class_ogre_1_1_colour_image_affector.html#ab38dc9df81b23a9b041b56d7329cb5b9":[7,0,0,75,6],
+"class_ogre_1_1_colour_image_affector.html#ad4b984bfbf148ddb3310b3d0ba8a9d5d":[7,0,0,75,9],
+"class_ogre_1_1_colour_image_affector.html#ae3e13925bde11db245f6c9bbf5031a93":[7,0,0,75,7],
+"class_ogre_1_1_colour_image_affector_1_1_cmd_image_adjust.html":[7,0,0,75,0],
+"class_ogre_1_1_colour_image_affector_1_1_cmd_image_adjust.html#a73b813ac40e8327d3e67d33aeb7264c9":[7,0,0,75,0,0],
+"class_ogre_1_1_colour_image_affector_1_1_cmd_image_adjust.html#a974c2899b3b9e87f09cc583c11f7be99":[7,0,0,75,0,1],
+"class_ogre_1_1_colour_image_affector_factory.html":[7,0,0,76],
+"class_ogre_1_1_colour_image_affector_factory.html#a073f267f4efff156cac2d0a2ef40f7dd":[7,0,0,76,0],
+"class_ogre_1_1_colour_interpolator_affector.html":[7,0,0,77],
+"class_ogre_1_1_colour_interpolator_affector.html#a055f5f5bbe49e66d40c84c257e78b340":[7,0,0,77,19],
+"class_ogre_1_1_colour_interpolator_affector.html#a08d117bf25f011f96d81f1f4ecb25113":[7,0,0,77,14],
+"class_ogre_1_1_colour_interpolator_affector.html#a0f55da0550a7e1ab70a1c8bf598a3e20":[7,0,0,77,12],
+"class_ogre_1_1_colour_interpolator_affector.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8":[7,0,0,77,18],
+"class_ogre_1_1_colour_interpolator_affector.html#a1d078304c38a9f85d483fc8ed0cdf1fe":[7,0,0,77,16],
+"class_ogre_1_1_colour_interpolator_affector.html#a23342275feed700c10a601e5edb17152":[7,0,0,77,3],
+"class_ogre_1_1_colour_interpolator_affector.html#a28d59576dcb488c86373eb74d6f0e1ed":[7,0,0,77,4],
+"class_ogre_1_1_colour_interpolator_affector.html#a3534e0793f6d1aa89477c58e16a822a9":[7,0,0,77,5],
+"class_ogre_1_1_colour_interpolator_affector.html#a4ebe10757356bf52a3debdfffa4c9b80":[7,0,0,77,7],
+"class_ogre_1_1_colour_interpolator_affector.html#a5f401d9023e7bb484ff3ff49e70c9510":[7,0,0,77,9],
+"class_ogre_1_1_colour_interpolator_affector.html#a7f3dfd3656eb976353b98ed34319d60a":[7,0,0,77,8],
+"class_ogre_1_1_colour_interpolator_affector.html#a9aac32f93bd149a34b809a57a9f01f8f":[7,0,0,77,15],
+"class_ogre_1_1_colour_interpolator_affector.html#aad68d8b18faad14e8286a67527094654":[7,0,0,77,17],
+"class_ogre_1_1_colour_interpolator_affector.html#ab38dc9df81b23a9b041b56d7329cb5b9":[7,0,0,77,10],
+"class_ogre_1_1_colour_interpolator_affector.html#ad49b2e241fcbe4e8061135e58b3d6bf3":[7,0,0,77,20],
+"class_ogre_1_1_colour_interpolator_affector.html#ad4b984bfbf148ddb3310b3d0ba8a9d5d":[7,0,0,77,13],
+"class_ogre_1_1_colour_interpolator_affector.html#ae3e13925bde11db245f6c9bbf5031a93":[7,0,0,77,11],
+"class_ogre_1_1_colour_interpolator_affector.html#ae62b5c03df14079e3c375612efb823fc":[7,0,0,77,6],
+"class_ogre_1_1_colour_interpolator_affector.html#af0805a4befafbcdd9e26f53095639683a8bf32ea3e3c96b8616c44bdf5d47fb28":[7,0,0,77,2],
+"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_colour_adjust.html":[7,0,0,77,0],
+"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_colour_adjust.html#a2c63d0f346cb31156d7fccc5029e9724":[7,0,0,77,0,2],
+"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_colour_adjust.html#a374c2c852858ed7d95de755b6e31fbe8":[7,0,0,77,0,0],
+"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_colour_adjust.html#a9e638b6b97f5c2a7013738d9636b0e4f":[7,0,0,77,0,1]
 };
