@@ -1,5 +1,50 @@
 var NAVTREEINDEX23 =
 {
+"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_time_adjust.html":[7,0,0,77,1],
+"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_time_adjust.html#a2864f03f51a1402c01eaa9e84a9e6fbd":[7,0,0,77,1,2],
+"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_time_adjust.html#a582c637990caf9c9d7230ff6fb5b36c0":[7,0,0,77,1,0],
+"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_time_adjust.html#ac0ebafd72c0d0809494fa5fa224c97be":[7,0,0,77,1,1],
+"class_ogre_1_1_colour_interpolator_affector_factory.html":[7,0,0,78],
+"class_ogre_1_1_colour_interpolator_affector_factory.html#a073f267f4efff156cac2d0a2ef40f7dd":[7,0,0,78,0],
+"class_ogre_1_1_colour_value.html":[5,0,2,10],
+"class_ogre_1_1_colour_value.html#a00384a789ac354ea8dd252c62cb17aa4":[5,0,2,10,36],
+"class_ogre_1_1_colour_value.html#a11c1455b2d4bc0bb0fc4fb20ba6fa099":[5,0,2,10,28],
+"class_ogre_1_1_colour_value.html#a122a85bcbd72a99321225fc0decd9e6e":[5,0,2,10,31],
+"class_ogre_1_1_colour_value.html#a13fbd050af26b8bd549ccb46aa699e07":[5,0,2,10,39],
+"class_ogre_1_1_colour_value.html#a170729634175d1cea8bd8c882bdde71e":[5,0,2,10,5],
+"class_ogre_1_1_colour_value.html#a1cf6b673afb17fe889e4255a938c3cbb":[5,0,2,10,6],
+"class_ogre_1_1_colour_value.html#a21875c1d92c3ad0cba9cafd5776f42a0":[5,0,2,10,11],
+"class_ogre_1_1_colour_value.html#a27b26fbfa1098376c47e337192d04f27":[5,0,2,10,4],
+"class_ogre_1_1_colour_value.html#a3595487122e676dae5786151b169e213":[5,0,2,10,8],
+"class_ogre_1_1_colour_value.html#a3d17eedbff96cef8dbd4414183e15cb3":[5,0,2,10,26],
+"class_ogre_1_1_colour_value.html#a435d20368c31728dea21469d1db036f6":[5,0,2,10,21],
+"class_ogre_1_1_colour_value.html#a438810466e8d1c29eb6b84f372ceb2e7":[5,0,2,10,3],
+"class_ogre_1_1_colour_value.html#a4825d1fb89ea5aae7f2e18e108aa7f23":[5,0,2,10,2],
+"class_ogre_1_1_colour_value.html#a4d74a64ed7b9e2c1235a05bc28d67f7b":[5,0,2,10,16],
+"class_ogre_1_1_colour_value.html#a5b0ed5d4289ec1f56295380a0a334e4f":[5,0,2,10,30],
+"class_ogre_1_1_colour_value.html#a5dde8a74df3cbfd55cb0e5ca90aafafe":[5,0,2,10,15],
+"class_ogre_1_1_colour_value.html#a67ef25ecd0fa97e7e51e5bd87b29ae65":[5,0,2,10,37],
+"class_ogre_1_1_colour_value.html#a6e086633637e335238d517e0ec9f2cd2":[5,0,2,10,38],
+"class_ogre_1_1_colour_value.html#a788549742c1f030184c53008423c7b9c":[5,0,2,10,19],
+"class_ogre_1_1_colour_value.html#a7c80a19ac61f97f217d5b39d8f1dd39b":[5,0,2,10,1],
+"class_ogre_1_1_colour_value.html#a7ced6ef07e9a1e6de8ea50ef824ed9b1":[5,0,2,10,10],
+"class_ogre_1_1_colour_value.html#a7f86f695818890ba2f857618b1af9f59":[5,0,2,10,9],
+"class_ogre_1_1_colour_value.html#a7f8a06f2a9dd645417c36b560f496c1a":[5,0,2,10,33],
+"class_ogre_1_1_colour_value.html#a854058a76927880ae345ac1c465f9713":[5,0,2,10,41],
+"class_ogre_1_1_colour_value.html#a8638135228e5ddcd1dc7db320542cf72":[5,0,2,10,17],
+"class_ogre_1_1_colour_value.html#a8bf64c97ca14f64127cb3f5f95e856cf":[5,0,2,10,20],
+"class_ogre_1_1_colour_value.html#a8da50314432c59dee0aa3e6a72183e34":[5,0,2,10,23],
+"class_ogre_1_1_colour_value.html#a8eba66b2908f44f00f8d9c9ec25877de":[5,0,2,10,34],
+"class_ogre_1_1_colour_value.html#aa8bbc191b3de291abe02fce7e0d619c2":[5,0,2,10,12],
+"class_ogre_1_1_colour_value.html#aae078d77b654f76e3b760174f93474ec":[5,0,2,10,40],
+"class_ogre_1_1_colour_value.html#aaf5cc43741699cd3c0c7e81a1dc349a2":[5,0,2,10,7],
+"class_ogre_1_1_colour_value.html#ab9c2a36f53ac599850f1cf8b822f750d":[5,0,2,10,35],
+"class_ogre_1_1_colour_value.html#abbc9a8f5cc1c054eb5b4633d6b0b2262":[5,0,2,10,24],
+"class_ogre_1_1_colour_value.html#abc5d5f80d4d99438863cc808169283b5":[5,0,2,10,32],
+"class_ogre_1_1_colour_value.html#ac8e68543a87fcc6e1c0789c052fa45ba":[5,0,2,10,13],
+"class_ogre_1_1_colour_value.html#acc033c4828ad9f7469269933d24850f5":[5,0,2,10,0],
+"class_ogre_1_1_colour_value.html#ad33e4ae6c7e6d223545613c4991c91ed":[5,0,2,10,22],
+"class_ogre_1_1_colour_value.html#ae256d6a81e87d0f33a0c27c10d6b78f6":[5,0,2,10,27],
 "class_ogre_1_1_colour_value.html#ae493dc97ca571117a5709088d1494bde":[5,0,2,10,18],
 "class_ogre_1_1_colour_value.html#aebee8d25bcd490889866a0ad94940ef7":[5,0,2,10,25],
 "class_ogre_1_1_colour_value.html#af3579c76f3cd365ac54454be6a3f6f89":[5,0,2,10,14],
@@ -31,10 +76,10 @@ var NAVTREEINDEX23 =
 "class_ogre_1_1_composition_pass.html#a0367e89580ffd67000ce52676866fa43":[5,0,1,8,10],
 "class_ogre_1_1_composition_pass.html#a052e16876215e11e03bcba8657faf917":[5,0,1,8,33],
 "class_ogre_1_1_composition_pass.html#a05cbca68fbc408dbf755612cfb72707d":[5,0,1,8,48],
-"class_ogre_1_1_composition_pass.html#a0937b1f59f584797d44383eeb44b30eb":[5,0,1,8,56],
-"class_ogre_1_1_composition_pass.html#a0a8e642c52e2b7db79765f93b1cf5730":[5,0,1,8,52],
+"class_ogre_1_1_composition_pass.html#a0937b1f59f584797d44383eeb44b30eb":[5,0,1,8,58],
+"class_ogre_1_1_composition_pass.html#a0a8e642c52e2b7db79765f93b1cf5730":[5,0,1,8,54],
 "class_ogre_1_1_composition_pass.html#a14fcb5fbfd45871dca725c88de5a83a5":[5,0,1,8,30],
-"class_ogre_1_1_composition_pass.html#a186b5a3bcb90a3ce1d66f97424cd339c":[5,0,1,8,51],
+"class_ogre_1_1_composition_pass.html#a186b5a3bcb90a3ce1d66f97424cd339c":[5,0,1,8,52],
 "class_ogre_1_1_composition_pass.html#a193d54ee08e19d538576ca300c30c006":[5,0,1,8,13],
 "class_ogre_1_1_composition_pass.html#a1947a2e49e4c78d3fa806933690e6522":[5,0,1,8,14],
 "class_ogre_1_1_composition_pass.html#a1b8cc0c3221bfbc751328cda98c8aff7":[5,0,1,8,31],
@@ -44,7 +89,7 @@ var NAVTREEINDEX23 =
 "class_ogre_1_1_composition_pass.html#a31e5b47326f6357b7172faca282cb3ea":[5,0,1,8,28],
 "class_ogre_1_1_composition_pass.html#a354620f0bec90c923b57707019195483":[5,0,1,8,36],
 "class_ogre_1_1_composition_pass.html#a3c873101dd6bb94c9cea93fcc2a6e55b":[5,0,1,8,24],
-"class_ogre_1_1_composition_pass.html#a3efae9c2f40f1f44a148497797c2f8f0":[5,0,1,8,57],
+"class_ogre_1_1_composition_pass.html#a3efae9c2f40f1f44a148497797c2f8f0":[5,0,1,8,59],
 "class_ogre_1_1_composition_pass.html#a453231b980fc04dd9af9f330feec5236":[5,0,1,8,9],
 "class_ogre_1_1_composition_pass.html#a45657514c52a86f22d9d575fa248de0a":[5,0,1,8,42],
 "class_ogre_1_1_composition_pass.html#a4af9e5a958c5ec3a69f8bd797d4c2563":[5,0,1,8,11],
@@ -52,6 +97,8 @@ var NAVTREEINDEX23 =
 "class_ogre_1_1_composition_pass.html#a548f5811f1b762b2a64257367f564378":[5,0,1,8,20],
 "class_ogre_1_1_composition_pass.html#a56bb1d899a43195712944398e2d1bc65":[5,0,1,8,6],
 "class_ogre_1_1_composition_pass.html#a5815c0e9e598fe58d2c7f76be9167976":[5,0,1,8,49],
+"class_ogre_1_1_composition_pass.html#a58915b98148aef94f7bc887983db41d3":[5,0,1,8,51],
+"class_ogre_1_1_composition_pass.html#a59249a96733d39ab3df8b073ef9d5633":[5,0,1,8,60],
 "class_ogre_1_1_composition_pass.html#a5b5540cb8dc10175dc30c3947032013c":[5,0,1,8,2],
 "class_ogre_1_1_composition_pass.html#a6a51eff0938089a5fc26c1bec5c3778f":[5,0,1,8,5],
 "class_ogre_1_1_composition_pass.html#a6e14a28e603b902ee0794f78912f329f":[5,0,1,8,40],
@@ -60,7 +107,7 @@ var NAVTREEINDEX23 =
 "class_ogre_1_1_composition_pass.html#a822bb35bad3ba41e1370c08891428053":[5,0,1,8,16],
 "class_ogre_1_1_composition_pass.html#a86b647f3dff3e2fc021302c23827b603":[5,0,1,8,18],
 "class_ogre_1_1_composition_pass.html#a88aed71c3c005bea6be70c8d58db3232":[5,0,1,8,47],
-"class_ogre_1_1_composition_pass.html#a88bc728d5e0497ce4c5dbc052239551d":[5,0,1,8,55],
+"class_ogre_1_1_composition_pass.html#a88bc728d5e0497ce4c5dbc052239551d":[5,0,1,8,57],
 "class_ogre_1_1_composition_pass.html#a8b0e3dcfccbdcc9672a96ae6dc2c0123":[5,0,1,8,4],
 "class_ogre_1_1_composition_pass.html#a92187a460af36b8ebe0828cf6d81c277":[5,0,1,8,17],
 "class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aa":[5,0,1,8,1],
@@ -69,11 +116,14 @@ var NAVTREEINDEX23 =
 "class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aaaa7d4ed28ab9cdd43e85a715bd4e068fc":[5,0,1,8,1,0],
 "class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aaaba93db3e2878858fe2fd199354c82af9":[5,0,1,8,1,4],
 "class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aaac8aa60611671e1b8867c1a30775ba84c":[5,0,1,8,1,2],
+"class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aaafa19263d8a14d62c4aec06a1dd14f6ed":[5,0,1,8,1,5],
+"class_ogre_1_1_composition_pass.html#aae07036bc113572b68bd3ad85aad4ad0":[5,0,1,8,61],
 "class_ogre_1_1_composition_pass.html#ab60bfaaed2a48057ac8e8e7ead113f60":[5,0,1,8,7],
 "class_ogre_1_1_composition_pass.html#ab7f667605829412a22d0cccd9c1d7e6c":[5,0,1,8,12],
+"class_ogre_1_1_composition_pass.html#ab80f5bdd57e0c746293bdd5a9f3adef2":[5,0,1,8,53],
 "class_ogre_1_1_composition_pass.html#ab8fc137845790b360d57056621cd1061":[5,0,1,8,3],
 "class_ogre_1_1_composition_pass.html#ac0daef1d307ace963959896a3db64d75":[5,0,1,8,50],
-"class_ogre_1_1_composition_pass.html#ac2831cd42c94887f6e239d1460dc6b5c":[5,0,1,8,53],
+"class_ogre_1_1_composition_pass.html#ac2831cd42c94887f6e239d1460dc6b5c":[5,0,1,8,55],
 "class_ogre_1_1_composition_pass.html#ac4fae76a4f67e1ea70dc270be9b0daed":[5,0,1,8,22],
 "class_ogre_1_1_composition_pass.html#ad3b550fd01154eddeaf8cbc7459c75f9":[5,0,1,8,44],
 "class_ogre_1_1_composition_pass.html#ad72002d4220edc51b6ac40bbd811cbee":[5,0,1,8,21],
@@ -81,7 +131,7 @@ var NAVTREEINDEX23 =
 "class_ogre_1_1_composition_pass.html#ad7afd96369d5093b5eb2123f2befed58":[5,0,1,8,35],
 "class_ogre_1_1_composition_pass.html#adcd852af123434d7ff154a2569121d27":[5,0,1,8,38],
 "class_ogre_1_1_composition_pass.html#adfa90e05d769083fe4823a6fff4177c0":[5,0,1,8,26],
-"class_ogre_1_1_composition_pass.html#ae350fcee79e006e23d6de413253568e5":[5,0,1,8,54],
+"class_ogre_1_1_composition_pass.html#ae350fcee79e006e23d6de413253568e5":[5,0,1,8,56],
 "class_ogre_1_1_composition_pass.html#ae3c196d705b7bf120e0d888b4867dda4":[5,0,1,8,37],
 "class_ogre_1_1_composition_pass.html#ae5884df0782f751715d36c0027912760":[5,0,1,8,46],
 "class_ogre_1_1_composition_pass.html#af0f6a55176e7c69fda820a5d22a50104":[5,0,1,8,27],
@@ -99,11 +149,11 @@ var NAVTREEINDEX23 =
 "class_ogre_1_1_composition_target_pass.html#a1cdcf4aecda536e2eeaf597c60d3271d":[5,0,1,9,14],
 "class_ogre_1_1_composition_target_pass.html#a211bcd76961f116969bbc4b1a5d7562d":[5,0,1,9,20],
 "class_ogre_1_1_composition_target_pass.html#a3f57dcb06d3d764e4fe532be89e6f350":[5,0,1,9,13],
+"class_ogre_1_1_composition_target_pass.html#a485d756e6f4cfa7aaea5286ee7f4b331":[5,0,1,9,19],
 "class_ogre_1_1_composition_target_pass.html#a5e1075c8f2a3c9cfaed6f65a9ea55334":[5,0,1,9,27],
 "class_ogre_1_1_composition_target_pass.html#a5f741ec104a602e81d3f9b5f01ae2d4c":[5,0,1,9,11],
 "class_ogre_1_1_composition_target_pass.html#a612ca8c0c7b29fe33def25042b933622":[5,0,1,9,3],
 "class_ogre_1_1_composition_target_pass.html#a77a7e3bada28e04c2498aff78886d8b8":[5,0,1,9,18],
-"class_ogre_1_1_composition_target_pass.html#a7eb0dfa68069759225458c041358505e":[5,0,1,9,19],
 "class_ogre_1_1_composition_target_pass.html#a81f81638ed902707871edaa54d570e3c":[5,0,1,9,25],
 "class_ogre_1_1_composition_target_pass.html#a9906c9ece49a038ff4996ff461238dd4":[5,0,1,9,4],
 "class_ogre_1_1_composition_target_pass.html#a9dc0b04a179dd54ca7d444d4bd1c2010":[5,0,1,9,22],
@@ -199,55 +249,5 @@ var NAVTREEINDEX23 =
 "class_ogre_1_1_compositor.html#a34a3a5086152382d77a85c25fbabb1be":[5,0,1,11,0],
 "class_ogre_1_1_compositor.html#a350b287fa3e83a389221274f68760008":[5,0,1,11,19],
 "class_ogre_1_1_compositor.html#a367f6fe60bb211cb4c32e3825ca67e4c":[5,0,1,11,35],
-"class_ogre_1_1_compositor.html#a382919945c07a6a13136889ad3fbf578":[5,0,1,11,38],
-"class_ogre_1_1_compositor.html#a3af26f716731b64850ea50cfa4d2edef":[5,0,1,11,31],
-"class_ogre_1_1_compositor.html#a3c49142f739ba8fb56d6e7b3db235fb7":[5,0,1,11,37],
-"class_ogre_1_1_compositor.html#a3eb4d1565e58524f2fa5bd75f7d2faaf":[5,0,1,11,15],
-"class_ogre_1_1_compositor.html#a5016aec1762b026997ddd346775879ef":[5,0,1,11,21],
-"class_ogre_1_1_compositor.html#a52653a85d40ae889556707320a784d3e":[5,0,1,11,14],
-"class_ogre_1_1_compositor.html#a5513ffce404b14cff72846318b018d32":[5,0,1,11,36],
-"class_ogre_1_1_compositor.html#a57a6ab020e5ac812bb96aa59b1497fbd":[5,0,1,11,10],
-"class_ogre_1_1_compositor.html#a5f67f123b05545fa5e4a561d9a1019db":[5,0,1,11,9],
-"class_ogre_1_1_compositor.html#a60ce96525ac730a0f7b466ed287beef3":[5,0,1,11,33],
-"class_ogre_1_1_compositor.html#a65cd9c6af5f17b32283be24e0b13010f":[5,0,1,11,11],
-"class_ogre_1_1_compositor.html#a66446a9477813c7aba01f7f5792539da":[5,0,1,11,6],
-"class_ogre_1_1_compositor.html#a699d1c851f494a8d5d23d23b695ceb47":[5,0,1,11,20],
-"class_ogre_1_1_compositor.html#a6aad43a583eb72dc24b479b3138c7277":[5,0,1,11,16],
-"class_ogre_1_1_compositor.html#a74138c0203835513613af73cdb08890d":[5,0,1,11,30],
-"class_ogre_1_1_compositor.html#a78ac5745673e6e9f44a866ef016710cd":[5,0,1,11,5],
-"class_ogre_1_1_compositor.html#a792451bc7c47f826ce03538b4060a527":[5,0,1,11,17],
-"class_ogre_1_1_compositor.html#a7e248a1cca0662418d4ab3f63c2e7cf6":[5,0,1,11,42],
-"class_ogre_1_1_compositor.html#a8eb34a9034aab62fd537c021a79e3366":[5,0,1,11,22],
-"class_ogre_1_1_compositor.html#a8f541900f7e1f73f4c313a732199029a":[5,0,1,11,23],
-"class_ogre_1_1_compositor.html#a9aac32f93bd149a34b809a57a9f01f8f":[5,0,1,11,52],
-"class_ogre_1_1_compositor.html#aa31bef1bfaa87731622e56f11b548e27":[5,0,1,11,24],
-"class_ogre_1_1_compositor.html#aa5d6f3f7e73b77b233fc62b11f270e4d":[5,0,1,11,39],
-"class_ogre_1_1_compositor.html#aa68664db6b8723dc198beef3d21d4ef5":[5,0,1,11,45],
-"class_ogre_1_1_compositor.html#aa85a7d4b10576c0463137622754f8fa2":[5,0,1,11,12],
-"class_ogre_1_1_compositor.html#aad68d8b18faad14e8286a67527094654":[5,0,1,11,54],
-"class_ogre_1_1_compositor.html#aae47eb9cabec8ad5c8b40a0dd0e8180d":[5,0,1,11,7],
-"class_ogre_1_1_compositor.html#aaf3746937cd11864f53bc1c3b4437541":[5,0,1,11,47],
-"class_ogre_1_1_compositor.html#aaf63d096584ac7d97fe1d1b0226c9561":[5,0,1,11,46],
-"class_ogre_1_1_compositor.html#ab6e377a3964d566ea112fe63bf1d7678":[5,0,1,11,40],
-"class_ogre_1_1_compositor.html#acc029ae8cf6f0db569d8328621c6cd50":[5,0,1,11,1],
-"class_ogre_1_1_compositor.html#ad23b6bce8105e74e6a95ca59716f2b9d":[5,0,1,11,18],
-"class_ogre_1_1_compositor.html#ad4b984bfbf148ddb3310b3d0ba8a9d5d":[5,0,1,11,50],
-"class_ogre_1_1_compositor.html#ade85e4d5579519e4117a84789c0ae8fd":[5,0,1,11,43],
-"class_ogre_1_1_compositor.html#ae0a0007de944eb3c2f933a372a752b35":[5,0,1,11,34],
-"class_ogre_1_1_compositor.html#ae229b1f58092109adef55bfc6f864d79":[5,0,1,11,26],
-"class_ogre_1_1_compositor.html#ae3e13925bde11db245f6c9bbf5031a93":[5,0,1,11,48],
-"class_ogre_1_1_compositor.html#ae84e52a8c5cab12987e87a6ef3a9f544":[5,0,1,11,8],
-"class_ogre_1_1_compositor.html#afcb4a61b965600a67ca2c2f060821db9":[5,0,1,11,44],
-"class_ogre_1_1_compositor_chain.html":[5,0,1,12],
-"class_ogre_1_1_compositor_chain.html#a03dbde3d43fe8f2b7d1a6c69a86a1265":[5,0,1,12,26],
-"class_ogre_1_1_compositor_chain.html#a0734f14af2d3afbff956f53ce08b6138":[5,0,1,12,22],
-"class_ogre_1_1_compositor_chain.html#a0786570dbe0567f781db42c64cdc0864":[5,0,1,12,25],
-"class_ogre_1_1_compositor_chain.html#a0c5a67e7aeb3f74242a45972f30073eb":[5,0,1,12,27],
-"class_ogre_1_1_compositor_chain.html#a136bcc91dece7d0c020c6bf4e635a2f3":[5,0,1,12,8],
-"class_ogre_1_1_compositor_chain.html#a14097db252e2d5518763949112f48037":[5,0,1,12,19],
-"class_ogre_1_1_compositor_chain.html#a16acff0bca06c03a0b3664032631dd5f":[5,0,1,12,9],
-"class_ogre_1_1_compositor_chain.html#a2209b014e144403acd39584e68850176":[5,0,1,12,18],
-"class_ogre_1_1_compositor_chain.html#a35303e72d69bd3f190ef0892951edf20a211cdeef73f26db87dcf6868074c1c9d":[5,0,1,12,3],
-"class_ogre_1_1_compositor_chain.html#a35303e72d69bd3f190ef0892951edf20ad74d313e7f90ecfbcbcd6e7de0726b88":[5,0,1,12,2],
-"class_ogre_1_1_compositor_chain.html#a35303e72d69bd3f190ef0892951edf20ae0921c1dd226396b0328d10d0d81f62b":[5,0,1,12,4]
+"class_ogre_1_1_compositor.html#a382919945c07a6a13136889ad3fbf578":[5,0,1,11,38]
 };
