@@ -1,6 +1,8 @@
 var searchData=
 [
   ['safeboolhelper',['SafeBoolHelper',['../struct_ogre_1_1_com_ptr_1_1_safe_bool_helper.html',1,'Ogre::ComPtr']]],
+  ['sampler',['Sampler',['../class_ogre_1_1_sampler.html',1,'Ogre']]],
+  ['sampletextureatom',['SampleTextureAtom',['../class_ogre_1_1_r_t_shader_1_1_sample_texture_atom.html',1,'Ogre::RTShader']]],
   ['scaleaffector',['ScaleAffector',['../class_ogre_1_1_scale_affector.html',1,'Ogre']]],
   ['scaleaffectorfactory',['ScaleAffectorFactory',['../class_ogre_1_1_scale_affector_factory.html',1,'Ogre']]],
   ['scalecontrollerfunction',['ScaleControllerFunction',['../class_ogre_1_1_scale_controller_function.html',1,'Ogre']]],
@@ -35,7 +37,6 @@ var searchData=
   ['shaderhelper',['ShaderHelper',['../class_ogre_1_1_shader_helper.html',1,'Ogre']]],
   ['shaderhelpercg',['ShaderHelperCg',['../class_ogre_1_1_shader_helper_cg.html',1,'Ogre']]],
   ['shaderhelperglsl',['ShaderHelperGLSL',['../class_ogre_1_1_shader_helper_g_l_s_l.html',1,'Ogre']]],
-  ['shaderhelperhlsl',['ShaderHelperHLSL',['../class_ogre_1_1_shader_helper_h_l_s_l.html',1,'Ogre']]],
   ['shadermanager',['ShaderManager',['../class_ogre_1_1_shader_manager.html',1,'Ogre']]],
   ['shaderpiecesmanager',['ShaderPiecesManager',['../class_ogre_1_1_shader_pieces_manager.html',1,'Ogre']]],
   ['shaderprogramwritercgfactory',['ShaderProgramWriterCGFactory',['../class_ogre_1_1_r_t_shader_1_1_shader_program_writer_c_g_factory.html',1,'Ogre::RTShader']]],
@@ -59,7 +60,6 @@ var searchData=
   ['sharedptr_3c_20gpulogicalbufferstruct_20_3e',['SharedPtr&lt; GpuLogicalBufferStruct &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
   ['sharedptr_3c_20gpunamedconstants_20_3e',['SharedPtr&lt; GpuNamedConstants &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
   ['sharedptr_3c_20gpuprogram_20_3e',['SharedPtr&lt; GpuProgram &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
-  ['sharedptr_3c_20gpuprogramparameters_20_3e',['SharedPtr&lt; GpuProgramParameters &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
   ['sharedptr_3c_20gpusharedparameters_20_3e',['SharedPtr&lt; GpuSharedParameters &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
   ['sharedptr_3c_20hardwareindexbuffer_20_3e',['SharedPtr&lt; HardwareIndexBuffer &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
   ['sharedptr_3c_20hardwareuniformbuffer_20_3e',['SharedPtr&lt; HardwareUniformBuffer &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
@@ -77,12 +77,11 @@ var searchData=
   ['sharedptr_3c_20ogre_3a_3artshader_3a_3adualquaternionskinning_20_3e',['SharedPtr&lt; Ogre::RTShader::DualQuaternionSkinning &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
   ['sharedptr_3c_20ogre_3a_3artshader_3a_3ahardwareskinningtechnique_20_3e',['SharedPtr&lt; Ogre::RTShader::HardwareSkinningTechnique &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
   ['sharedptr_3c_20ogre_3a_3artshader_3a_3alinearskinning_20_3e',['SharedPtr&lt; Ogre::RTShader::LinearSkinning &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
-  ['sharedptr_3c_20ogre_3a_3avector3_20_3e',['SharedPtr&lt; Ogre::Vector3 &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
+  ['sharedptr_3c_20ogre_3a_3avector_20_3e',['SharedPtr&lt; Ogre::Vector &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
   ['sharedptr_3c_20rendersystemdata_20_3e',['SharedPtr&lt; RenderSystemData &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
   ['sharedptr_3c_20resource_20_3e',['SharedPtr&lt; Resource &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
   ['sharedptr_3c_20shadowcamerasetup_20_3e',['SharedPtr&lt; ShadowCameraSetup &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
   ['sharedptr_3c_20skeleton_20_3e',['SharedPtr&lt; Skeleton &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
-  ['sharedptr_3c_20std_3a_3avector_3c_20memorydatastreamptr_20_3e_20_3e',['SharedPtr&lt; std::vector&lt; MemoryDataStreamPtr &gt; &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
   ['sharedptr_3c_20subrenderstateaccessor_20_3e',['SharedPtr&lt; SubRenderStateAccessor &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
   ['sharedptr_3c_20terrainmaterialgenerator_20_3e',['SharedPtr&lt; TerrainMaterialGenerator &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
   ['sharedptr_3c_20texture_20_3e',['SharedPtr&lt; Texture &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
