@@ -37,6 +37,7 @@ var searchData=
   ['ogre_5fexcept_5fex',['OGRE_EXCEPT_EX',['../_ogre_d3_d11_prerequisites_8h.html#a158d9c8ba6320aa37b7c9c05a2f2fd8f',1,'OgreD3D11Prerequisites.h']]],
   ['ogre_5ffallthrough',['OGRE_FALLTHROUGH',['../_ogre_platform_8h.html#af56e69ee080587cf0f82cab0908e528f',1,'OgrePlatform.h']]],
   ['ogre_5fforce_5finline',['OGRE_FORCE_INLINE',['../_ogre_platform_8h.html#a6cbacd9965b6b575077a96dbf96cb23c',1,'OgrePlatform.h']]],
+  ['ogre_5fformat_5fprintf',['OGRE_FORMAT_PRINTF',['../_ogre_string_8h.html#a18be116478950d504532daf9c307fa1b',1,'OgreString.h']]],
   ['ogre_5fgl_5fdefault_5fmap_5fbuffer_5fthreshold',['OGRE_GL_DEFAULT_MAP_BUFFER_THRESHOLD',['../_ogre_g_l_hardware_buffer_manager_8h.html#aae90f8b1399ebc9b28abb1a0c4ef8426',1,'OGRE_GL_DEFAULT_MAP_BUFFER_THRESHOLD():&#160;OgreGLHardwareBufferManager.h'],['../_ogre_g_l3_plus_hardware_buffer_manager_8h.html#aae90f8b1399ebc9b28abb1a0c4ef8426',1,'OGRE_GL_DEFAULT_MAP_BUFFER_THRESHOLD():&#160;OgreGL3PlusHardwareBufferManager.h']]],
   ['ogre_5fhash_5fbits',['OGRE_HASH_BITS',['../_ogre_id_string_8h.html#a65d81f8d195ea976dbed9daee4cc31f0',1,'OgreIdString.h']]],
   ['ogre_5fhash_5ffunc',['OGRE_HASH_FUNC',['../_ogre_id_string_8h.html#a295b313eb759fefc52c8e195bb9c8e01',1,'OgreIdString.h']]],
@@ -101,11 +102,6 @@ var searchData=
   ['ogre_5ftoken_5fpaste_5fextra',['OGRE_TOKEN_PASTE_EXTRA',['../_ogre_thread_defines_boost_8h.html#a91ea768464f54b7215ce6ddce806d168',1,'OGRE_TOKEN_PASTE_EXTRA():&#160;OgreThreadDefinesBoost.h'],['../_ogre_thread_defines_poco_8h.html#a91ea768464f54b7215ce6ddce806d168',1,'OGRE_TOKEN_PASTE_EXTRA():&#160;OgreThreadDefinesPoco.h'],['../_ogre_thread_defines_s_t_d_8h.html#a91ea768464f54b7215ce6ddce806d168',1,'OGRE_TOKEN_PASTE_EXTRA():&#160;OgreThreadDefinesSTD.h'],['../_ogre_thread_defines_t_b_b_8h.html#a91ea768464f54b7215ce6ddce806d168',1,'OGRE_TOKEN_PASTE_EXTRA():&#160;OgreThreadDefinesTBB.h']]],
   ['ogre_5funlock_5frecursive_5fmutex',['OGRE_UNLOCK_RECURSIVE_MUTEX',['../_ogre_d3_d9_prerequisites_8h.html#a93ac575df386b84b1954cb49c5d5602b',1,'OgreD3D9Prerequisites.h']]],
   ['ogre_5fversion',['OGRE_VERSION',['../_ogre_prerequisites_8h.html#a3f631403da0a255c201870bfd068f8c5',1,'OgrePrerequisites.h']]],
-  ['ogre_5fversion_5fmajor',['OGRE_VERSION_MAJOR',['../_ogre_prerequisites_8h.html#ae5b524dcaad06fe829b6a1952cc6f7cf',1,'OgrePrerequisites.h']]],
-  ['ogre_5fversion_5fminor',['OGRE_VERSION_MINOR',['../_ogre_prerequisites_8h.html#a151f60246acece3e651a8f1d0999f85b',1,'OgrePrerequisites.h']]],
-  ['ogre_5fversion_5fname',['OGRE_VERSION_NAME',['../_ogre_prerequisites_8h.html#a4a5177c0cfa26a662edfe3e311935fdf',1,'OgrePrerequisites.h']]],
-  ['ogre_5fversion_5fpatch',['OGRE_VERSION_PATCH',['../_ogre_prerequisites_8h.html#a144780d2bcdd852d2ff7a7a450c7856d',1,'OgrePrerequisites.h']]],
-  ['ogre_5fversion_5fsuffix',['OGRE_VERSION_SUFFIX',['../_ogre_prerequisites_8h.html#abce1e968a0f7309c73a8a2d7a19544e2',1,'OgrePrerequisites.h']]],
   ['ogre_5fwarn',['OGRE_WARN',['../_ogre_platform_8h.html#ab61ba9272b27cdd1181dd5a18d40b750',1,'OgrePlatform.h']]],
   ['ogre_5fwq_5flock_5fmutex',['OGRE_WQ_LOCK_MUTEX',['../_ogre_thread_defines_boost_8h.html#a8ce85557a9af87093c51ee7e29983ed3',1,'OGRE_WQ_LOCK_MUTEX():&#160;OgreThreadDefinesBoost.h'],['../_ogre_thread_defines_none_8h.html#a8ce85557a9af87093c51ee7e29983ed3',1,'OGRE_WQ_LOCK_MUTEX():&#160;OgreThreadDefinesNone.h'],['../_ogre_thread_defines_poco_8h.html#a8ce85557a9af87093c51ee7e29983ed3',1,'OGRE_WQ_LOCK_MUTEX():&#160;OgreThreadDefinesPoco.h'],['../_ogre_thread_defines_s_t_d_8h.html#a8ce85557a9af87093c51ee7e29983ed3',1,'OGRE_WQ_LOCK_MUTEX():&#160;OgreThreadDefinesSTD.h'],['../_ogre_thread_defines_t_b_b_8h.html#a8ce85557a9af87093c51ee7e29983ed3',1,'OGRE_WQ_LOCK_MUTEX():&#160;OgreThreadDefinesTBB.h']]],
   ['ogre_5fwq_5flock_5fmutex_5fnamed',['OGRE_WQ_LOCK_MUTEX_NAMED',['../_ogre_thread_defines_boost_8h.html#ab994bbfdc9effbbf7170506620add8e0',1,'OGRE_WQ_LOCK_MUTEX_NAMED():&#160;OgreThreadDefinesBoost.h'],['../_ogre_thread_defines_none_8h.html#ab994bbfdc9effbbf7170506620add8e0',1,'OGRE_WQ_LOCK_MUTEX_NAMED():&#160;OgreThreadDefinesNone.h'],['../_ogre_thread_defines_poco_8h.html#ab994bbfdc9effbbf7170506620add8e0',1,'OGRE_WQ_LOCK_MUTEX_NAMED():&#160;OgreThreadDefinesPoco.h'],['../_ogre_thread_defines_s_t_d_8h.html#ab994bbfdc9effbbf7170506620add8e0',1,'OGRE_WQ_LOCK_MUTEX_NAMED():&#160;OgreThreadDefinesSTD.h'],['../_ogre_thread_defines_t_b_b_8h.html#ab994bbfdc9effbbf7170506620add8e0',1,'OGRE_WQ_LOCK_MUTEX_NAMED():&#160;OgreThreadDefinesTBB.h']]],
