@@ -8,7 +8,7 @@ var indexSectionsWithContent =
   5: "_abcdefghiklmnopqrstuvwxyz",
   6: "_abcdefghiklmnopqrstuvwz",
   7: "abcdefgilmnoprstuvw",
-  8: "abcdefghiklmnopqrstuvw",
+  8: "abcdefghiklmnopqrstuvwz",
   9: "abcdefgimoprstw",
   10: "_abcdeghimnopstw",
   11: "abcdeghilmoprstv",
